#
# spec file for package qemu-testsuite
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define noarch_supported 1110

%define build_x86_firmware_from_source 0
%define build_slof_from_source 0
%define kvm_available 0
%define legacy_qemu_kvm 0

%if "%{?distribution}" == ""
%define distro private-build
%else
%define distro %{distribution}
%endif

%ifarch %ix86 x86_64
# choice of building all from source or using provided binary x86 blobs
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
%define build_x86_firmware_from_source 1
%endif
%endif

%ifarch ppc64
%define build_slof_from_source 1
%endif

%ifarch ppc64le
%if 0%{?suse_version} > 1320 ||  0%{?suse_version} == 1315
%define build_slof_from_source 1
%endif
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390x armv7hl aarch64
%define kvm_available 1
%endif

%ifarch %ix86 x86_64 s390x
%define legacy_qemu_kvm 1
%endif

%if 0%{?suse_version} >= 1210
%define with_systemd 1
%endif

%ifarch x86_64
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && ( 0%{?is_opensuse} == 0 || 0%{?sle_version} > 120100 ) )
%define with_rbd 1
%endif
%endif

%ifarch aarch64
%if 0%{?suse_version} > 1320 || ( 0%{?is_opensuse} == 0 && 0%{?sle_version} > 120100 )
%define with_rbd 1
%endif
%endif

%ifarch ppc64le
%if 0%{?suse_version} > 1320 || ( 0%{?is_opensuse} == 0 && 0%{?sle_version} > 120200 )
%define with_rbd 1
%endif
%endif

%ifarch s390x
%if 0%{?is_opensuse} == 0 && 0%{?sle_version} > 120200
%define with_rbd 1
%endif
%endif

%ifarch ppc64
%if 0%{?is_opensuse} && 0%{?sle_version} > 120200
%define with_rbd 1
%endif
%endif

%if 0%{?suse_version} > 1320
%define with_seccomp 1
%endif

%ifarch %ix86 x86_64
%define with_seccomp 1
%endif

%if 0%{?suse_version} >= 1140
%define with_spice 1
%else
%ifarch %ix86 x86_64
%define with_spice 1
%endif
%endif

%if 0%( pkg-config --exists 'udev > 190' && echo '1' ) == 01
%define _udevrulesdir /usr/lib/udev/rules.d
%else
%define _udevrulesdir /lib/udev/rules.d
%endif

Name:           qemu-testsuite
Url:            https://www.qemu.org/
Summary:        Universal CPU emulator
License:        BSD-3-Clause and GPL-2.0-only and GPL-2.0-or-later and LGPL-2.1-or-later and MIT
Group:          System/Emulators/PC
Version:        2.9.1
Release:        62.1
Source:         https://wiki.qemu.org/download/qemu-2.9.1.tar.xz
Source99:       https://wiki.qemu.org/download/qemu-2.9.1.tar.xz.sig
Source1:        80-kvm.rules
Source2:        qemu-ifup
Source3:        kvm_stat
Source4:        qemu-kvm.1.gz
Source5:        60-kvm.rules
Source6:        ksm.service
Source7:        60-kvm.x86.rules
Source8:        80-qemu-ga.rules
Source9:        qemu-ga.service
Source10:       kvm.conf
Source11:       kvm_stat.1.gz
Source12:       supported.x86.txt
Source13:       supported.s390.txt
Source14:       supported.arm.txt
Source15:       supported.ppc.txt
# Upstream First -- https://wiki.qemu.org/Contribute/SubmitAPatch
# This patch queue is auto-generated from https://gitlab.suse.de/virtualization/qemu
Patch0001:      0001-XXX-dont-dump-core-on-sigabort.patch
Patch0002:      0002-qemu-binfmt-conf-Modify-default-pat.patch
Patch0003:      0003-qemu-cvs-alsa_bitfield.patch
Patch0004:      0004-qemu-cvs-alsa_ioctl.patch
Patch0005:      0005-qemu-cvs-alsa_mmap.patch
Patch0006:      0006-qemu-cvs-gettimeofday.patch
Patch0007:      0007-qemu-cvs-ioctl_debug.patch
Patch0008:      0008-qemu-cvs-ioctl_nodirection.patch
Patch0009:      0009-linux-user-add-binfmt-wrapper-for-a.patch
Patch0010:      0010-PPC-KVM-Disable-mmu-notifier-check.patch
Patch0011:      0011-linux-user-fix-segfault-deadlock.patch
Patch0012:      0012-linux-user-binfmt-support-host-bina.patch
Patch0013:      0013-linux-user-Fake-proc-cpuinfo.patch
Patch0014:      0014-linux-user-XXX-disable-fiemap.patch
Patch0015:      0015-slirp-nooutgoing.patch
Patch0016:      0016-vnc-password-file-and-incoming-conn.patch
Patch0017:      0017-linux-user-use-target_ulong.patch
Patch0018:      0018-block-Add-support-for-DictZip-enabl.patch
Patch0019:      0019-block-Add-tar-container-format.patch
Patch0020:      0020-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
Patch0021:      0021-console-add-question-mark-escape-op.patch
Patch0022:      0022-Make-char-muxer-more-robust-wrt-sma.patch
Patch0023:      0023-linux-user-lseek-explicitly-cast-no.patch
Patch0024:      0024-configure-Enable-PIE-for-ppc-and-pp.patch
Patch0025:      0025-AIO-Reduce-number-of-threads-for-32.patch
Patch0026:      0026-dictzip-Fix-on-big-endian-systems.patch
Patch0027:      0027-xen_disk-Add-suse-specific-flush-di.patch
Patch0028:      0028-qemu-bridge-helper-reduce-security-.patch
Patch0029:      0029-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
Patch0030:      0030-configure-Fix-detection-of-seccomp-.patch
Patch0031:      0031-linux-user-properly-test-for-infini.patch
Patch0032:      0032-linux-user-remove-all-traces-of-qem.patch
Patch0033:      0033-roms-Makefile-pass-a-packaging-time.patch
Patch0034:      0034-Raise-soft-address-space-limit-to-h.patch
Patch0035:      0035-increase-x86_64-physical-bits-to-42.patch
Patch0036:      0036-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
Patch0037:      0037-i8254-Fix-migration-from-SLE11-SP2.patch
Patch0038:      0038-acpi_piix4-Fix-migration-from-SLE11.patch
Patch0039:      0039-Fix-tigervnc-long-press-issue.patch
Patch0040:      0040-fix-xen-hvm-direct-kernel-boot.patch
Patch0041:      0041-string-input-visitor-Fix-uint64-par.patch
Patch0042:      0042-test-string-input-visitor-Add-int-t.patch
Patch0043:      0043-test-string-input-visitor-Add-uint6.patch
Patch0044:      0044-tests-Add-QOM-property-unit-tests.patch
Patch0045:      0045-tests-Add-scsi-disk-test.patch
Patch0046:      0046-RFC-update-Linux-headers-from-irqs-.patch
Patch0047:      0047-ARM-KVM-Enable-in-kernel-timers-wit.patch
Patch0048:      0048-input-Add-trace-event-for-empty-key.patch
Patch0049:      0049-i386-Allow-cpuid-bit-override.patch
Patch0050:      0050-jazz_led-fix-bad-snprintf.patch
Patch0051:      0051-slirp-smb-Replace-constant-strings-.patch
Patch0052:      0052-altera_timer-fix-incorrect-memset.patch
Patch0053:      0053-megasas-always-store-SCSIRequest-in.patch
Patch0054:      0054-slirp-check-len-against-dhcp-option.patch
Patch0055:      0055-Replace-struct-ucontext-with-uconte.patch
Patch0056:      0056-xen-disk-don-t-leak-stack-data-via-.patch
Patch0057:      0057-IDE-Do-not-flush-empty-CDROM-drives.patch
Patch0058:      0058-IDE-test-flush-on-empty-CDROM.patch
Patch0059:      0059-multiboot-validate-multiboot-header.patch
Patch0060:      0060-vga-stop-passing-pointers-to-vga_dr.patch
Patch0061:      0061-io-monitor-encoutput-buffer-size-fr.patch
Patch0062:      0062-cirrus-fix-oob-access-in-mode4and5-.patch
Patch0063:      0063-9pfs-use-g_malloc0-to-allocate-spac.patch
Patch0064:      0064-target-i386-cpu-Add-new-EPYC-CPU-mo.patch
Patch0065:      0065-i386-Add-support-for-SPEC_CTRL-MSR.patch
Patch0066:      0066-header-sync.patch
Patch0067:      0067-s390x-kvm-Handle-bpb-feature.patch
Patch0068:      0068-s390x-kvm-provide-stfle.81.patch
Patch0069:      0069-pcihp-fix-pcihp-for-1.6-machine-typ.patch
Patch0070:      0070-virtio-check-VirtQueue-Vring-object.patch
Patch0071:      0071-ps2-check-PS2Queue-pointers-in-post.patch
Patch0072:      0072-nbd-server-CVE-2017-15119-Reject-op.patch
Patch0073:      0073-osdep-Fix-ROUND_UP-64-bit-32-bit.patch
Patch0074:      0074-vga-check-the-validation-of-memory-.patch
Patch0075:      0075-multiboot-check-mh_load_end_addr-ad.patch
Patch0076:      0076-vnc-fix-debug-spelling.patch
Patch0077:      0077-ui-remove-sync-parameter-from-vnc_u.patch
Patch0078:      0078-ui-remove-unreachable-code-in-vnc_u.patch
Patch0079:      0079-ui-remove-redundant-indentation-in-.patch
Patch0080:      0080-ui-avoid-pointless-VNC-updates-if-f.patch
Patch0081:      0081-ui-track-how-much-decoded-data-we-c.patch
Patch0082:      0082-ui-introduce-enum-to-track-VNC-clie.patch
Patch0083:      0083-ui-correctly-reset-framebuffer-upda.patch
Patch0084:      0084-ui-refactor-code-for-determining-if.patch
Patch0085:      0085-ui-fix-VNC-client-throttling-when-a.patch
Patch0086:      0086-ui-fix-VNC-client-throttling-when-f.patch
Patch0087:      0087-ui-place-a-hard-cap-on-VNC-server-o.patch
Patch0088:      0088-x86-cpu-increase-model_id-array-siz.patch
Patch0089:      0089-i386-Add-spec-ctrl-CPUID-bit.patch
Patch0090:      0090-i386-Add-FEAT_8000_0008_EBX-CPUID-f.patch
Patch0091:      0091-i386-Add-new-IBRS-versions-of-Intel.patch
Patch0092:      0092-i386-Add-EPYC-IBPB-CPU-model.patch
Patch0093:      0093-migration-warn-about-inconsistent-s.patch
Patch0094:      0094-i386-define-the-ssbd-CPUID-feature-.patch
Patch0095:      0095-tpm-lookup-cancel-path-under-tpm-de.patch
Patch0096:      0096-xen-add-block-resize-support-for-xe.patch
Patch0097:      0097-slirp-correct-size-computation-whil.patch
Patch0098:      0098-qga-check-bytes-count-read-by-guest.patch
Patch0099:      0099-i386-Define-the-Virt-SSBD-MSR-and-h.patch
Patch0100:      0100-i386-define-the-AMD-virt-ssbd-CPUID.patch
Patch0101:      0101-seccomp-changing-from-whitelist-to-.patch
Patch0102:      0102-seccomp-add-obsolete-argument-to-co.patch
Patch0103:      0103-seccomp-add-elevateprivileges-argum.patch
Patch0104:      0104-seccomp-add-spawn-argument-to-comma.patch
Patch0105:      0105-seccomp-add-resourcecontrol-argumen.patch
Patch0106:      0106-seccomp-allow-sched_setscheduler-wi.patch
Patch0107:      0107-seccomp-prefer-SCMP_ACT_KILL_PROCES.patch
Patch0108:      0108-configure-require-libseccomp-2.2.0.patch
Patch0109:      0109-seccomp-set-the-seccomp-filter-to-a.patch
Patch0110:      0110-sandbox-disable-sandbox-if-CONFIG_S.patch
Patch0111:      0111-seccomp-check-TSYNC-host-capability.patch
Patch0112:      0112-xen-rename-xen_modified_memory-to-x.patch
Patch0113:      0113-xen-make-use-of-xen_xc-implicit-in-.patch
Patch0114:      0114-xen-use-libxendevicemodel-when-avai.patch
Patch0115:      0115-xen-disk-only-advertize-feature-per.patch
Patch0116:      0116-xen-disk-add-support-for-multi-page.patch
Patch0117:      0117-xen-disk-use-g_new0-to-fix-build.patch
Patch0118:      0118-xen-add-a-global-indicator-for-gran.patch
Patch0119:      0119-xen-dont-try-setting-max-grants-mul.patch
Patch0120:      0120-xen-add-a-meaningful-declaration-of.patch
Patch0121:      0121-xen_backend-add-grant-table-helpers.patch
Patch0122:      0122-xen_disk-remove-open-coded-use-of-l.patch
Patch0123:      0123-xen-remove-other-open-coded-use-of-.patch
Patch0124:      0124-xen_backend-add-an-emulation-of-gra.patch
Patch0125:      0125-xen_disk-remove-use-of-grant-map-un.patch
Patch0126:      0126-xen_disk-use-a-single-entry-iovec.patch
Patch0127:      0127-ne2000-fix-possible-out-of-bound-ac.patch
Patch0128:      0128-rtl8139-fix-possible-out-of-bound-a.patch
Patch0129:      0129-pcnet-fix-possible-buffer-overflow.patch
Patch0130:      0130-net-ignore-packet-size-greater-than.patch
Patch0131:      0131-lsi53c895a-check-message-length-val.patch
Patch0132:      0132-hw-char-serial-Only-retry-if-qemu_c.patch
Patch0133:      0133-hw-char-serial-retry-write-if-EAGAI.patch
Patch0134:      0134-xen_disk-Avoid-repeated-memory-allo.patch
Patch0135:      0135-linux-user-write-fd-NULL-0-parity-w.patch
Patch0136:      0136-linux-user-make-pwrite64-pread64-fd.patch
Patch0137:      0137-kvmclock-update-system_time_msr-add.patch
Patch0138:      0138-kvmclock-use-the-updated-system_tim.patch
Patch0139:      0139-slirp-check-data-length-while-emula.patch
Patch0140:      0140-usb-mtp-use-O_NOFOLLOW-and-O_CLOEXE.patch
Patch0141:      0141-9p-fix-QEMU-crash-when-renaming-fil.patch
Patch0142:      0142-9p-write-lock-path-in-v9fs_co_open2.patch
Patch0143:      0143-9p-take-write-lock-on-fid-path-upda.patch
Patch0144:      0144-ppc-pnv-check-size-before-data-buff.patch
Patch0145:      0145-bitmap-add-bitmap_copy_and_clear_at.patch
Patch0146:      0146-memory-add-support-getting-and-usin.patch
Patch0147:      0147-vga-add-vga_scanline_invalidated-he.patch
Patch0148:      0148-vga-make-display-updates-thread-saf.patch
Patch0149:      0149-vga-fix-display-update-region-calcu.patch
Patch0150:      0150-vga-use-DIV_ROUND_UP.patch
Patch0151:      0151-vga-fix-display-update-region-calcu.patch
Patch0152:      0152-vga-drop-line_offset-variable.patch
Patch0153:      0153-vga-handle-cirrus-vbe-mode-wraparou.patch
Patch0154:      0154-vga-add-ram_addr_t-cast.patch
Patch0155:      0155-vga-fix-region-checks-in-wraparound.patch
Patch0156:      0156-vga-fix-region-calculation.patch
Patch0157:      0157-vga-catch-depth-0.patch
Patch0158:      0158-i386-add-Skylake-Server-cpu-model.patch
Patch0159:      0159-i386-Add-new-IBRS-versions-of-Intel.patch
Patch0160:      0160-virtio-scsi-Add-virtqueue_size-para.patch
Patch0161:      0161-slirp-check-sscanf-result-when-emul.patch
Patch0162:      0162-ppc-add-host-serial-and-host-model-.patch
Patch0163:      0163-i2c-ddc-fix-oob-read.patch
Patch0164:      0164-device_tree.c-Don-t-use-load_image.patch
Patch0165:      0165-spapr-Simplify-handling-of-host-ser.patch
Patch0166:      0166-target-i386-define-md-clear-bit.patch
# Please do not add QEMU patches manually here.
# Run update_git.sh to regenerate this queue.

# SeaBIOS / SeaVGABIOS (Currently no patches)

# ipxe
# PATCH-FIX-OPENSUSE ipxe-stable-buildid.patch brogers@suse.com -- reproducible builds
Patch1100:      ipxe-stable-buildid.patch
Patch1101:      ipxe-use-gcc6-for-more-compact-code.patch
Patch1102:      ipxe-build-Avoid-implicit-fallthrough-warnings-on-GCC-7.patch
Patch1103:      ipxe-iscsi-Always-send-FirstBurstLength-parameter.patch
Patch1104:      ipxe-ath-Add-missing-break-statements.patch
Patch1105:      ipxe-mucurses-Fix-erroneous-__nonnull-attribute.patch 

# sgabios
# PATCH-FIX-OPENSUSE sgabios-stable-buildid.patch brogers@suse.com -- reproducible builds
Patch1200:      sgabios-stable-buildid.patch

# SLOF (Currently no patches)

# this is to make lint happy
Source300:      qemu-rpmlintrc
Source302:      bridge.conf
Source400:      update_git.sh
ExcludeArch:    s390
%if "%{name}" == "qemu-testsuite"
ExcludeArch:    s390x
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#!BuildIgnore:  gcc-PIE
BuildRequires:  SDL-devel
%if 0%{?suse_version} >= 1320
BuildRequires:  SDL2-devel
%endif
BuildRequires:  alsa-devel
%if %{build_x86_firmware_from_source}
BuildRequires:  binutils-devel
%endif
BuildRequires:  bluez-devel
%if 0%{?suse_version} >= 1130
BuildRequires:  brlapi-devel
%endif
BuildRequires:  curl-devel
BuildRequires:  cyrus-sasl-devel
BuildRequires:  e2fsprogs-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
%if %{build_x86_firmware_from_source}
%if 0%{?suse_version} <= 1320
BuildRequires:  gcc6
%endif
%endif
BuildRequires:  glib2-devel
%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
BuildRequires:  glusterfs-devel
%endif
%if 0%{?suse_version} >= 1220
BuildRequires:  gtk3-devel
%else
BuildRequires:  gtk2-devel
%endif
BuildRequires:  libaio
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libbz2-devel
%if 0%{?is_opensuse}
BuildRequires:  libcacard-devel
%endif
BuildRequires:  libcap-devel
BuildRequires:  libcap-ng-devel
BuildRequires:  libdrm-devel
%if 0%{?suse_version} >= 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
BuildRequires:  libepoxy-devel
%endif
%if 0%{?suse_version} >= 1310
# 12.3 and earlier don't ship a compatible libfdt; use the bundled one there
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120200 )
BuildRequires:  libfdt-devel
%else
BuildRequires:  libfdt1-devel
%endif
%endif
BuildRequires:  libgbm-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
%if 0%{?suse_version} >= 1315
BuildRequires:  libibverbs-devel
%endif
%if 0%{?with_rbd}
%if 0%{?is_opensuse} || 0%{?sle_version} > 120100
BuildRequires:  librbd-devel
%else
BuildRequires:  ceph-devel
%endif
%endif
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
BuildRequires:  libiscsi-devel
%endif
BuildRequires:  libjpeg-devel
%if 0%{?suse_version} >= 1310
BuildRequires:  libnettle-devel
%endif
%ifarch %ix86 x86_64
%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
BuildRequires:  libnuma-devel
%endif
%else
%ifarch aarch64
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
BuildRequires:  libnuma-devel
%endif
%endif
%else
%ifnarch %arm s390x
BuildRequires:  libnuma-devel
%endif
%endif
BuildRequires:  libpcap-devel
BuildRequires:  libpixman-1-0-devel
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
%if 0%{?suse_version} >= 1315
BuildRequires:  librdmacm-devel
%endif
%if 0%{?with_seccomp}
BuildRequires:  libseccomp-devel
%endif
%if 0%{?with_spice}
BuildRequires:  libspice-server-devel
%endif
%if 0%{?suse_version} > 1140
BuildRequires:  libssh2-devel
%endif
%if 0%{?suse_version} > 1310
BuildRequires:  libusb-1_0-devel
%endif
%if 0%{?suse_version} > 1320
BuildRequires:  libvdeplug-devel
%else
BuildRequires:  libvdeplug3-devel
%endif
BuildRequires:  lzo-devel
%if 0%{?suse_version} > 1220
BuildRequires:  makeinfo
%endif
BuildRequires:  Mesa-devel
BuildRequires:  ncurses-devel
%if %{build_x86_firmware_from_source}
BuildRequires:  ovmf-tools
%endif
BuildRequires:  pkgconfig
BuildRequires:  pwdutils
BuildRequires:  python
%if 0%{?suse_version} >= 1310
BuildRequires:  snappy-devel
%endif
%if 0%{?with_spice}
BuildRequires:  spice-protocol-devel
%endif
%if 0%{?with_systemd}
BuildRequires:  systemd
%{?systemd_requires}
%endif
%if %{kvm_available}
BuildRequires:  pkgconfig(udev)
%endif
BuildRequires:  usbredir-devel
%if 0%{?suse_version} >= 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
BuildRequires:  virglrenderer-devel >= 0.4.1
%endif
%if 0%{?suse_version} >= 1210
%if 0%{?suse_version} >= 1220
BuildRequires:  vte-devel
%else
BuildRequires:  vte2-devel
%endif
%endif
%ifarch x86_64
BuildRequires:  xen-devel
%endif
BuildRequires:  xfsprogs-devel
%if %{build_x86_firmware_from_source}
BuildRequires:  xz-devel
%endif
BuildRequires:  zlib-devel
%if "%{name}" == "qemu-testsuite"
BuildRequires:  bc
BuildRequires:  qemu-arm   = %version
BuildRequires:  qemu-block-curl = %version
BuildRequires:  qemu-block-dmg = %version
BuildRequires:  qemu-extra = %version
BuildRequires:  qemu-guest-agent = %version
BuildRequires:  qemu-ppc   = %version
BuildRequires:  qemu-s390  = %version
BuildRequires:  qemu-tools = %version
BuildRequires:  qemu-x86   = %version
%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
BuildRequires:  qemu-block-gluster = %version
%endif
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
BuildRequires:  qemu-block-iscsi = %version
%endif
%if 0%{?with_rbd}
BuildRequires:  qemu-block-rbd = %version
%endif
%if 0%{?suse_version} > 1140
BuildRequires:  qemu-block-ssh = %version
%endif
%endif
Requires(pre):  shadow
Requires(post): coreutils
%if %{kvm_available}
Requires(post): acl
Requires(post): udev
%ifarch s390x
Requires(post): procps
%endif
%if 0%{?suse_version} > 1320
Recommends:     kvm_stat
%else
Recommends:     python-curses
%endif
%endif
Recommends:     qemu-block-curl
Recommends:     qemu-tools
Recommends:     qemu-x86
%ifarch ppc ppc64 ppc64le
Recommends:     qemu-ppc
%else
Suggests:       qemu-ppc
%endif
%ifarch s390x
Recommends:     qemu-s390
%else
Suggests:       qemu-s390
%endif
%ifarch %arm aarch64
Recommends:     qemu-arm
%else
Suggests:       qemu-arm
%endif
Suggests:       qemu-block-dmg
%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
Suggests:       qemu-block-gluster
%endif
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
Suggests:       qemu-block-iscsi
%endif
%if 0%{?with_rbd}
Suggests:       qemu-block-rbd
%endif
%if 0%{?suse_version} > 1140
Suggests:       qemu-block-ssh
%endif
Suggests:       qemu-extra
Suggests:       qemu-lang
%if 0%{?with_systemd} && 0%{?is_opensuse}
Recommends:     qemu-ksm = %{version}
%endif

%if %{build_slof_from_source}
%define ppc_default_built_firmware {%nil}
%define ppc_extra_built_firmware {slof.bin}
%endif

%ifarch ppc64
%define ppc64_only_default_built_firmware {spapr-rtas.bin}
%define ppc64_only_extra_built_firmware {%nil}
%endif

%ifarch s390x
%define s390x_default_built_firmware {s390-ccw.img}
%define s390x_extra_built_firmware {%nil}
%endif

%ifarch %ix86 x86_64
%define x86_default_built_firmware {linuxboot.bin linuxboot_dma.bin \
multiboot.bin kvmvapic.bin}
%ifarch x86_64
%define x86_64_only_default_built_firmware {%nil}
%endif
%endif

%define x86_extra_built_firmware_list {bios.bin bios-256k.bin sgabios.bin \
vgabios.bin vgabios-cirrus.bin vgabios-stdvga.bin vgabios-virtio.bin \
vgabios-vmware.bin vgabios-qxl.bin pxe-e1000.rom pxe-pcnet.rom \
pxe-ne2k_pci.rom pxe-rtl8139.rom pxe-eepro100.rom pxe-virtio.rom}
%define x86_64_only_extra_built_firmware_list {efi-e1000.rom efi-e1000e.rom \
efi-eepro100.rom efi-pcnet.rom efi-ne2k_pci.rom efi-rtl8139.rom efi-virtio.rom \
efi-vmxnet3.rom}

%if %{build_x86_firmware_from_source}
%define x86_extra_built_firmware %{x86_extra_built_firmware_list}
%ifarch x86_64
%define x86_64_only_extra_built_firmware %{x86_64_only_extra_built_firmware_list}
%endif
%endif

%define built_firmware { \
%{?ppc_default_built_firmware} %{?ppc_extra_built_firmware} \
%{?ppc64_only_default_built_firmware} %{?ppc64_only_extra_built_firmware} \
%{?s390x_default_built_firmware} %{?s390x_extra_built_firmware} \
%{?x86_default_built_firmware} %{?x86_extra_built_firmware} \
%{?x86_64_only_default_built_firmware} %{?x86_64_only_extra_built_firmware} }

%description
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

%if "%{name}" != "qemu-testsuite"

%package x86
Summary:        Universal CPU emulator -- x86
Group:          System/Emulators/PC
Requires:       qemu = %version
Requires:       qemu-ipxe
Requires:       qemu-seabios
Requires:       qemu-sgabios
Requires:       qemu-vgabios

%description x86
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package provides i386 and x86_64 emulation.

%package ppc
Summary:        Universal CPU emulator -- Power Architecture
Group:          System/Emulators/PC
Requires:       qemu = %version
Recommends:     qemu-ipxe
Recommends:     qemu-vgabios

%description ppc
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package provides ppc and ppc64 emulation.

%package s390
Summary:        Universal CPU emulator -- S/390
Group:          System/Emulators/PC
Requires:       qemu = %version

%description s390
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package provides s390x emulation.

%package arm
Summary:        Universal CPU emulator -- ARM
Group:          System/Emulators/PC
Requires:       qemu = %version
Recommends:     qemu-ipxe
Recommends:     qemu-vgabios

%description arm
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package provides arm emulation.

%package extra
Summary:        Universal CPU emulator -- extra architectures
Group:          System/Emulators/PC
Requires:       qemu = %version
Recommends:     qemu-ipxe
Recommends:     qemu-vgabios

%description extra
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package provides some lesser used emulations, such as moxie and xtensa.

%if %{legacy_qemu_kvm}
%package kvm
Url:            https://www.qemu.org
Summary:        Kernel-based Virtual Machine
Group:          System/Emulators/PC
%ifarch %ix86 x86_64
Requires:       qemu-x86 = %version
%endif
%ifarch s390x
Requires:       qemu-s390 = %version
%endif
Provides:       kvm = %version
Obsoletes:      kvm < %version

%description kvm
KVM (Kernel-based Virtual Machine) is virtualization software for Linux.
It is designed to leverage the hardware virtualization features included
with various architectures. QEMU uses KVM for CPU virtualization, while
still providing emulation of other system components. This package is
not required for KVM usage, but rather facilitates its usage with tools
derived from the legacy kvm package.
%endif

%package lang
Summary:        Universal CPU emulator -- Translations
Group:          System/Emulators/PC

%description lang
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains translations.

# Modules need to match {qemu-system-*,qemu-img} version.
# We cannot have qemu and qemu-tools require them in the right version,
# as that would drag in the dependencies the modules are supposed to avoid.
# Nor can we have modules require the right version of qemu and qemu-tools
# as Xen reuses our qemu-tools but does not want our qemu and qemu-x86.
%define qemu_module_conflicts \
Conflicts:      qemu < %version-%release \
Conflicts:      qemu > %version-%release \
Conflicts:      qemu-tools < %version-%release \
Conflicts:      qemu-tools > %version-%release

%package block-curl
Summary:        Universal CPU emulator -- cURL block support
Group:          System/Emulators/PC
Provides:       qemu:%_libdir/%name/block-curl.so
%{qemu_module_conflicts}

%description block-curl
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains a module for accessing network-based image files
over a network connection from qemu-img tool and QEMU system emulation.

%package block-dmg
Summary:        Universal CPU emulator -- DMG block support
Group:          System/Emulators/PC
%{qemu_module_conflicts}

%description block-dmg
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains a module for accessing Mac OS X image files
from qemu-img tool and QEMU system emulation.

%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
%package block-gluster
Summary:        Universal CPU emulator -- GlusterFS block support
Group:          System/Emulators/PC
%{qemu_module_conflicts}

%description block-gluster
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains a module for accessing network-based image files
over a GlusterFS network connection from qemu-img tool and QEMU system emulation.
%endif

%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
%package block-iscsi
Summary:        Universal CPU emulator -- iSCSI block support
Group:          System/Emulators/PC
%{qemu_module_conflicts}

%description block-iscsi
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains a module for accessing network-based image files
over an iSCSI network connection from qemu-img tool and QEMU system emulation.
%endif

%if 0%{?with_rbd}
%package block-rbd
Summary:        Universal CPU emulator -- Ceph (rbd) block support
Group:          System/Emulators/PC
%{qemu_module_conflicts}

%description block-rbd
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains a module for accessing ceph (rbd,rados)
image files.
%endif

%if 0%{?suse_version} > 1140
%package block-ssh
Summary:        Universal CPU emulator -- SSH block support
Group:          System/Emulators/PC
%{qemu_module_conflicts}

%description block-ssh
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains a module for accessing network-based image files
over an SSH network connection from qemu-img tool and QEMU system emulation.
%endif

%package tools
Summary:        Universal CPU emulator -- Tools
Group:          System/Emulators/PC
Provides:       qemu:%_libexecdir/qemu-bridge-helper
Requires(pre):  permissions
Requires(pre):  shadow
Recommends:     qemu-block-curl
%if 0%{?with_rbd}
Recommends:     qemu-block-rbd
%endif

%description tools
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains various tools, including a bridge helper.

%package guest-agent
Summary:        Universal CPU emulator -- Guest agent
Group:          System/Emulators/PC
Provides:       qemu:%_bindir/qemu-ga
Requires(pre):  shadow
Requires(post): udev
%if 0%{?with_systemd}
%{?systemd_requires}
%endif

%description guest-agent
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub-package contains the guest agent.

%ifarch %ix86 x86_64
%package seabios
Summary:        X86 BIOS for QEMU
Group:          System/Emulators/PC
Version:        1.10.2
Release:        62.1
%if 0%{?suse_version} > %{noarch_supported}
BuildArch:      noarch
%endif
Conflicts:      qemu < 1.6.0

%description seabios
SeaBIOS is an open source implementation of a 16bit x86 BIOS. SeaBIOS
is the default BIOS for QEMU.

%package vgabios
Summary:        VGA BIOSes for QEMU
Group:          System/Emulators/PC
Version:        1.10.2
Release:        62.1
%if 0%{?suse_version} > %{noarch_supported}
BuildArch:      noarch
%endif
Conflicts:      qemu < 1.6.0

%description vgabios
VGABIOS provides the video ROM BIOSes for the following variants of VGA
emulated devices: Std VGA, QXL, Cirrus CLGD 5446 and VMware emulated
video card.

%package sgabios
Summary:        Serial Graphics Adapter BIOS for QEMU
Group:          System/Emulators/PC
Version:        8
Release:        62.1
%if 0%{?suse_version} > %{noarch_supported}
BuildArch:      noarch
%endif
Conflicts:      qemu < 1.6.0

%description sgabios
The Google Serial Graphics Adapter BIOS or SGABIOS provides a means for legacy
x86 software to communicate with an attached serial console as if a video card
were attached.

%package ipxe
Summary:        PXE ROMs for QEMU NICs
Group:          System/Emulators/PC
Version:        1.0.0+
Release:        62.1
%if 0%{?suse_version} > %{noarch_supported}
BuildArch:      noarch
%endif
Conflicts:      qemu < 1.6.0

%description ipxe
Preboot Execution Environment (PXE) ROM support for various emulated network
adapters available with QEMU.
%endif

%if 0%{?with_systemd} && 0%{?is_opensuse}
%package ksm
Summary:        Kernel Samepage Merging services
Group:          System/Emulators/PC
Requires(pre):  coreutils
Requires(post): coreutils

%description ksm
Kernel Samepage Merging (KSM) is a memory-saving de-duplication feature,
that merges anonymous (private) pages (not pagecache ones).

This package provides a service file for starting and stopping KSM.
%endif

%endif # !qemu-testsuite

%prep
%setup -q -n qemu-2.9.1
%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1
%patch0007 -p1
%patch0008 -p1
%patch0009 -p1
%patch0010 -p1
%patch0011 -p1
%patch0012 -p1
%patch0013 -p1
%patch0014 -p1
%patch0015 -p1
%patch0016 -p1
%patch0017 -p1
%patch0018 -p1
%patch0019 -p1
%patch0020 -p1
%patch0021 -p1
%patch0022 -p1
%patch0023 -p1
%patch0024 -p1
%patch0025 -p1
%patch0026 -p1
%patch0027 -p1
%patch0028 -p1
%patch0029 -p1
%patch0030 -p1
%patch0031 -p1
%patch0032 -p1
%patch0033 -p1
%patch0034 -p1
%patch0035 -p1
%patch0036 -p1
%patch0037 -p1
%patch0038 -p1
%patch0039 -p1
%patch0040 -p1
%patch0041 -p1
%patch0042 -p1
%patch0043 -p1
%patch0044 -p1
%patch0045 -p1
%patch0046 -p1
%patch0047 -p1
%patch0048 -p1
%patch0049 -p1
%patch0050 -p1
%patch0051 -p1
%patch0052 -p1
%patch0053 -p1
%patch0054 -p1
%patch0055 -p1
%patch0056 -p1
%patch0057 -p1
%patch0058 -p1
%patch0059 -p1
%patch0060 -p1
%patch0061 -p1
%patch0062 -p1
%patch0063 -p1
%patch0064 -p1
%patch0065 -p1
%patch0066 -p1
%patch0067 -p1
%patch0068 -p1
%patch0069 -p1
%patch0070 -p1
%patch0071 -p1
%patch0072 -p1
%patch0073 -p1
%patch0074 -p1
%patch0075 -p1
%patch0076 -p1
%patch0077 -p1
%patch0078 -p1
%patch0079 -p1
%patch0080 -p1
%patch0081 -p1
%patch0082 -p1
%patch0083 -p1
%patch0084 -p1
%patch0085 -p1
%patch0086 -p1
%patch0087 -p1
%patch0088 -p1
%patch0089 -p1
%patch0090 -p1
%patch0091 -p1
%patch0092 -p1
%patch0093 -p1
%patch0094 -p1
%patch0095 -p1
%patch0096 -p1
%patch0097 -p1
%patch0098 -p1
%patch0099 -p1
%patch0100 -p1
%patch0101 -p1
%patch0102 -p1
%patch0103 -p1
%patch0104 -p1
%patch0105 -p1
%patch0106 -p1
%patch0107 -p1
%patch0108 -p1
%patch0109 -p1
%patch0110 -p1
%patch0111 -p1
%patch0112 -p1
%patch0113 -p1
%patch0114 -p1
%patch0115 -p1
%patch0116 -p1
%patch0117 -p1
%patch0118 -p1
%patch0119 -p1
%patch0120 -p1
%patch0121 -p1
%patch0122 -p1
%patch0123 -p1
%patch0124 -p1
%patch0125 -p1
%patch0126 -p1
%patch0127 -p1
%patch0128 -p1
%patch0129 -p1
%patch0130 -p1
%patch0131 -p1
%patch0132 -p1
%patch0133 -p1
%patch0134 -p1
%patch0135 -p1
%patch0136 -p1
%patch0137 -p1
%patch0138 -p1
%patch0139 -p1
%patch0140 -p1
%patch0141 -p1
%patch0142 -p1
%patch0143 -p1
%patch0144 -p1
%patch0145 -p1
%patch0146 -p1
%patch0147 -p1
%patch0148 -p1
%patch0149 -p1
%patch0150 -p1
%patch0151 -p1
%patch0152 -p1
%patch0153 -p1
%patch0154 -p1
%patch0155 -p1
%patch0156 -p1
%patch0157 -p1
%patch0158 -p1
%patch0159 -p1
%patch0160 -p1
%patch0161 -p1
%patch0162 -p1
%patch0163 -p1
%patch0164 -p1
%patch0165 -p1
%patch0166 -p1

pushd roms/ipxe
%patch1100 -p1
%if 0%{?suse_version} <= 1320
%patch1101 -p1
%endif
%patch1102 -p1
%patch1103 -p1
%patch1104 -p1
%patch1105 -p1
popd

pushd roms/sgabios
%patch1200 -p1
popd

pushd roms/SLOF
popd

# as a safeguard, delete the firmware files that we intend to build
for i in %built_firmware
do
  unlink pc-bios/$i
done

%build
XC_COMPAT="
-DXC_WANT_COMPAT_DEVICEMODEL_API=1
-DXC_WANT_COMPAT_EVTCHN_API=1
-DXC_WANT_COMPAT_GNTTAB_API=1
-DXC_WANT_COMPAT_MAP_FOREIGN_API=1
"
XC_COMPAT="`echo ${XC_COMPAT} | xargs`"
sed -i~ /undef/d include/hw/xen/xen_common.h
diff -u include/hw/xen/xen_common.h~ include/hw/xen/xen_common.h || :
./configure \
	--prefix=%_prefix \
	--sysconfdir=%_sysconfdir \
	--libdir=%_libdir \
	--libexecdir=%_libexecdir \
	--localstatedir=%_localstatedir \
	--docdir=%_docdir/qemu \
	--extra-cflags="%{optflags} ${XC_COMPAT}" \
	--disable-stack-protector \
	--disable-strip \
	--with-pkgversion="%(echo '%{distro}' | sed 's/ (.*)//')" \
	--enable-system --disable-linux-user \
	--enable-tools --enable-guest-agent \
	--enable-modules \
	--enable-pie \
	--enable-docs \
	--audio-drv-list="pa alsa sdl oss" \
	--enable-attr \
	--enable-bluez \
%if 0%{?suse_version} >= 1130
	--enable-brlapi \
%else
	--disable-brlapi \
%endif
	--enable-bzip2 \
	--enable-cap-ng \
	--enable-coroutine-pool \
	--enable-curl \
	--enable-curses \
	--enable-fdt \
%if 0
# Let it auto-detect these based on gnutls - uses libnettle in Tumbleweed but unavailable in SLE11
	--enable-gcrypt \
	--disable-nettle \
%endif
%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
	--enable-glusterfs \
%else
	--disable-glusterfs \
%endif
	--enable-gnutls \
	--enable-gtk \
%if 0%{?suse_version} >= 1220
	--with-gtkabi=3.0 \
%else
	--with-gtkabi=2.0 \
%endif
	--disable-hax \
	--disable-jemalloc \
%if %{kvm_available}
	--enable-kvm \
%else
	--disable-kvm \
%endif
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
	--enable-libiscsi \
%else
	--disable-libiscsi \
%endif
	--disable-libnfs \
%if 0%{?suse_version} > 1140
	--enable-libssh2 \
%else
	--disable-libssh2 \
%endif
%if 0%{?suse_version} > 1310
	--enable-libusb \
%else
	--disable-libusb \
%endif
	--enable-linux-aio \
	--enable-lzo \
	--disable-netmap \
%ifarch %ix86 x86_64
%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
	--enable-numa \
%else
	--disable-numa \
%endif
%else
%ifarch aarch64
%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
	--enable-numa \
%endif
%else
	--disable-numa \
%endif
%else
%ifarch %arm s390x
	--disable-numa \
%else
	--enable-numa \
%endif
%endif
%if 0%{?suse_version} >= 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
	--enable-opengl \
%endif
	--with-system-pixman \
%if 0%{?with_rbd}
	--enable-rbd \
%else
	--disable-rbd \
%endif
%if 0%{?suse_version} >= 1315
	--enable-rdma \
%else
	--disable-rdma \
%endif
	--enable-replication \
	--enable-sdl \
%if 0%{?suse_version} >= 1320
	--with-sdlabi=2.0 \
%else
	--with-sdlabi=1.2 \
%endif
%if 0%{?with_seccomp}
	--enable-seccomp \
%else
	--disable-seccomp \
%endif
%if 0%{?is_opensuse}
	--enable-smartcard \
%else
	--disable-smartcard \
%endif
%if 0%{?suse_version} >= 1310
	--enable-snappy \
%else
	--disable-snappy \
%endif
%if 0%{?with_spice}
	--enable-spice \
%else
	--disable-spice \
%endif
	--disable-tcmalloc \
	--enable-tpm \
	--enable-usb-redir \
	--enable-vde \
	--enable-vhost-net \
%if 0%{?suse_version} >= 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
	--enable-virglrenderer \
%endif
	--enable-virtfs \
	--enable-vnc \
	--enable-vnc-jpeg \
	--enable-vnc-png \
	--enable-vnc-sasl \
%if 0%{?suse_version} == 1320
	--disable-vte \
%else
	--enable-vte \
%endif
%ifarch x86_64
	--enable-xen \
	--enable-xen-pci-passthrough \
	--enable-xen-pv-domain-build \
%else
	--disable-xen \
%endif
	--enable-xfsctl \

%if "%{name}" != "qemu-testsuite"

make %{?_smp_mflags} V=1

# Firmware

%ifarch s390x
for i in %s390x_default_built_firmware
do
  cp pc-bios/s390-ccw/$i pc-bios/
done
%endif

%ifarch ppc64
for i in %ppc64_only_default_built_firmware
do
  cp pc-bios/spapr-rtas/$i pc-bios/
done
%endif

%ifarch %ix86 x86_64
for i in %x86_default_built_firmware
do
  cp pc-bios/optionrom/$i pc-bios/
done
%ifarch x86_64
for i in %x86_64_only_default_built_firmware
do
  cp pc-bios/optionrom/$i pc-bios/
done
%endif
%endif

%if %{build_x86_firmware_from_source}
make %{?_smp_mflags} -C roms bios

make %{?_smp_mflags} -C roms seavgabios
make %{?_smp_mflags} -C roms pxerom
%ifarch x86_64
make %{?_smp_mflags} -C roms efirom
%endif
make                 -C roms sgabios
# enforce pxe rom sizes for migration compatability from SLE 11 SP3 forward
# the following need to be > 64K
%define supported_nics_large {e1000 rtl8139}
# the following need to be <= 64K
%define supported_nics_small {virtio}
# Though not required, make unsupported pxe roms migration compatable as well
%define unsupported_nics {eepro100 ne2k_pci pcnet}

for i in %supported_nics_large %unsupported_nics
  do
    if test "`stat -c '%s' pc-bios/pxe-$i.rom`" -gt "131072" ; then
    echo "pxe rom is too large"
    exit 1
  fi
  if test "`stat -c '%s' pc-bios/pxe-$i.rom`" -le "65536" ; then
    ./roms/ipxe/src/util/padimg.pl pc-bios/pxe-$i.rom -s 65536 -b 255
    echo -ne "SEGMENT OVERAGE\0" >> pc-bios/pxe-$i.rom
  fi
done
for i in %supported_nics_small
  do
    if test "`stat -c '%s' pc-bios/pxe-$i.rom`" -gt "65536" ; then
    echo "pxe rom is too large"
    exit 1
  fi
done
%endif

%if %{build_slof_from_source}
make %{?_smp_mflags} -C roms slof
%endif

%else # qemu-testsuite

ln -s %{_bindir}/qemu-img qemu-img
ln -s %{_bindir}/qemu-ga qemu-ga
ln -s %{_bindir}/qemu-io qemu-io

for i in %built_firmware
do
  ln -s %{_datadir}/qemu/$i pc-bios/$i
done

for conf in default-configs/*-softmmu.mak; do
  arch=`echo "$conf" | sed -e 's|default-configs/\(.*\)-softmmu.mak|\1|g'`
  ln -s %{_bindir}/qemu-system-$arch $arch-softmmu/qemu-system-$arch
done

# Compile the QOM test binary first, so that ...

touch -r config-host.mak pc-bios
make tests/qom-test %{?_smp_mflags} V=1
# Firmware
# ... make comes in fresh and has lots of address space (needed for 32bit, bsc#957379)
%if 0%{?suse_version} >= 1310
make check-report.html V=1
%else
make check-report.xml V=1
%endif

%endif

%check
%if "%{name}" == "qemu-testsuite"

%ifnarch %ix86 x64_64
export QEMU_PROG=%{_bindir}/qemu-system-x86_64
%endif
export QEMU_IMG_PROG=%{_bindir}/qemu-img
export QEMU_IO_PROG=%{_bindir}/qemu-io
export QEMU_NBD_PROG=%{_bindir}/qemu-nbd
# make check-block would rebuild qemu-img and qemu-io
make tests/qemu-iotests/socket_scm_helper V=1
pushd tests/qemu-iotests
# -qcow 001 seems to hang?
# TODO investigate hangs and failures
#for fmt in -raw -bochs -cloop -parallels -qcow2 -qed -vdi -vpc -vhdx -vmdk; do
#  ./check -v -T $fmt -file -g quick || true
#done
popd

# Create minimal gzip format file
echo "Test" > test.txt
cat test.txt | gzip - > test.gz
# Check qemu-img info output (bsc#945778)
format=`qemu-img info test.gz | grep "file format:" | cut -d ':' -f 2 | tr -d '[:space:]'`
[ "$format" == "raw" ] || false

# Create minimal tar format file
tar cf test.tar test.txt
# Check qemu-img info output (bsc#945778)
format=`qemu-img info test.tar | grep "file format:" | cut -d ':' -f 2 | tr -d '[:space:]'`
[ "$format" == "raw" ] || false

%endif # qemu-testsuite

%install
%if "%{name}" != "qemu-testsuite"

touch -r config-host.mak pc-bios
make install DESTDIR=%{buildroot}
%ifnarch %ix86 x86_64
for f in acpi-dsdt.aml %{x86_extra_built_firmware_list} \
         %{x86_64_only_extra_built_firmware_list}; do
  unlink %{buildroot}%{_datadir}/%name/$f
done
%endif
%find_lang %name
install -D -m 644 %{SOURCE302} %{buildroot}%{_sysconfdir}/qemu/bridge.conf
install -D -m 755 %{SOURCE2} %{buildroot}/usr/share/qemu/qemu-ifup
install -D -p -m 0644 %{SOURCE8} %{buildroot}%{_udevrulesdir}/80-qemu-ga.rules
%if 0%{?is_opensuse} == 0
install -D -m 0644 %{SOURCE12} %{buildroot}%{_docdir}/qemu-x86/supported.txt
install -D -m 0644 %{SOURCE13} %{buildroot}%{_docdir}/qemu-s390/supported.txt
install -D -m 0644 %{SOURCE14} %{buildroot}%{_docdir}/qemu-arm/supported.txt
install -D -m 0644 %{SOURCE15} %{buildroot}%{_docdir}/qemu-ppc/supported.txt
%endif
%if %{legacy_qemu_kvm}
cat > %{buildroot}%{_bindir}/qemu-kvm << 'EOF'
#!/bin/sh

%ifarch s390x
exec %{_bindir}/qemu-system-s390x -machine accel=kvm "$@"
%else
exec %{_bindir}/qemu-system-x86_64 -machine accel=kvm "$@"
%endif
EOF
chmod 755 %{buildroot}%{_bindir}/qemu-kvm
install -D -m 644 %{SOURCE4} %{buildroot}%{_mandir}/man1/qemu-kvm.1.gz
%ifarch s390x
mkdir -p %{buildroot}%{_sysconfdir}/sysctl.d
cat >  %{buildroot}%{_sysconfdir}/sysctl.d/50-allow-kvm-on-s390x.conf <<- 'EOF'
	# To allow KVM to run on s390x, we need to set the sysctl below
	vm.allocate_pgste = 1
EOF
chmod 644 %{buildroot}%{_sysconfdir}/sysctl.d/50-allow-kvm-on-s390x.conf
%if 0%{?is_opensuse} == 0
install -d %{buildroot}%{_docdir}/qemu-kvm
ln -s ../qemu-s390/supported.txt %{buildroot}%{_docdir}/qemu-kvm/kvm-supported.txt
%endif
%else
%if 0%{?is_opensuse} == 0
install -d %{buildroot}%{_docdir}/qemu-kvm
ln -s ../qemu-x86/supported.txt %{buildroot}%{_docdir}/qemu-kvm/kvm-supported.txt
%endif
%endif
%endif
%if %{kvm_available}
%if 0%{?suse_version} <= 1320
install -D -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kvm_stat
install -D -m 644 %{SOURCE11} %{buildroot}%{_mandir}/man1/kvm_stat.1.gz
%endif
%if 0%{?suse_version} >= 1230
install -D -m 644 %{SOURCE1} %{buildroot}%{_udevrulesdir}/80-kvm.rules
%else
%ifarch %ix86 x86_64
install -D -m 644 %{SOURCE7} %{buildroot}%{_udevrulesdir}/60-kvm.rules
%else
install -D -m 644 %{SOURCE5} %{buildroot}%{_udevrulesdir}/60-kvm.rules
%endif
%endif
%endif
%if 0%{?with_systemd}
install -D -p -m 0644 %{SOURCE9} %{buildroot}%{_unitdir}/qemu-ga.service
%if 0%{?is_opensuse}
install -D -p -m 0644 %{SOURCE6} %{buildroot}%{_unitdir}/ksm.service
%endif
%ifarch s390x
install -D -m 0644 %{SOURCE10} %{buildroot}%{_libexecdir}/modules-load.d/kvm.conf
%endif
%endif
%fdupes -s %{buildroot}

%else # qemu-testsuite

%if 0%{?suse_version} >= 1310
install -D -m 644 check-report.html %{buildroot}%{_datadir}/qemu/check-report.html
%endif
install -D -m 644 check-report.xml %{buildroot}%{_datadir}/qemu/check-report.xml

%endif

%if "%{name}" != "qemu-testsuite"

%pre
%{_bindir}/getent group kvm >/dev/null || %{_sbindir}/groupadd -r kvm 2>/dev/null
%{_bindir}/getent group qemu >/dev/null || %{_sbindir}/groupadd -r qemu 2>/dev/null
%{_bindir}/getent passwd qemu >/dev/null || \
  %{_sbindir}/useradd -r -g qemu -G kvm -d / -s /sbin/nologin \
  -c "qemu user" qemu

%if %{kvm_available}
%post
# Do not execute operations affecting host devices while running in a chroot
if [ $(stat -L -c "%i" /proc/1/root/) = $(stat -L -c "%i" /) ]; then
  setfacl --remove-all /dev/kvm &> /dev/null || :
%if 0%{?with_systemd}
%ifarch s390x
  if [ -c /dev/kvm ]; then
    %{_bindir}/chmod 666 /dev/kvm
    %{_bindir}/chgrp kvm /dev/kvm
  fi
%endif
  %udev_rules_update
  %_bindir/udevadm trigger -y kvm || :
%else
  /sbin/udevadm control --reload-rules  || :
  /sbin/udevadm trigger -y kvm || :
%endif
%ifarch s390x
  sysctl vm.allocate_pgste=1 || :
%endif
fi
%endif

%if 0%{?suse_version} >= 1130
%pre tools
%{_bindir}/getent group kvm >/dev/null || %{_sbindir}/groupadd -r kvm 2>/dev/null
%post tools
%set_permissions %_libexecdir/qemu-bridge-helper

%verifyscript tools
%verify_permissions %_libexecdir/qemu-bridge-helper
%endif

%pre guest-agent
%{_bindir}/getent group kvm >/dev/null || %{_sbindir}/groupadd -r kvm 2>/dev/null
%if 0%{?with_systemd}
%service_add_pre qemu-ga.service

%preun guest-agent
%service_del_preun qemu-ga.service

%post guest-agent
%service_add_post qemu-ga.service
if [ -e /dev/virtio-ports/org.qemu.guest_agent.0 ]; then
  /usr/bin/systemctl start qemu-ga.service || :
fi

%postun guest-agent
%service_del_postun qemu-ga.service

%if 0%{?is_opensuse}
%pre ksm
%service_add_pre ksm.service

%post ksm
%service_add_post ksm.service

%preun ksm
%service_del_preun ksm.service

%postun ksm
%service_del_postun ksm.service
%endif
%endif

%endif # !qemu-testsuite

%files
%defattr(-, root, root)
%if "%{name}" != "qemu-testsuite"
%doc Changelog README VERSION
%license COPYING COPYING.LIB
%_docdir/%name/qemu-doc.txt
%_docdir/%name/qemu-doc.html
%_docdir/%name/qemu-qmp-ref.txt
%_docdir/%name/qemu-qmp-ref.html
%_docdir/%name/qemu-ga-ref.txt
%_docdir/%name/qemu-ga-ref.html
%_mandir/man1/qemu.1.gz
%_mandir/man7/qemu-qmp-ref.7.gz
%_mandir/man7/qemu-ga-ref.7.gz
%dir %_datadir/%name
%_datadir/%name/keymaps
%_datadir/%name/trace-events-all
%_datadir/%name/qemu-icon.bmp
%_datadir/%name/qemu_logo_no_text.svg
%dir %_sysconfdir/%name
%_datadir/%name/qemu-ifup
%if %{kvm_available}
%if 0%{?suse_version} <= 1320
%_bindir/kvm_stat
%doc %_mandir/man1/kvm_stat.1.gz
%endif
%if 0%{?suse_version} >= 1230
%{_udevrulesdir}/80-kvm.rules
%else
%{_udevrulesdir}/60-kvm.rules
%endif
%ifarch s390x
%{_sysconfdir}/sysctl.d/50-allow-kvm-on-s390x.conf
%if 0%{?with_systemd}
%_libexecdir/modules-load.d/kvm.conf
%endif
%endif
%endif

%files x86
%defattr(-, root, root)
%_bindir/qemu-system-i386
%_bindir/qemu-system-x86_64
%_datadir/%name/kvmvapic.bin
%_datadir/%name/linuxboot.bin
%_datadir/%name/linuxboot_dma.bin
%_datadir/%name/multiboot.bin
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-x86
%_docdir/qemu-x86/supported.txt
%endif

%files ppc
%defattr(-, root, root)
%_bindir/qemu-system-ppc
%_bindir/qemu-system-ppc64
%_bindir/qemu-system-ppcemb
%_datadir/%name/ppc_rom.bin
%_datadir/%name/openbios-ppc
%_datadir/%name/slof.bin
%_datadir/%name/spapr-rtas.bin
%_datadir/%name/u-boot.e500
%_datadir/%name/bamboo.dtb
%_datadir/%name/petalogix-ml605.dtb
%_datadir/%name/skiboot.lid
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-ppc
%_docdir/qemu-ppc/supported.txt
%endif

%files s390
%defattr(-, root, root)
%_bindir/qemu-system-s390x
%_datadir/%name/s390-ccw.img
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-s390
%_docdir/qemu-s390/supported.txt
%endif

%files arm
%defattr(-, root, root)
%_bindir/qemu-system-arm
%_bindir/qemu-system-aarch64
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-arm
%_docdir/qemu-arm/supported.txt
%endif

%files extra
%defattr(-, root, root)
%_bindir/qemu-system-alpha
%_bindir/qemu-system-cris
%_bindir/qemu-system-lm32
%_bindir/qemu-system-m68k
%_bindir/qemu-system-microblaze
%_bindir/qemu-system-microblazeel
%_bindir/qemu-system-mips
%_bindir/qemu-system-mipsel
%_bindir/qemu-system-mips64
%_bindir/qemu-system-mips64el
%_bindir/qemu-system-moxie
%_bindir/qemu-system-nios2
%_bindir/qemu-system-or1k
%_bindir/qemu-system-sh4
%_bindir/qemu-system-sh4eb
%_bindir/qemu-system-sparc
%_bindir/qemu-system-sparc64
%_bindir/qemu-system-tricore
%_bindir/qemu-system-unicore32
%_bindir/qemu-system-xtensa
%_bindir/qemu-system-xtensaeb
%_datadir/%name/palcode-clipper
%_datadir/%name/openbios-sparc32
%_datadir/%name/openbios-sparc64
%_datadir/%name/petalogix-s3adsp1800.dtb
%_datadir/%name/QEMU,cgthree.bin
%_datadir/%name/QEMU,tcx.bin

%if %{legacy_qemu_kvm}
%files kvm
%defattr(-,root,root)
%_bindir/qemu-kvm
%_mandir/man1/qemu-kvm.1.gz
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-kvm
%_docdir/qemu-kvm/kvm-supported.txt
%endif
%endif

%files block-curl
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-curl.so

%files block-dmg
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-dmg-bz2.so

%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
%files block-gluster
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-gluster.so
%endif

%if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
%files block-iscsi
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-iscsi.so
%endif

%if 0%{?with_rbd}
%files block-rbd
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-rbd.so
%endif

%if 0%{?suse_version} > 1140
%files block-ssh
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-ssh.so
%endif

%files lang -f %name.lang
%defattr(-, root, root)

%ifarch %ix86 x86_64
%files seabios
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/bios.bin
%_datadir/%name/bios-256k.bin
%_datadir/%name/acpi-dsdt.aml

%files vgabios
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/vgabios.bin
%_datadir/%name/vgabios-cirrus.bin
%_datadir/%name/vgabios-qxl.bin
%_datadir/%name/vgabios-stdvga.bin
%_datadir/%name/vgabios-virtio.bin
%_datadir/%name/vgabios-vmware.bin

%files sgabios
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/sgabios.bin

%files ipxe
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/pxe-e1000.rom
%_datadir/%name/pxe-eepro100.rom
%_datadir/%name/pxe-pcnet.rom
%_datadir/%name/pxe-ne2k_pci.rom
%_datadir/%name/pxe-rtl8139.rom
%_datadir/%name/pxe-virtio.rom
%_datadir/%name/efi-e1000.rom
%_datadir/%name/efi-e1000e.rom
%_datadir/%name/efi-eepro100.rom
%_datadir/%name/efi-pcnet.rom
%_datadir/%name/efi-ne2k_pci.rom
%_datadir/%name/efi-rtl8139.rom
%_datadir/%name/efi-virtio.rom
%_datadir/%name/efi-vmxnet3.rom
%endif

%files tools
%defattr(-, root, root)
%_mandir/man1/qemu-img.1.gz
%_mandir/man1/virtfs-proxy-helper.1.gz
%_mandir/man8/qemu-nbd.8.gz
%_bindir/ivshmem-client
%_bindir/ivshmem-server
%_bindir/qemu-io
%_bindir/qemu-img
%_bindir/qemu-nbd
%_bindir/virtfs-proxy-helper
#%_bindir/vscclient
%verify(not mode) %attr(4750,root,kvm) %_libexecdir/qemu-bridge-helper
%dir %_sysconfdir/%name
%config %_sysconfdir/%name/bridge.conf

%files guest-agent
%defattr(-, root, root)
%_mandir/man8/qemu-ga.8.gz
%attr(755,root,kvm) %_bindir/qemu-ga
%if 0%{?with_systemd}
%{_unitdir}/qemu-ga.service
%endif
%{_udevrulesdir}/80-qemu-ga.rules

%if 0%{?with_systemd} && 0%{?is_opensuse}
%files ksm
%defattr(-, root, root)
%{_unitdir}/ksm.service
%endif

%else # qemu-testsuite
%_datadir/qemu/check-report.xml
%if 0%{?suse_version} >= 1310
%_datadir/qemu/check-report.html
%endif
%endif

%changelog
* Fri May  3 2019 Bruce Rogers <brogers@suse.com>
- Add x86 cpu feature "md-clear" (CVE-2018-12126 CVE-2018-12127
  CVE-2018-12130 CVE-2019-11091 bsc#1111331)
  0166-target-i386-define-md-clear-bit.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Tue Apr  2 2019 lma@suse.com
- Fix information leak in slirp (CVE-2019-9824 bsc#1129622)
  0161-slirp-check-sscanf-result-when-emul.patch
- Add method to specify whether or not to expose certain ppc64 host
  information, which can be considered a security issue
  (CVE-2019-8934 bsc#1126455)
  0162-ppc-add-host-serial-and-host-model-.patch
- Fix OOB memory access and information leak in virtual monitor
  interface (CVE-2019-03812 bsc#1125721)
  0163-i2c-ddc-fix-oob-read.patch
- Fix DOS possibility in device tree processing (CVE-2018-20815
  bsc#1130675)
  0164-device_tree.c-Don-t-use-load_image.patch
- Adjust fix for CVE-2019-8934 (bsc#1126455) to match the latest
  upstream adjustments for the same. Basically now the security fix
  is to provide a dummy host-model and host-serial value, which
  overrides getting that value from the host
  0165-spapr-Simplify-handling-of-host-ser.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Fri Mar 29 2019 Bruce Rogers <brogers@suse.com>
- Add ability to set virtqueue size using virtqueue_size parameter.
  Using a smaller size allows for more disks. This feature request
  was for SLE12-SP2, but we want to be able to forward migrate
  VM's which use this parameter, so adding to SLE12-SP3 as well
  (FATE#327255)
  0160-virtio-scsi-Add-virtqueue_size-para.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Thu Mar 28 2019 Bruce Rogers <brogers@suse.com>
- Backport Skylake-Server vcpu model support from qemu v2.11
  We don't include post v2.11 additional feature tweaks so that we
  can easily forward migrate to our v2.11 based qemu in more recent
  SLE versions (FATE#327261 bsc#1131955)
  0158-i386-add-Skylake-Server-cpu-model.patch
  0159-i386-Add-new-IBRS-versions-of-Intel.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Wed Jan 30 2019 Bruce Rogers <brogers@suse.com>
- Address OOB and DoS vulnerabilities in vga subsystem
  0145-bitmap-add-bitmap_copy_and_clear_at.patch
  0146-memory-add-support-getting-and-usin.patch
  0147-vga-add-vga_scanline_invalidated-he.patch
  0148-vga-make-display-updates-thread-saf.patch
  0149-vga-fix-display-update-region-calcu.patch
  0150-vga-use-DIV_ROUND_UP.patch
  (CVE-2017-13673)
  0151-vga-fix-display-update-region-calcu.patch
  0152-vga-drop-line_offset-variable.patch
  (CVE-2017-13672 - follow on fix)
  0153-vga-handle-cirrus-vbe-mode-wraparou.patch
  0154-vga-add-ram_addr_t-cast.patch
  0155-vga-fix-region-checks-in-wraparound.patch
  (CVE-2018-7858 bsc#1084604)
  0156-vga-fix-region-calculation.patch
  0157-vga-catch-depth-0.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Tue Jan 29 2019 Bruce Rogers <brogers@suse.com>
- Fix bad guest time after migration (bsc#1113231)
  0137-kvmclock-update-system_time_msr-add.patch
  0138-kvmclock-use-the-updated-system_tim.patch
- Address various security/stability issues
  * Fix OOB access in slirp (CVE-2019-6778 bsc#1123156)
  0139-slirp-check-data-length-while-emula.patch
  * Fix host security vulnerability related to handling symlinks in
  usb-mtp (CVE-2018-16872 bsc#1119493)
  0140-usb-mtp-use-O_NOFOLLOW-and-O_CLOEXE.patch
  * Fix DoS in virtfs (CVE-2018-19489 bsc#1117275)
  0141-9p-fix-QEMU-crash-when-renaming-fil.patch
  * Fix OOB issue (use-after-free) if virtfs interface is
  deliberately abused (CVE-2018-19364 bsc#1116717)
  0142-9p-write-lock-path-in-v9fs_co_open2.patch
  0143-9p-take-write-lock-on-fid-path-upda.patch
  * Fix OOB access performing PowerNV memory operations
  (CVE-2018-18954 bsc#1114957)
  0144-ppc-pnv-check-size-before-data-buff.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Tue Jan 15 2019 Liang Yan <lyan@suse.com>
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
  * Patches added:
  0135-linux-user-write-fd-NULL-0-parity-w.patch
  0136-linux-user-make-pwrite64-pread64-fd.patch
  (bsc#1121600)
* Thu Dec 13 2018 lma@suse.com
- Use /bin/bash to echo value into sys fs for ksm control (bsc#1112646)
* Wed Dec 12 2018 ohering@suse.de
- fix memory leak in xen_disk (bsc#1100408)
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
  * Patches added:
  0134-xen_disk-Avoid-repeated-memory-allo.patch
* Wed Dec 12 2018 olaf@aepfle.de
- building against xen-devel requires the XC_* compat macros to be
  set because this version of QEMU will be built against many
  versions of Xen. configure will decide on the appropriate function
  names it knows about today. To actually call these functions,
  future versions of Xen may require XC_* to be set.
  Furthermore, fix a bug in QEMU: xen_common.h undefines the XC_*
  macros unconditionally. (bsc#1100408)
* Fri Nov 16 2018 Liang Yan <lyan@suse.com>
- Fix a condition when retry logic does not execute in case of data
  transmit failure or connection hungup (bsc#1108474)
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
  * Patches added:
  0132-hw-char-serial-Only-retry-if-qemu_c.patch
  0133-hw-char-serial-retry-write-if-EAGAI.patch
* Mon Nov  5 2018 Bruce Rogers <brogers@suse.com>
- Address the following security vulnerability:
  * Avoid OOB access in restoring lsi53c895a emulated SCSI controller
  state (CVE-2018-18849 bsc#1114422)
  0131-lsi53c895a-check-message-length-val.patch
- Tweak spec file url's to match today's reality
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Mon Oct 29 2018 Larry Dewey <ldewey@suse.com>
  * Pulling upstream security fixes for NE2000, RTL8139, pcnet, and packet size
  changes (CVE-2018-10839 CVE-2018-17958 CVE-2018-17962 CVE-2018-17963
  bsc#1110910 bsc#1111006 bsc#1111010 bsc#1111013)
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
  * Patches added:
  0127-ne2000-fix-possible-out-of-bound-ac.patch
  0128-rtl8139-fix-possible-out-of-bound-a.patch
  0129-pcnet-fix-possible-buffer-overflow.patch
  0130-net-ignore-packet-size-greater-than.patch
* Wed Oct 10 2018 Larry Dewey <ldewey@suse.com>
  * Improving disk performance for qemu on xen (bsc#1100408)
- Important notes about the following patches:
  0114* - Combined changes from 8f25e7544 were included
    for convenience and simplification
  0120* - Modification made as the Xen interface versioning was changed
  0123* - Removed xen_9p* file as it does not exist
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
  * Patches added:
  0112-xen-rename-xen_modified_memory-to-x.patch
  0113-xen-make-use-of-xen_xc-implicit-in-.patch
  0114-xen-use-libxendevicemodel-when-avai.patch
  0115-xen-disk-only-advertize-feature-per.patch
  0116-xen-disk-add-support-for-multi-page.patch
  0117-xen-disk-use-g_new0-to-fix-build.patch
  0118-xen-add-a-global-indicator-for-gran.patch
  0119-xen-dont-try-setting-max-grants-mul.patch
  0120-xen-add-a-meaningful-declaration-of.patch
  0121-xen_backend-add-grant-table-helpers.patch
  0122-xen_disk-remove-open-coded-use-of-l.patch
  0123-xen-remove-other-open-coded-use-of-.patch
  0124-xen_backend-add-an-emulation-of-gra.patch
  0125-xen_disk-remove-use-of-grant-map-un.patch
  0126-xen_disk-use-a-single-entry-iovec.patch
* Fri Oct  5 2018 Bruce Rogers <brogers@suse.com>
- Change spec file http references to https
* Thu Oct  4 2018 Larry Dewey <ldewey@suse.com>
- Adding patches to mitigate seccomp vulnerability
  (bsc#1106222 CVE-2018-15746)
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
  * Patches added:
  0101-seccomp-changing-from-whitelist-to-.patch
  0102-seccomp-add-obsolete-argument-to-co.patch
  0103-seccomp-add-elevateprivileges-argum.patch
  0104-seccomp-add-spawn-argument-to-comma.patch
  0105-seccomp-add-resourcecontrol-argumen.patch
  0106-seccomp-allow-sched_setscheduler-wi.patch
  0107-seccomp-prefer-SCMP_ACT_KILL_PROCES.patch
  0108-configure-require-libseccomp-2.2.0.patch
  0109-seccomp-set-the-seccomp-filter-to-a.patch
  0110-sandbox-disable-sandbox-if-CONFIG_S.patch
  0111-seccomp-check-TSYNC-host-capability.patch
* Fri Sep 21 2018 Bruce Rogers <brogers@suse.com>
- Correct some versioning as follows:
  * Accurately reflect the qemu-ipxe package version value by adding
  "+" at the end
  * Don't overwrite seabios .version file, since now (for quite some
  time actually) upstream tarball creation creates this file and
  the value we are writing to it is actually wrong
* Wed Aug  8 2018 brogers@suse.com
- Update to upstream Spectre v4 vulnerability mitigation support,
  which includes exchanging our early patch with the upstream
  version (basically the same) and adding AMD related support.
  (CVE-2018-3639 bsc#1092885)
  * Patches renamed:
  0094-i386-Add-bit-2-of-SPEC_CTRL-MSR-sup.patch
  - > 0094-i386-define-the-ssbd-CPUID-feature-.patch
  * Patches added:
  0099-i386-Define-the-Virt-SSBD-MSR-and-h.patch
  0100-i386-define-the-AMD-virt-ssbd-CPUID.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Tue Jul 31 2018 fli@suse.com
- Fix integer overflow while allocating a large memory chunk in
  qemu-ga: qmp_guest_file_read (CVE-2018-12617 bsc#1098735)
  0098-qga-check-bytes-count-read-by-guest.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Fri Jun 22 2018 fli@suse.com
- Fix heap buffer overflow while reassembling fragmented datagrams
  in Slirp networking (CVE-2018-11806 bsc#1096223)
  0097-slirp-correct-size-computation-whil.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Thu Jun  7 2018 brogers@suse.com
- Tweak patch file generation to be more git version agnostic.
  Also change update_git.sh to not reformat spec file by default.
* Fri May 25 2018 brogers@suse.com
- Add support for block resize support for xen disks through the
  monitor. (fate#325467)
  0096-xen-add-block-resize-support-for-xe.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Mon May 14 2018 brogers@suse.com
- Spectre v4 vulnerability mitigation support for KVM guests.
  High level description of vulnerability: Systems with microprocessors
  utilizing speculative execution and speculative execution of memory
  reads before the addresses of all prior memory writes are known may
  allow unauthorized disclosure of information to an attacker with
  local user access via a side-channel analysis.
  This patch permits the new x86 cpu feature flag named "ssbd" to be
  presented to the guest, given that the host has this feature, and
  KVM exposes it to the guest as well. As this change also relies on
  the same MSR infrastructure used for the "spec-ctrl" feature now is
  a good time to remove the temporary patch used to help ensure a
  smooth transition to spec-ctrl support regardless of KVM support.
  For this feature to be enabled, via adding it to the qemu commandline
  (eg: -cpu <model>,+spec-ctrl,+ssbd), so the guest OS can take advantage
  of the feature, spec-ctrl and ssbd support is also required in the host.
  (CVE-2018-3639 bsc#1092885)
  * Patches dropped:
  0094-i386-Compensate-for-KVM-SPEC_CTRL-f.patch
  * Patches added:
  0094-i386-Add-bit-2-of-SPEC_CTRL-MSR-sup.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Wed Apr  4 2018 lyan@suse.com
- Add new look up path "sys/class/tpm" for tpm cancel path based
  on Linux 4.0 change (commit 313d21eeab9282e)(bsc#1070615)
  0095-tpm-lookup-cancel-path-under-tpm-de.patch
* Fri Mar  9 2018 brogers@suse.com
- This update has the next round of Spectre v2 related patches,
  which now integrates with corresponding changes in libvirt. A
  January 2018 release of qemu initially addressed the Spectre v2
  vulnerability for KVM guests by exposing the spec-ctrl feature
  for all x86 vcpu types, which was the quick and dirty approach,
  but not the proper solution. We remove that initial patch and now
  rely on patches from upstream. This update defines spec_ctrl and
  ibpb cpu feature flags as well as new cpu models which are clones
  of existing models with either -IBRS or -IBPB added to the end of
  the model name. These new vcpu models explicitly include the new
  feature(s), whereas the feature flags can be added to the cpu
  parameter as with other features. In short, for continued Spectre
  v2 protection, ensure that either the appropriate cpu feature
  flag is added to the QEMU command-line, or one of the new cpu
  models is used. Although migration from older versions is
  supported, the new cpu features won't be properly exposed to the
  guest until it is restarted with the cpu features explicitly
  added. A reboot is insufficient.
- A warning patch is added which attempts to detect a migration
  from a qemu version which had the quick and dirty fix (it only
  detects certain cases, but hopefully is helpful.)
  For additional information on Spectre v2 as it relates to QEMU,
  see: https://www.qemu.org/2018/02/14/qemu-2-11-1-and-spectre-update/
  (CVE-2017-5715 bsc#1068032)
- A patch is added to continue to detect Spectre v2 mitigation
  features (as shown by cpuid), and if found provide that feature
  to guests, even if running on older KVM (kernel) versions which
  do not yet expose that feature to QEMU. (bsc#1082276)
  These two patches will be removed when we can reasonably assume
  everyone is running with the appropriate updates.
  * Patches dropped:
  0065-i386-kvm-MSR_IA32_SPEC_CTRL-and-MSR.patch
  * Patches added:
  0065-i386-Add-support-for-SPEC_CTRL-MSR.patch
  0088-x86-cpu-increase-model_id-array-siz.patch
  0089-i386-Add-spec-ctrl-CPUID-bit.patch
  0090-i386-Add-FEAT_8000_0008_EBX-CPUID-f.patch
  0091-i386-Add-new-IBRS-versions-of-Intel.patch
  0092-i386-Add-EPYC-IBPB-CPU-model.patch
  0093-migration-warn-about-inconsistent-s.patch
  0094-i386-Compensate-for-KVM-SPEC_CTRL-f.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Wed Feb 28 2018 lyan@suse.com
- Security fixes for the following CVE issues:
  (bsc#1071228 CVE-2017-17381)
  0070-virtio-check-VirtQueue-Vring-object.patch
  (bsc#1068613  CVE-2017-16845)
  0071-ps2-check-PS2Queue-pointers-in-post.patch
  (bsc#1070144 CVE-2017-15119)
  0072-nbd-server-CVE-2017-15119-Reject-op.patch
  (bsc#1076775 CVE-2017-18043)
  0073-osdep-Fix-ROUND_UP-64-bit-32-bit.patch
  (bsc#1076114 CVE-2018-5683)
  0074-vga-check-the-validation-of-memory-.patch
  (bsc#1083291 CVE-2018-7550)
  0075-multiboot-check-mh_load_end_addr-ad.patch
  (bsc#1073489 CVE-2017-15124)
  0076-vnc-fix-debug-spelling.patch
  0077-ui-remove-sync-parameter-from-vnc_u.patch
  0078-ui-remove-unreachable-code-in-vnc_u.patch
  0079-ui-remove-redundant-indentation-in-.patch
  0080-ui-avoid-pointless-VNC-updates-if-f.patch
  0081-ui-track-how-much-decoded-data-we-c.patch
  0082-ui-introduce-enum-to-track-VNC-clie.patch
  0083-ui-correctly-reset-framebuffer-upda.patch
  0084-ui-refactor-code-for-determining-if.patch
  0085-ui-fix-VNC-client-throttling-when-a.patch
  0086-ui-fix-VNC-client-throttling-when-f.patch
  0087-ui-place-a-hard-cap-on-VNC-server-o.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Thu Feb  1 2018 fli@suse.com
- Fix pcihp for 1.6 and older machine types (bsc#1074572)
  0069-pcihp-fix-pcihp-for-1.6-machine-typ.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Mon Jan 29 2018 lyan@suse.com
- Spectre fixes for s390x by providing more hw features to guests
  (bsc#1076813)
  0066-header-sync.patch
  0067-s390x-kvm-Handle-bpb-feature.patch
  0068-s390x-kvm-provide-stfle.81.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
  * Patches added:
* Fri Jan 12 2018 brogers@suse.com
- Fix packaging dependencies (coreutils) for qemu-ksm package
  (bsc#1040202)
* Thu Dec 21 2017 brogers@suse.com
- Pass through to guest info related to x86 security vulnerability
  (CVE-2017-5715 bsc#1068032)
  0065-i386-kvm-MSR_IA32_SPEC_CTRL-and-MSR.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Tue Nov 28 2017 brogers@suse.com
- Support EPYC vCPU type (bsc#1052825 fate#324038)
  0064-target-i386-cpu-Add-new-EPYC-CPU-mo.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Thu Oct 19 2017 brogers@suse.com
- Add announcement in support docs about qed storage format no
  longer being supported in next major SLE release (SLE15)
  (fate#324200)
- Address various security/stability issues
  * Fix DoS in I/O channel websockets (CVE-2017-15268 bsc#1062942)
  0061-io-monitor-encoutput-buffer-size-fr.patch
  * Fix OOB access in cirrus vga device emulation (CVE-2017-15289
  bsc#1063122)
  0062-cirrus-fix-oob-access-in-mode4and5-.patch
  * Fix information leak in 9pfs interface (CVE-2017-15038 bsc#1062069)
  0063-9pfs-use-g_malloc0-to-allocate-spac.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Wed Oct 11 2017 fli@suse.com
- Address various security issues
  * Fix xen/blkif responses leak stack data (CVE-2017-10911 bsc#1057378)
  0056-xen-disk-don-t-leak-stack-data-via-.patch
  * Fix crash when ide flushes empty CDROM drives (CVE-2017-12809 bsc#1054724)
  0057-IDE-Do-not-flush-empty-CDROM-drives.patch
  0058-IDE-test-flush-on-empty-CDROM.patch
  * Fix OOB access while loading kernel via multiboot image (CVE-2017-14167 bsc#1057585)
  0059-multiboot-validate-multiboot-header.patch
  * Fix OOB read access during vga display update (CVE-2017-13672 bsc#1056334)
  0060-vga-stop-passing-pointers-to-vga_dr.patch
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-SP3
* Thu Sep 21 2017 brogers@suse.com
- Fix case of not being able to build from rpm sources due to
  undefined macro (boo#1057966)
- Fix typo in supported.s390.txt
* Fri Sep  8 2017 lyan@suse.com
- Updated to v2.9.1, a bug-fix-only release
  * Updated version carries fixes for the following reported issues:
  CVE-2017-13711 bsc#1056291
- Patch queue updated from https://gitlab.suse.de/virtualization/qemu.git SLE12-
  SP3
  * Patches dropped:
  0049-ACPI-don-t-call-acpi_pcihp_device_p.patch
  0051-input-limit-kbd-queue-depth.patch
  0052-audio-release-capture-buffers.patch
  0053-scsi-avoid-an-off-by-one-error-in-m.patch
  0054-vmw_pvscsi-check-message-ring-page-.patch
  0055-9pfs-local-forbid-client-access-to-.patch
  0059-Hacks-for-building-on-gcc-7-Fedora-.patch
  0060-9pfs-local-fix-unlink-of-alien-file.patch
  0061-megasas-do-not-read-DCMD-opcode-mor.patch
  0063-nbd-Fully-initialize-client-in-case.patch
  0064-9pfs-local-remove-use-correct-path-.patch
  0065-hid-Reset-kbd-modifiers-on-reset.patch
  0066-input-Decrement-queue-count-on-kbd-.patch
  0067-xhci-only-update-dequeue-ptr-on-com.patch
  0068-vnc-Set-default-kbd-delay-to-10ms.patch
  0069-qemu-nbd-Ignore-SIGPIPE.patch
  0070-usb-redir-fix-stack-overflow-in-usb.patch
  0071-exec-use-qemu_ram_ptr_length-to-acc.patch
  0073-xen-mapcache-store-dma-information-.patch
  0074-exec-Add-lock-parameter-to-qemu_ram.patch
  * Patches renamed:
  0050-i386-Allow-cpuid-bit-override.patch
  - > 0049-i386-Allow-cpuid-bit-override.patch
  0056-jazz_led-fix-bad-snprintf.patch
  - > 0050-jazz_led-fix-bad-snprintf.patch
  0057-slirp-smb-Replace-constant-strings-.patch
  - > 0051-slirp-smb-Replace-constant-strings-.patch
  0058-altera_timer-fix-incorrect-memset.patch
  - > 0052-altera_timer-fix-incorrect-memset.patch
  0062-megasas-always-store-SCSIRequest-in.patch
  - > 0053-megasas-always-store-SCSIRequest-in.patch
  0072-slirp-check-len-against-dhcp-option.patch
  - > 0054-slirp-check-len-against-dhcp-option.patch
  0075-Replace-struct-ucontext-with-uconte.patch
  - > 0055-Replace-struct-ucontext-with-uconte.patch
* Thu Aug 24 2017 brogers@suse.com
- Fix package build failure as of glibc v2.26 update in Factory
  (boo#1055587)
  0075-Replace-struct-ucontext-with-uconte.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Mon Aug 21 2017 schwab@suse.de
- Remove redundant prerequire for pwdutils
* Fri Aug 18 2017 brogers@suse.com
- Postrequire acl for setfacl
* Wed Aug 16 2017 schwab@suse.de
- Prerequire shadow for groupadd
* Tue Aug 15 2017 brogers@suse.com
- The recent security fix for CVE-2017-11334 adversely affects Xen.
  Include two additional patches to make sure Xen is going to be OK.
  0073-xen-mapcache-store-dma-information-.patch
  0074-exec-Add-lock-parameter-to-qemu_ram.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Aug  9 2017 lyan@suse.com
- Pre-add group kvm for qemu-tools (bsc#1011144)
* Mon Aug  7 2017 brogers@suse.com
- Fixed a few more inaccuracies in the support docs.
* Tue Jul 25 2017 brogers@suse.com
- Address various security/stability issues
  * Fix DOS vulnerability in qemu-nbd (bsc#1046636 CVE-2017-10664)
  0069-qemu-nbd-Ignore-SIGPIPE.patch
  * Fix DOS from stack overflow in debug messages of usb redirection
  support (bsc#1047674 CVE-2017-10806)
  0070-usb-redir-fix-stack-overflow-in-usb.patch
  * Fix OOB access during DMA operation (CVE-2017-11334 bsc#1048902)
  0071-exec-use-qemu_ram_ptr_length-to-acc.patch
  * Fix OOB access parsing dhcp slirp options (CVE-2017-11434 bsc#1049381)
  0072-slirp-check-len-against-dhcp-option.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Jul 25 2017 brogers@suse.com
- Fix support docs to indicate ARM64 is now fully L3 supported in
  SLES 12 SP3. Apply a few additional clarifications in the support
  docs. (bsc#1050268)
- Adjust to libvdeplug-devel package naming changes.
* Tue Jul 18 2017 brogers@suse.com
- Fix migration with xhci (bsc#1048296)
  0067-xhci-only-update-dequeue-ptr-on-com.patch
- Increase VNC delay to fix missing keyboard input events (bsc#1031692)
  0068-vnc-Set-default-kbd-delay-to-10ms.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Thu Jun 29 2017 lyan@suse.com
- Remove build dependency package iasl used for seabios
* Mon Jun 26 2017 brogers@suse.com
- Fixed stuck state during usb keyboard reset (bsc#1044936)
  0065-hid-Reset-kbd-modifiers-on-reset.patch
- Fixed keyboard events getting lost (bsc#1044936)
  0066-input-Decrement-queue-count-on-kbd-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Jun 20 2017 brogers@suse.com
- Use most recent compiler to build size-critical firmware, instead
  of hard-coding gcc6 for all target versions (bsc#1043390)
  * A few upstream ipxe patches were needed for gcc7 compatibility:
  ipxe-ath-Add-missing-break-statements.patch
  ipxe-mucurses-Fix-erroneous-__nonnull-attribute.patch
- Add --no-renames to the git format-patch command in the git
  workflow script for better patch compatibility
- Address various security/stability issues
  * Fix potential privilege escalation in virtfs (CVE-2016-9602
  bsc#1020427)
  0060-9pfs-local-fix-unlink-of-alien-file.patch
  * Fix DOS in megasas device emulation (CVE-2017-9503 bsc#1043296)
  0061-megasas-do-not-read-DCMD-opcode-mor.patch
  0062-megasas-always-store-SCSIRequest-in.patch
  * Fix DOS in qemu-nbd server (CVE-2017-9524 bsc#1043808)
  0063-nbd-Fully-initialize-client-in-case.patch
  * Fix regression introduced by recent virtfs security fixes (bsc#1045035)
  0064-9pfs-local-remove-use-correct-path-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Jun  6 2017 lyan@suse.com
- Backport ipxe to support FirstBurstLength (bsc#1040476)
  ipxe-iscsi-Always-send-FirstBurstLength-parameter.patch
* Mon May 22 2017 brogers@suse.com
- Fixes for gcc7 compatability (bsc#1040228) (in behalf of Liang Yan)
  0056-jazz_led-fix-bad-snprintf.patch
  0057-slirp-smb-Replace-constant-strings-.patch
  0058-altera_timer-fix-incorrect-memset.patch
  0059-Hacks-for-building-on-gcc-7-Fedora-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Mon May 22 2017 brogers@suse.com
- Protect access to metadata in virtio-9pfs (CVE-2017-7493 bsc#1039495)
  0055-9pfs-local-forbid-client-access-to-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Thu May 11 2017 brogers@suse.com
- Address various security/stability issues
  * Fix DOS potential in vnc interface (CVE-2017-8379 bsc#1037334)
  0051-input-limit-kbd-queue-depth.patch
  * Fix DOS potential in vnc interface (CVE-2017-8309 bsc#1037242)
  0052-audio-release-capture-buffers.patch
  * Fix OOB access in megasas device emulation (CVE-2017-8380
  bsc#1037336)
  0053-scsi-avoid-an-off-by-one-error-in-m.patch
  * Fix DOS in Vmware pv scsi emulation (CVE-2017-8112 bsc#1036211)
  0054-vmw_pvscsi-check-message-ring-page-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Thu May  4 2017 brogers@suse.com
- Fix building packages for some older distros.
- Further refine our handling of building firmware (or not) for
  the various arch's and distro versions we build for. Note that
  if we don't build x86 firmware, (eg: x86 Leap 42.1) the upstream
  binary blobs are used, which may have migration incompatibilities
  with previous versions of qemu provided.
* Thu Apr 27 2017 brogers@suse.com
- Fix issue in shipping qemu v2.9.0, where pci-passthrough for Xen
  HVM guests got broken (bsc#1034131)
  0049-ACPI-don-t-call-acpi_pcihp_device_p.patch
- Include experimental, unsupported feature to assist in some
  performance analysis work.
  0050-i386-Allow-cpuid-bit-override.patch
* Thu Apr 20 2017 brogers@suse.com
- Updated to v2.9.0: See http://wiki.qemu-project.org/ChangeLog/2.9
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Apr 18 2017 brogers@suse.com
- Updated to v2.9.0-rc5: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Includes fix for CVE-2017-7471, a virtfs security issue.
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Apr 12 2017 brogers@suse.com
- Add empty keyboard queue tracepoint to help openQA testing work
  better (bsc#1031692)
  0048-input-Add-trace-event-for-empty-key.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Apr 11 2017 brogers@suse.com
- Updated to v2.9.0-rc4: See http://wiki.qemu-project.org/ChangeLog/2.9
- Enable ceph/rbd support for s390x (bsc#1030068)
- Enable ceph/rbd support for ppc* as available
- Update ARM in-kernel-timers patch (bsc#1033416)
  * Patches renamed:
  0041-ARM-KVM-Enable-in-kernel-timers-wit.patch -> 0047-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0042-string-input-visitor-Fix-uint64-par.patch -> 0041-string-input-visitor-Fix-uint64-par.patch
  0043-test-string-input-visitor-Add-int-t.patch -> 0042-test-string-input-visitor-Add-int-t.patch
  0044-test-string-input-visitor-Add-uint6.patch -> 0043-test-string-input-visitor-Add-uint6.patch
  0045-tests-Add-QOM-property-unit-tests.patch -> 0044-tests-Add-QOM-property-unit-tests.patch
  0046-tests-Add-scsi-disk-test.patch -> 0045-tests-Add-scsi-disk-test.patch
  * Patches added (support patch):
  0046-RFC-update-Linux-headers-from-irqs-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Apr  5 2017 brogers@suse.com
- Updated to v2.9.0-rc3: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Patches dropped (included in upstream source archive):
  0047-hw-intc-arm_gicv3_kvm-Check-KVM_DEV.patch
  0048-i386-Replace-uint32_t-with-FeatureW.patch
  0049-i386-Don-t-override-cpu-options-on-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
- Added additional documentation provided with v2.9.0
- Fix build failure with gcc7 (bsc#1031340)
  ipxe-build-Avoid-implicit-fallthrough-warnings-on-GCC-7.patch
- Made miscellaneous spec file refinements
* Thu Mar 30 2017 brogers@suse.com
- The support documents included are now fairly accurate for the
  arm and s390 world, and the x86 version also received a few
  tweaks. Also included in those docs is a url reference to upstream
  qemu deprecation plans and discussions.
  (fate#321146)
- Add post v2.9.0-rc2 upstream patches which fix -cpu host and -cpu
  max feature overrides for libvirt compatability.
  0048-i386-Replace-uint32_t-with-FeatureW.patch
  0049-i386-Don-t-override-cpu-options-on-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Mar 28 2017 brogers@suse.com
- Updated to v2.9.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Includes fix for in guest privilege escalation when using TCG
  (bsc#1030624)
  * Patches dropped (equivalent included in upstream source archive):
  0047-linux-user-exclude-cpu-model-code-w.patch
- Fix failure booting SLE12-SP2 Aarch64 guest (bsc#1031384)
  0047-hw-intc-arm_gicv3_kvm-Check-KVM_DEV.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Mar 21 2017 brogers@suse.com
- Updated to v2.9.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Patches dropped (no longer needed based on what we now build for):
  0024-virtfs-proxy-helper-Provide-__u64-f.patch
  * Patches dropped (included in upstream source archive):
  0034-dma-rc4030-limit-interval-timer-rel.patch
  * Patches renamed:
  0025-configure-Enable-PIE-for-ppc-and-pp.patch -> 0024-configure-Enable-PIE-for-ppc-and-pp.patch
  0026-AIO-Reduce-number-of-threads-for-32.patch -> 0025-AIO-Reduce-number-of-threads-for-32.patch
  0027-dictzip-Fix-on-big-endian-systems.patch -> 0026-dictzip-Fix-on-big-endian-systems.patch
  0028-xen_disk-Add-suse-specific-flush-di.patch -> 0027-xen_disk-Add-suse-specific-flush-di.patch
  0029-qemu-bridge-helper-reduce-security-.patch -> 0028-qemu-bridge-helper-reduce-security-.patch
  0030-qemu-binfmt-conf-use-qemu-ARCH-binf.patch -> 0029-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0031-configure-Fix-detection-of-seccomp-.patch -> 0030-configure-Fix-detection-of-seccomp-.patch
  0032-linux-user-properly-test-for-infini.patch -> 0031-linux-user-properly-test-for-infini.patch
  0033-linux-user-remove-all-traces-of-qem.patch -> 0032-linux-user-remove-all-traces-of-qem.patch
  0035-roms-Makefile-pass-a-packaging-time.patch -> 0033-roms-Makefile-pass-a-packaging-time.patch
  0036-Raise-soft-address-space-limit-to-h.patch -> 0034-Raise-soft-address-space-limit-to-h.patch
  0037-increase-x86_64-physical-bits-to-42.patch -> 0035-increase-x86_64-physical-bits-to-42.patch
  0038-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch -> 0036-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0039-i8254-Fix-migration-from-SLE11-SP2.patch -> 0037-i8254-Fix-migration-from-SLE11-SP2.patch
  0040-acpi_piix4-Fix-migration-from-SLE11.patch -> 0038-acpi_piix4-Fix-migration-from-SLE11.patch
  0041-Fix-tigervnc-long-press-issue.patch -> 0039-Fix-tigervnc-long-press-issue.patch
  0042-fix-xen-hvm-direct-kernel-boot.patch -> 0040-fix-xen-hvm-direct-kernel-boot.patch
  0043-ARM-KVM-Enable-in-kernel-timers-wit.patch -> 0041-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0044-string-input-visitor-Fix-uint64-par.patch -> 0042-string-input-visitor-Fix-uint64-par.patch
  0045-test-string-input-visitor-Add-int-t.patch -> 0043-test-string-input-visitor-Add-int-t.patch
  0046-test-string-input-visitor-Add-uint6.patch -> 0044-test-string-input-visitor-Add-uint6.patch
  0047-tests-Add-QOM-property-unit-tests.patch -> 0045-tests-Add-QOM-property-unit-tests.patch
  0048-tests-Add-scsi-disk-test.patch -> 0046-tests-Add-scsi-disk-test.patch
  0049-linux-user-exclude-cpu-model-code-w.patch -> 0047-linux-user-exclude-cpu-model-code-w.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Mon Mar 20 2017 brogers@suse.com
- Updated to v2.9.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Updated version carries fixes for the following reported issues:
  CVE-2016-9602 bsc#1020427, CVE-2016-9923 bsc#1014703,
  CVE-2017-2630 bsc#1025396, CVE-2017-2633 bsc#1026612,
  CVE-2017-5579 bsc#1021741, CVE-2017-5931 bsc#1024114,
  CVE-2017-5973 bsc#1025109, CVE-2017-5987 bsc#1025311,
  CVE-2017-6058 bsc#1025837, CVE-2017-6505 bsc#1028184
  * Patches dropped:
  seabios_128kb.patch (no longer required)
  * Patches dropped (included in upstream source archive):
  0035-net-imx-limit-buffer-descriptor-cou.patch
  0045-virtio-gpu-call-cleanup-mapping-fun.patch
  0051-virtio-gpu-fix-information-leak-in-.patch
  0052-display-cirrus-ignore-source-pitch-.patch
  0053-s390x-kvm-fix-small-race-reboot-vs..patch
  0054-target-s390x-use-qemu-cpu-model-in-.patch
  0056-tests-check-path-to-avoid-a-failing.patch
  0057-display-virtio-gpu-3d-check-virgl-c.patch
  0058-watchdog-6300esb-add-exit-function.patch
  0059-virtio-gpu-3d-fix-memory-leak-in-re.patch
  0060-virtio-gpu-fix-memory-leak-in-resou.patch
  0061-virtio-fix-vq-inuse-recalc-after-mi.patch
  0062-audio-es1370-add-exit-function.patch
  0063-audio-ac97-add-exit-function.patch
  0064-megasas-fix-guest-triggered-memory-.patch
  0065-cirrus-handle-negative-pitch-in-cir.patch
  0066-cirrus-fix-blit-address-mask-handli.patch
  0067-cirrus-fix-oob-access-issue-CVE-201.patch
  0068-usb-ccid-check-ccid-apdu-length.patch
  0069-sd-sdhci-check-data-length-during-d.patch
  0070-virtio-gpu-fix-resource-leak-in-vir.patch
  0071-cirrus-fix-patterncopy-checks.patch
  0072-cirrus-add-blit_is_unsafe-call-to-c.patch
  * Patches renamed:
  0036-roms-Makefile-pass-a-packaging-time.patch -> 0035-roms-Makefile-pass-a-packaging-time.patch
  0037-Raise-soft-address-space-limit-to-h.patch -> 0036-Raise-soft-address-space-limit-to-h.patch
  0038-increase-x86_64-physical-bits-to-42.patch -> 0037-increase-x86_64-physical-bits-to-42.patch
  0039-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch -> 0038-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0040-i8254-Fix-migration-from-SLE11-SP2.patch -> 0039-i8254-Fix-migration-from-SLE11-SP2.patch
  0041-acpi_piix4-Fix-migration-from-SLE11.patch -> 0040-acpi_piix4-Fix-migration-from-SLE11.patch
  0042-Fix-tigervnc-long-press-issue.patch -> 0041-Fix-tigervnc-long-press-issue.patch
  0043-fix-xen-hvm-direct-kernel-boot.patch -> 0042-fix-xen-hvm-direct-kernel-boot.patch
  0044-ARM-KVM-Enable-in-kernel-timers-wit.patch -> 0043-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0046-string-input-visitor-Fix-uint64-par.patch -> 0044-string-input-visitor-Fix-uint64-par.patch
  0047-test-string-input-visitor-Add-int-t.patch -> 0045-test-string-input-visitor-Add-int-t.patch
  0048-test-string-input-visitor-Add-uint6.patch -> 0046-test-string-input-visitor-Add-uint6.patch
  0049-tests-Add-QOM-property-unit-tests.patch -> 0047-tests-Add-QOM-property-unit-tests.patch
  0050-tests-Add-scsi-disk-test.patch -> 0048-tests-Add-scsi-disk-test.patch
  0055-linux-user-exclude-cpu-model-code-w.patch -> 0049-linux-user-exclude-cpu-model-code-w.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Mar  1 2017 brogers@suse.com
-  Buildignore for the global gcc-PIE, as this package enables PIE
  on its own and has troubles if all use it. (meissner@suse.com)
* Wed Mar  1 2017 brogers@suse.com
- Address various security/stability issues
  * Fix OOB access in virito-gpu-3d (CVE-2016-10028 bsc#1017084
  bsc#1016503)
  0057-display-virtio-gpu-3d-check-virgl-c.patch
  * Fix DOS in Intel 6300ESB device emulation (CVE-2016-10155 bsc#1021129)
  0058-watchdog-6300esb-add-exit-function.patch
  * Fix DOS in virtio-gpu-3d (CVE-2017-5552 bsc#1021195)
  0059-virtio-gpu-3d-fix-memory-leak-in-re.patch
  * Fix DOS in virtio-gpu (CVE-2017-5578 bsc#1021481)
  0060-virtio-gpu-fix-memory-leak-in-resou.patch
  * Fix cause of infrequent migration failures from bad virtio device
  state. (bsc#1020928)
  0061-virtio-fix-vq-inuse-recalc-after-mi.patch
  * Fix DOS in es1370 emulated audio device (CVE-2017-5526 bsc#1020589)
  0062-audio-es1370-add-exit-function.patch
  * Fix DOS in ac97 emulated audio device (CVE-2017-5525 bsc#1020491)
  0063-audio-ac97-add-exit-function.patch
  * Fix DOS in megasas device emulation (CVE-2017-5856 bsc#1023053)
  0064-megasas-fix-guest-triggered-memory-.patch
  * Fix various inaccuracies in cirrus vga device emulation
  0065-cirrus-handle-negative-pitch-in-cir.patch
  0066-cirrus-fix-blit-address-mask-handli.patch
  * Fix OOB access in cirrus vga emulation (CVE-2017-2615 bsc#1023004)
  0067-cirrus-fix-oob-access-issue-CVE-201.patch
  * Fix DOS in usb CCID card device emulator (CVE-2017-5898 bsc#1023907)
  0068-usb-ccid-check-ccid-apdu-length.patch
  * Fix OOB access in SDHCI device emulation (CVE-2017-5667 bsc#1022541)
  0069-sd-sdhci-check-data-length-during-d.patch
  * Fix DOS in virtio-gpu-3d (CVE-2017-5857 bsc#1023073)
  0070-virtio-gpu-fix-resource-leak-in-vir.patch
  * Fix cirrus patterncopy checks
  0071-cirrus-fix-patterncopy-checks.patch
  * Fix OOB access in cirrus vga emulation (CVE-2017-2620 bsc#1024972)
  0072-cirrus-add-blit_is_unsafe-call-to-c.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
* Thu Feb 23 2017 brogers@suse.com
- Fix name of s390x specific sysctl configuration file to end with
  .conf (bsc#1026583)
* Fri Feb 17 2017 brogers@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Check that sysfs path exists before running test which requires
  it. This allows qemu-testsuite to succeed in local build service
  chroot based package build.
  0056-tests-check-path-to-avoid-a-failing.patch
* Wed Feb 15 2017 brogers@suse.com
- Factory and SLE12-SP3 got a name change in the dtc devel package:
  libfdt1-devel -> libfdt-devel. Adjust our spec file accordingly.
* Tue Feb 14 2017 brogers@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Patches added:
  0055-linux-user-exclude-cpu-model-code-w.patch
* Thu Feb  2 2017 brogers@suse.com
- Make sure qemu guest agent is usable as soon as qemu-guest-agent
  package is installed. The previous post script was still not
  doing the job.
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Fix potential hang/crash rebooting s390x guest
  0053-s390x-kvm-fix-small-race-reboot-vs..patch
  * Fix s390x linux-user failure since v2.8.0 update
  0054-target-s390x-use-qemu-cpu-model-in-.patch
* Wed Jan 25 2017 brogers@suse.com
- Merge qemu packages from openSUSE and SUSE SLE releases together
  for the v2.8 qemu update. The qemu.changes file is the openSUSE
  version with this entry providing CVE, FATE, and bugzilla
  references from the SUSE SLE qemu package to date (see below)
- Updated to v2.8.0: See http://wiki.qemu-project.org/ChangeLog/2.8
  * For SUSE SLE-12-SP3, update relates to fate#319684, fate#321331,
  fate#321335, fate#321339, fate#321349, fate#321857
  * For best compatibility, qemu-ifup and kvm_stat scripts now owned
  by qemu package
  * Build ipxe roms with gcc6 to maintain SLE legacy migration
  compatibility requirements
  * qmp-commands.txt file removed, to resurface in future doc reorganization
  * qemu-tech.html file merged into other existing doc
  * trace-events renamed to trace-events-all
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Patches dropped (upstream):
  0013-linux-user-lock-tcg.patch
  0014-linux-user-Run-multi-threaded-code-.patch
  0015-linux-user-lock-tb-flushing-too.patch
  0017-linux-user-implement-FS_IOC_GETFLAG.patch
  0018-linux-user-implement-FS_IOC_SETFLAG.patch
  0034-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0039-Fix-tlb_vaddr_to_host-with-CONFIG_U.patch
  0041-vmsvga-correct-bitmap-and-pixmap-si.patch
  0042-scsi-mptconfig-fix-an-assert-expres.patch
  0043-scsi-mptconfig-fix-misuse-of-MPTSAS.patch
  0044-scsi-pvscsi-limit-loop-to-fetch-SG-.patch
  0045-usb-xhci-fix-memory-leak-in-usb_xhc.patch
  0046-scsi-mptsas-use-g_new0-to-allocate-.patch
  0047-scsi-pvscsi-limit-process-IO-loop-t.patch
  0048-virtio-add-check-for-descriptor-s-m.patch
  0049-net-mcf-limit-buffer-descriptor-cou.patch
  0050-usb-ehci-fix-memory-leak-in-ehci_pr.patch
  0051-xhci-limit-the-number-of-link-trbs-.patch
  0052-9pfs-allocate-space-for-guest-origi.patch
  0053-9pfs-fix-memory-leak-in-v9fs_link.patch
  0054-9pfs-fix-potential-host-memory-leak.patch
  0055-9pfs-fix-information-leak-in-xattr-.patch
  0056-9pfs-fix-memory-leak-in-v9fs_xattrc.patch
  0057-9pfs-fix-memory-leak-in-v9fs_write.patch
  0058-char-serial-check-divider-value-aga.patch
  0059-net-pcnet-check-rx-tx-descriptor-ri.patch
  0060-net-eepro100-fix-memory-leak-in-dev.patch
  0061-net-rocker-set-limit-to-DMA-buffer-.patch
  0062-net-vmxnet-initialise-local-tx-desc.patch
  0063-net-rtl8139-limit-processing-of-rin.patch
  0064-audio-intel-hda-check-stream-entry-.patch
  0065-virtio-gpu-fix-memory-leak-in-virti.patch
  0066-9pfs-fix-integer-overflow-issue-in-.patch
  slof_xhci.patch
  * Patches renamed:
  0016-linux-user-Fake-proc-cpuinfo.patch -> 0013-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-XXX-disable-fiemap.patch -> 0014-linux-user-XXX-disable-fiemap.patch
  0020-slirp-nooutgoing.patch -> 0015-slirp-nooutgoing.patch
  0021-vnc-password-file-and-incoming-conn.patch -> 0016-vnc-password-file-and-incoming-conn.patch
  0022-linux-user-use-target_ulong.patch -> 0017-linux-user-use-target_ulong.patch
  0023-block-Add-support-for-DictZip-enabl.patch -> 0018-block-Add-support-for-DictZip-enabl.patch
  0024-block-Add-tar-container-format.patch -> 0019-block-Add-tar-container-format.patch
  0025-Legacy-Patch-kvm-qemu-preXX-dictzip.patch -> 0020-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0026-console-add-question-mark-escape-op.patch -> 0021-console-add-question-mark-escape-op.patch
  0027-Make-char-muxer-more-robust-wrt-sma.patch -> 0022-Make-char-muxer-more-robust-wrt-sma.patch
  0028-linux-user-lseek-explicitly-cast-no.patch -> 0023-linux-user-lseek-explicitly-cast-no.patch
  0029-virtfs-proxy-helper-Provide-__u64-f.patch -> 0024-virtfs-proxy-helper-Provide-__u64-f.patch
  0030-configure-Enable-PIE-for-ppc-and-pp.patch -> 0025-configure-Enable-PIE-for-ppc-and-pp.patch
  0031-AIO-Reduce-number-of-threads-for-32.patch -> 0026-AIO-Reduce-number-of-threads-for-32.patch
  0032-dictzip-Fix-on-big-endian-systems.patch -> 0027-dictzip-Fix-on-big-endian-systems.patch
  0033-xen_disk-Add-suse-specific-flush-di.patch -> 0028-xen_disk-Add-suse-specific-flush-di.patch
  0035-qemu-bridge-helper-reduce-security-.patch -> 0029-qemu-bridge-helper-reduce-security-.patch
  0036-qemu-binfmt-conf-use-qemu-ARCH-binf.patch -> 0030-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0037-configure-Fix-detection-of-seccomp-.patch -> 0031-configure-Fix-detection-of-seccomp-.patch
  0038-linux-user-properly-test-for-infini.patch -> 0032-linux-user-properly-test-for-infini.patch
  0040-linux-user-remove-all-traces-of-qem.patch -> 0033-linux-user-remove-all-traces-of-qem.patch
  0067-dma-rc4030-limit-interval-timer-rel.patch -> 0034-dma-rc4030-limit-interval-timer-rel.patch
  0068-net-imx-limit-buffer-descriptor-cou.patch -> 0035-net-imx-limit-buffer-descriptor-cou.patch
  0069-roms-Makefile-pass-a-packaging-time.patch -> 0036-roms-Makefile-pass-a-packaging-time.patch
  * Patches added:
  0037-Raise-soft-address-space-limit-to-h.patch
  0038-increase-x86_64-physical-bits-to-42.patch
  0039-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0040-i8254-Fix-migration-from-SLE11-SP2.patch
  0041-acpi_piix4-Fix-migration-from-SLE11.patch
  0042-Fix-tigervnc-long-press-issue.patch
  0043-fix-xen-hvm-direct-kernel-boot.patch
  0044-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0045-virtio-gpu-call-cleanup-mapping-fun.patch
  0046-string-input-visitor-Fix-uint64-par.patch
  0047-test-string-input-visitor-Add-int-t.patch
  0048-test-string-input-visitor-Add-uint6.patch
  0049-tests-Add-QOM-property-unit-tests.patch
  0050-tests-Add-scsi-disk-test.patch
  0051-virtio-gpu-fix-information-leak-in-.patch
  0052-display-cirrus-ignore-source-pitch-.patch
  ipxe-use-gcc6-for-more-compact-code.patch
  * SLE patches dropped (accounted for in above listed changes):
  0002-qemu-0.9.0.cvs-binfmt.patch
  0009-block-vmdk-Support-creation-of-SCSI.patch
  0010-linux-user-add-binfmt-wrapper-for-a.patch
  0011-PPC-KVM-Disable-mmu-notifier-check.patch
  0012-linux-user-fix-segfault-deadlock.patch
  0013-linux-user-binfmt-support-host-bina.patch
  0014-linux-user-Ignore-broken-loop-ioctl.patch
  0015-linux-user-lock-tcg.patch
  0016-linux-user-Run-multi-threaded-code-.patch
  0017-linux-user-lock-tb-flushing-too.patch
  0018-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-implement-FS_IOC_GETFLAG.patch
  0020-linux-user-implement-FS_IOC_SETFLAG.patch
  0021-linux-user-XXX-disable-fiemap.patch
  0022-slirp-nooutgoing.patch
  0023-vnc-password-file-and-incoming-conn.patch
  0024-linux-user-add-more-blk-ioctls.patch
  0025-linux-user-use-target_ulong.patch
  0026-block-Add-support-for-DictZip-enabl.patch
  0027-block-Add-tar-container-format.patch
  0028-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0029-console-add-question-mark-escape-op.patch
  0030-Make-char-muxer-more-robust-wrt-sma.patch
  0031-linux-user-lseek-explicitly-cast-no.patch
  0032-virtfs-proxy-helper-Provide-_u64-f.patch
  0033-configure-Enable-PIE-for-ppc-and-pp.patch
  0034-Raise-soft-address-space-limit-to-h.patch
  0035-increase-x86_64-physical-bits-to-42.patch
  0036-vnc-provide-fake-color-map.patch
  0037-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0038-i8254-Fix-migration-from-SLE11-SP2.patch
  0039-acpi_piix4-Fix-migration-from-SLE11.patch
  0040-qtest-Increase-socket-timeout-to-ac.patch
  0041-dictzip-Fix-on-big-endian-systems.patch
  0043-xen_disk-Add-suse-specific-flush-di.patch
  0044-Split-large-discard-requests-from-b.patch
  0045-fix-xen-hvm-direct-kernel-boot.patch
  0046-xen-introduce-dummy-system-device.patch
  0047-xen-write-information-about-support.patch
  0048-xen-add-pvUSB-backend.patch
  0049-xen-move-xen_sysdev-to-xen_backend..patch
  0050-vnc-add-configurable-keyboard-delay.patch
  0051-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0052-configure-add-echo_version-helper.patch
  0053-configure-support-vte-2.91.patch
  0054-scsi-esp-fix-migration.patch
  0055-hw-arm-virt-mark-the-PCIe-host-cont.patch
  0056-xen-when-removing-a-backend-don-t-r.patch
  0057-xen-drain-submit-queue-in-xen-usb-b.patch
  0058-qcow2-avoid-extra-flushes-in-qcow2.patch
  0059-qemu-bridge-helper-reduce-security-.patch
  0060-xen-use-a-common-function-for-pv-an.patch
  0061-xen_platform-unplug-also-SCSI-disks.patch
  0062-virtio-check-vring-descriptor-buffe.patch
  0063-net-vmxnet3-check-for-device_active.patch
  0064-net-vmxnet-initialise-local-tx-desc.patch
  0065-scsi-pvscsi-avoid-infinite-loop-whi.patch
  0066-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0067-hw-net-Fix-a-heap-overflow-in-xlnx..patch
  0068-vmsvga-correct-bitmap-and-pixmap-si.patch
  0069-usb-xhci-fix-memory-leak-in-usb_xhc.patch
  0070-virtio-add-check-for-descriptor-s-m.patch
  0071-net-mcf-limit-buffer-descriptor-cou.patch
  0072-usb-ehci-fix-memory-leak-in-ehci_pr.patch
  0073-xhci-limit-the-number-of-link-trbs-.patch
  0074-9pfs-allocate-space-for-guest-origi.patch
  0075-9pfs-fix-memory-leak-in-v9fs_link.patch
  0076-9pfs-fix-potential-host-memory-leak.patch
  0077-9pfs-fix-memory-leak-in-v9fs_write.patch
  0078-char-serial-check-divider-value-aga.patch
  0079-net-pcnet-check-rx-tx-descriptor-ri.patch
  0080-net-eepro100-fix-memory-leak-in-dev.patch
  0081-net-rocker-set-limit-to-DMA-buffer-.patch
  0082-net-rtl8139-limit-processing-of-rin.patch
  0083-audio-intel-hda-check-stream-entry-.patch
  0084-virtio-gpu-fix-memory-leak-in-virti.patch
  0085-9pfs-fix-integer-overflow-issue-in-.patch
  0086-dma-rc4030-limit-interval-timer-rel.patch
  0087-net-imx-limit-buffer-descriptor-cou.patch
  0088-target-i386-Implement-CPUID-0xB-Ext.patch
  0089-target-i386-present-virtual-L3-cach.patch
  0090-migration-fix-inability-to-save-VM-.patch
  0091-ui-gtk-Fix-a-runtime-warning-on-vte.patch
  0092-gtk-don-t-leak-the-GtkBorder-with-V.patch
  0093-xen-fix-ioreq-handling.patch
  0094-macio-Use-blk_drain-instead-of-blk_.patch
  0095-rbd-Switch-rbd_start_aio-to-byte-ba.patch
  0096-virtio-blk-Release-s-rq-queue-at-sy.patch
  0097-virtio-blk-Remove-stale-comment-abo.patch
  0098-block-reintroduce-bdrv_flush_all.patch
  0099-qemu-use-bdrv_flush_all-for-vm_stop.patch
  0100-block-backend-remove-blkflush_all.patch
  0101-char-fix-missing-return-in-error-pa.patch
  0102-rbd-shift-byte-count-as-a-64-bit-va.patch
  0103-mirror-use-bdrv_drained_begin-bdrv_.patch
  0104-block-curl-Use-BDRV_SECTOR_SIZE.patch
  0105-block-curl-Fix-return-value-from-cu.patch
  0106-block-curl-Remember-all-sockets.patch
  0107-block-curl-Do-not-wait-for-data-bey.patch
  0108-virtio-allow-per-device-class-legac.patch
  0109-virtio-net-mark-VIRTIO_NET_F_GSO-as.patch
  0110-vhost-adapt-vhost_verify_ring_mappi.patch
  0111-ivshmem-Fix-64-bit-memory-bar-confi.patch
  0112-intel_iommu-fix-incorrect-device-in.patch
  0113-9pfs-fix-information-leak-in-xattr-.patch
  0114-9pfs-fix-memory-leak-in-v9fs_xattrc.patch
  0115-net-mcf-check-receive-buffer-size-r.patch
  0116-virtio-gpu-fix-memory-leak-in-updat.patch
  0117-virtio-gpu-fix-information-leak-in-.patch
  0118-9pfs-adjust-the-order-of-resource-c.patch
  0119-9pfs-add-cleanup-operation-in-FileO.patch
  0120-9pfs-add-cleanup-operation-for-hand.patch
  0121-9pfs-add-cleanup-operation-for-prox.patch
  0122-virtio-gpu-call-cleanup-mapping-fun.patch
  0123-string-input-visitor-Fix-uint64-par.patch
  0124-test-string-input-visitor-Add-int-t.patch
  0125-test-string-input-visitor-Add-uint6.patch
  0126-tests-Add-QOM-property-unit-tests.patch
  0127-tests-Add-scsi-disk-test.patch
  0128-usb-ehci-fix-memory-leak-in-ehci_in.patch
  0129-usbredir-free-vm_change_state_handl.patch
  0130-virtio-gpu-fix-information-leak-in-.patch
  ipxe-ath9k-Fix-buffer-overrun-for-ar9287.patch
  ipxe-ath-Fix-building-with-GCC-6.patch
  ipxe-efi-fix-garbage-bytes-in-device-path.patch
  ipxe-efi-fix-uninitialised-data-in-HII.patch
  ipxe-legacy-Fix-building-with-GCC-6.patch
  ipxe-mucurses-Fix-GCC-6-nonnull-compare-errors.patch
  ipxe-sis190-Fix-building-with-GCC-6.patch
  ipxe-skge-Fix-building-with-GCC-6.patch
  ipxe-util-v5.24-perl-errors-on-redeclare.patch
- SLE CVE, FATE, and bugzilla references not otherwise listed in
  this changelog file. The intent of this list is to indicate that
  the fix or feature continues the line of inheritance in the
  development stream of this package. The list is intended to
  satisfy searches only - refer to the SLE-12-SP2 changelog file
  for additional details.
  * fate#314468 fate#314497 fate#315125 fate#315467 fate#317015
  fate#317741 fate#317763 fate#318349 fate#319660 fate#319979
  fate#321010
  * bnc#812983 bnc#869026 bnc#869746 bnc#874413 bnc#875582 bnc#875870
  bnc#877642 bnc#877645 bnc#878541 bsc#882405 bsc#886378 bnc#893339
  bnc#893892 bnc#895369 bnc#896726 bnc#897654 bnc#905097 bnc#907805
  bnc#908380 bnc#914521 bsc#924018 bsc#929339 bsc#932267 bsc#932770
  bsc#933981 bsc#936537 bsc#937125 bsc#938344 bsc#940929 bsc#942845
  bsc#943446 bsc#944697 bsc#945404 bsc#945987 bsc#945989 bsc#946020
  bsc#947159 bnc#953518 bsc#954864 bsc#956829 bsc#957162 bsc#958491
  bsc#958917 bsc#959005 bsc#959386 bsc#960334 bsc#960708 bsc#960725
  bsc#960835 bsc#961333 bsc#961556 bsc#961691 bsc#962320 bsc#963782
  bsc#964413 bsc#970791 bsc#974141 bsc#978158 bsc#979473 bsc#982365
  bsc#989655 bsc#991466 bsc#994771 bsc#994774 bsc#996441 bsc#997858
  bsc#999212
  bsc#1001151 bsc#1002116 bsc#1005353 boo#1007263 bsc#1007769
  bsc#1008519 bsc#1009109 bsc#1013285 bsc#1013341 bsc#1013764
  bsc#1013767 bsc#1014109 bsc#1014110 bsc#1014111 bsc#1014112
  bsc#1014256 bsc#1014514 bsc#1014702 bsc#1015169 bsc#1016779
  * CVE-2014-0222 CVE-2014-0223 CVE-2014-3461 CVE-2014-3640 CVE-2014-7840
  CVE-2014-8106 CVE-2015-1779 CVE-2015-3209 CVE-2015-4037 CVE-2015-5154
  CVE-2015-5225 CVE-2015-5278 CVE-2015-5279 CVE-2015-5745 CVE-2015-6815
  CVE-2015-6855 CVE-2015-7295 CVE-2015-7512 CVE-2015-7549 CVE-2015-8345
  CVE-2015-8504 CVE-2015-8558 CVE-2015-8567 CVE-2015-8568 CVE-2015-8613
  CVE-2015-8619 CVE-2015-8743 CVE-2015-8744 CVE-2015-8745 CVE-2016-1568
  CVE-2016-1714 CVE-2016-1922 CVE-2016-1981 CVE-2016-2198 CVE-2016-3710
  CVE-2016-6490 CVE-2016-6833 CVE-2016-6888 CVE-2016-7116 CVE-2016-7155
  CVE-2016-7161 CVE-2016-9381 CVE-2016-9776 CVE-2016-9845 CVE-2016-9846
  CVE-2016-9907 CVE-2016-9908 CVE-2016-9911 CVE-2016-9912 CVE-2016-9913
  CVE-2016-9921 CVE-2016-9922
* Fri Jan 13 2017 brogers@suse.com
- Despite the previous entry about re-enabling ceph on Nov 19, 2016
  the change wasn't actually done. Do it now.
* Wed Jan 11 2017 afaerber@suse.de
- sgabios-stable-buildid.patch: Use geeko@buildhost
* Mon Nov 28 2016 afaerber@suse.de
- slof_xhci.patch: XHCI fixes (boo#977027)
* Mon Nov 28 2016 afaerber@suse.de
- Recommend x86 ROMs for emulated PCI cards on ppc, arm, others
  (bsc#1005869, michals)
* Tue Nov 22 2016 afaerber@suse.de
- Tidy SLOF patch boilerplate (michals)
* Mon Nov 21 2016 afaerber@suse.de
- Build with spice on all archs. (boo#1009438, michals)
* Sat Nov 19 2016 brogers@suse.com
- Refine the approach to producing stable builds in our ROM based
  packages. All built roms which have hostname or date calls now
  produce consistent results build to build via patch changes, so
  remove the hostname and date call workarounds. (bsc#1011213)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0069-roms-Makefile-pass-a-packaging-time.patch
  sgabios-stable-buildid.patch
* Sat Nov 19 2016 brogers@suse.com
- Re-enable ceph (rbd) functionality in OBS builds as we've been told
  the issues which prompted us to disable it are resolved
- Address various security/stability issues
  * Fix OOB access in VMware SVGA emulation (CVE-2016-7170 bsc#998516)
  0041-vmsvga-correct-bitmap-and-pixmap-si.patch
  * Fix DOS in LSI SAS1068 emulation (CVE-2016-7157 bsc#997860)
  0042-scsi-mptconfig-fix-an-assert-expres.patch
  0043-scsi-mptconfig-fix-misuse-of-MPTSAS.patch
  * Fix DOS in Vmware pv scsi interface (CVE-2016-7156 bsc#997859)
  0044-scsi-pvscsi-limit-loop-to-fetch-SG-.patch
  * Fix DOS in USB xHCI emulation (CVE-2016-7466 bsc#1000345)
  0045-usb-xhci-fix-memory-leak-in-usb_xhc.patch
  * Fix OOB access in LSI SAS1068 emulation (CVE-2016-7423 bsc#1000397)
  0046-scsi-mptsas-use-g_new0-to-allocate-.patch
  * Fix DOS in Vmware pv scsi interface (CVE-2016-7421 bsc#999661)
  0047-scsi-pvscsi-limit-process-IO-loop-t.patch
  * Fix NULL pointer dereference in virtio processing
  (CVE-2016-7422 bsc#1000346)
  0048-virtio-add-check-for-descriptor-s-m.patch
  * Fix DOS in ColdFire Fast Ethernet Controller emulation
  (CVE-2016-7908 bsc#1002550)
  0049-net-mcf-limit-buffer-descriptor-cou.patch
  * Fix DOS in USB EHCI emulation (CVE-2016-7995 bsc#1003612)
  0050-usb-ehci-fix-memory-leak-in-ehci_pr.patch
  * Fix DOS in USB xHCI emulation (CVE-2016-8576 bsc#1003878)
  0051-xhci-limit-the-number-of-link-trbs-.patch
  * Fix DOS in virtio-9pfs (CVE-2016-8578 bsc#1003894)
  0052-9pfs-allocate-space-for-guest-origi.patch
  * Fix DOS in virtio-9pfs (CVE-2016-9105 bsc#1007494)
  0053-9pfs-fix-memory-leak-in-v9fs_link.patch
  * Fix DOS in virtio-9pfs (CVE-2016-8577 bsc#1003893)
  0054-9pfs-fix-potential-host-memory-leak.patch
  * Plug data leak in virtio-9pfs interface (CVE-2016-9103 bsc#1007454)
  0055-9pfs-fix-information-leak-in-xattr-.patch
  * Fix DOS in virtio-9pfs interface (CVE-2016-9102 bsc#1007450)
  0056-9pfs-fix-memory-leak-in-v9fs_xattrc.patch
  * Fix DOS in virtio-9pfs (CVE-2016-9106 bsc#1007495)
  0057-9pfs-fix-memory-leak-in-v9fs_write.patch
  * Fix DOS in 16550A UART emulation (CVE-2016-8669 bsc#1004707)
  0058-char-serial-check-divider-value-aga.patch
  * Fix DOS in PC-Net II emulation (CVE-2016-7909 bsc#1002557)
  0059-net-pcnet-check-rx-tx-descriptor-ri.patch
  * Fix DOS in PRO100 emulation (CVE-2016-9101 bsc#1007391)
  0060-net-eepro100-fix-memory-leak-in-dev.patch
  * Fix OOB access in Rocker switch emulation (CVE-2016-8668 bsc#1004706)
  0061-net-rocker-set-limit-to-DMA-buffer-.patch
  * Plug data leak in vmxnet3 emulation (CVE-2016-6836 bsc#994760)
  0062-net-vmxnet-initialise-local-tx-desc.patch
  * Fix DOS in RTL8139 emulation (CVE-2016-8910 bsc#1006538)
  0063-net-rtl8139-limit-processing-of-rin.patch
  * Fix DOS in Intel HDA controller emulation (CVE-2016-8909 bsc#1006536)
  0064-audio-intel-hda-check-stream-entry-.patch
  * Fix DOS in virtio-gpu (CVE-2016-7994 bsc#1003613)
  0065-virtio-gpu-fix-memory-leak-in-virti.patch
  * Fix DOS in virtio-9pfs (CVE-2016-9104 bsc#1007493)
  0066-9pfs-fix-integer-overflow-issue-in-.patch
  * Fix DOS in JAZZ RC4030 emulation (CVE-2016-8667 bsc#1004702)
  0067-dma-rc4030-limit-interval-timer-rel.patch
  * Fix DOS in i.MX NIC emulation (CVE-2016-7907 bsc#1002549)
  0068-net-imx-limit-buffer-descriptor-cou.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
* Fri Nov 11 2016 ohering@suse.de
- Use fixed timestamps and stable build_id in ipxe and other ROMs
  * Patches added:
  ipxe-stable-buildid.patch
* Mon Nov  7 2016 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patch updated:
  0040-linux-user-skip-0-flag-from-proc-se.patch -> 0040-linux-user-remove-all-traces-of-qem.patch
* Tue Sep 27 2016 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0040-linux-user-skip-0-flag-from-proc-se.patch
* Thu Sep 22 2016 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0039-Fix-tlb_vaddr_to_host-with-CONFIG_U.patch
* Wed Sep 21 2016 afaerber@suse.de
- Document two new options, but leave jemalloc disabled for now
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches dropped:
  0034-build-link-with-libatomic-on-powerp.patch
  * Patches renamed:
  0035-xen-SUSE-xenlinux-unplug-for-emulat.patch -> 0034-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0036-qemu-bridge-helper-reduce-security-.patch -> 0035-qemu-bridge-helper-reduce-security-.patch
  0037-qemu-binfmt-conf-use-qemu-ARCH-binf.patch -> 0036-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0038-configure-Fix-detection-of-seccomp-.patch -> 0037-configure-Fix-detection-of-seccomp-.patch
  0039-linux-user-properly-test-for-infini.patch -> 0038-linux-user-properly-test-for-infini.patch
* Sat Sep 10 2016 afaerber@suse.de
- Updated to v2.7.0: See http://wiki.qemu-project.org/ChangeLog/2.7
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0039-linux-user-properly-test-for-infini.patch
* Tue Sep  6 2016 brogers@suse.com
- Use new kvm_stat package where available, else provide updated
  kvm_stat script.
* Wed Aug 31 2016 afaerber@suse.de
- Update to v2.7.0-rc5: See http://wiki.qemu-project.org/ChangeLog/2.7
* Tue Aug 23 2016 afaerber@suse.de
- Updated to v2.7.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.7
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches dropped:
  0002-qemu-0.9.0.cvs-binfmt.patch (script rewritten upstream)
  0009-block-vmdk-Support-creation-of-SCSI.patch (deprecated)
  0014-linux-user-Ignore-broken-loop-ioctl.patch (implemented upstream)
  0024-linux-user-add-more-blk-ioctls.patch (more implemented upstream)
  0034-qtest-Increase-socket-timeout.patch (increased further upstream)
  0036-configure-Enable-libseccomp-for-ppc.patch (enabled upstream)
  0038-block-split-large-discard-requests-.patch
  0041-xen-introduce-dummy-system-device.patch
  0042-xen-write-information-about-support.patch
  0043-xen-add-pvUSB-backend.patch
  0044-xen-move-xen_sysdev-to-xen_backend..patch
  0045-vnc-add-configurable-keyboard-delay.patch
  0046-configure-add-echo_version-helper.patch
  0047-configure-support-vte-2.91.patch
  0048-hw-arm-virt-mark-the-PCIe-host-cont.patch
  0050-scsi-esp-fix-migration.patch
  0051-xen-when-removing-a-backend-don-t-r.patch
  0052-xen-drain-submit-queue-in-xen-usb-b.patch
  0053-qcow2-avoid-extra-flushes-in-qcow2.patch
  0055-xen-use-a-common-function-for-pv-an.patch
  ipxe-ath9k-Fix-buffer-overrun-for-ar9287.patch
  ipxe-mucurses-Fix-GCC-6-nonnull-compare-errors.patch
  ipxe-sis190-Fix-building-with-GCC-6.patch
  ipxe-skge-Fix-building-with-GCC-6.patch
  ipxe-ath-Fix-building-with-GCC-6.patch
  ipxe-legacy-Fix-building-with-GCC-6.patch
  ipxe-util-v5.24-perl-errors-on-redeclare.patch
  ipxe-efi-fix-garbage-bytes-in-device-path.patch
  ipxe-efi-fix-uninitialised-data-in-HII.patch
  * Patches renamed:
  0010-linux-user-add-binfmt-wrapper-for-a.patch -> 0009-linux-user-add-binfmt-wrapper-for-a.patch
  0011-PPC-KVM-Disable-mmu-notifier-check.patch  -> 0010-PPC-KVM-Disable-mmu-notifier-check.patch
  0012-linux-user-fix-segfault-deadlock.patch    -> 0011-linux-user-fix-segfault-deadlock.patch
  0013-linux-user-binfmt-support-host-bina.patch -> 0012-linux-user-binfmt-support-host-bina.patch
  0015-linux-user-lock-tcg.patch                 -> 0013-linux-user-lock-tcg.patch
  0016-linux-user-Run-multi-threaded-code-.patch -> 0014-linux-user-Run-multi-threaded-code-.patch
  0017-linux-user-lock-tb-flushing-too.patch     -> 0015-linux-user-lock-tb-flushing-too.patch
  0018-linux-user-Fake-proc-cpuinfo.patch        -> 0016-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-implement-FS_IOC_GETFLAG.patch -> 0017-linux-user-implement-FS_IOC_GETFLAG.patch
  0020-linux-user-implement-FS_IOC_SETFLAG.patch -> 0018-linux-user-implement-FS_IOC_SETFLAG.patch
  0021-linux-user-XXX-disable-fiemap.patch       -> 0019-linux-user-XXX-disable-fiemap.patch
  0022-slirp-nooutgoing.patch                    -> 0020-slirp-nooutgoing.patch
  0023-vnc-password-file-and-incoming-conn.patch -> 0021-vnc-password-file-and-incoming-conn.patch
  0025-linux-user-use-target_ulong.patch         -> 0022-linux-user-use-target_ulong.patch
  0026-block-Add-support-for-DictZip-enabl.patch -> 0023-block-Add-support-for-DictZip-enabl.patch
  0027-block-Add-tar-container-format.patch      -> 0024-block-Add-tar-container-format.patch
  0028-Legacy-Patch-kvm-qemu-preXX-dictzip.patch -> 0025-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0029-console-add-question-mark-escape-op.patch -> 0026-console-add-question-mark-escape-op.patch
  0030-Make-char-muxer-more-robust-wrt-sma.patch -> 0027-Make-char-muxer-more-robust-wrt-sma.patch
  0031-linux-user-lseek-explicitly-cast-no.patch -> 0028-linux-user-lseek-explicitly-cast-no.patch
  0032-virtfs-proxy-helper-Provide-__u64-f.patch -> 0029-virtfs-proxy-helper-Provide-__u64-f.patch
  0033-configure-Enable-PIE-for-ppc-and-pp.patch -> 0030-configure-Enable-PIE-for-ppc-and-pp.patch
  0035-AIO-Reduce-number-of-threads-for-32.patch -> 0031-AIO-Reduce-number-of-threads-for-32.patch
  0037-dictzip-Fix-on-big-endian-systems.patch   -> 0032-dictzip-Fix-on-big-endian-systems.patch
  0039-xen_disk-Add-suse-specific-flush-di.patch -> 0033-xen_disk-Add-suse-specific-flush-di.patch
  0040-build-link-with-libatomic-on-powerp.patch -> 0034-build-link-with-libatomic-on-powerp.patch
  0049-xen-SUSE-xenlinux-unplug-for-emulat.patch -> 0035-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0054-qemu-bridge-helper-reduce-security-.patch -> 0036-qemu-bridge-helper-reduce-security-.patch
  * Patches added:
  0002-qemu-binfmt-conf-Modify-default-pat.patch
  0037-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  * Package renamed trace-events-all file and linuxboot_dma.bin
  * Handle building and packaging roms for e1000e and vmxnet3 (Bruce)
  * Remove ipxe patches which are now enabled upstream (Bruce)
  * Enable seccomp for s390x (Mark Post):
  0038-configure-Fix-detection-of-seccomp-.patch
* Wed Aug 17 2016 brogers@suse.com
- Update to v2.6.1 a stable, bug-fix-only release (fate#316228)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped (upstreamed):
  0041-net-mipsnet-check-packet-length-aga.patch
  0042-i386-kvmvapic-initialise-imm32-vari.patch
  0043-esp-check-command-buffer-length-bef.patch
  0044-esp-check-dma-length-before-reading.patch
  0045-scsi-pvscsi-check-command-descripto.patch
  0046-scsi-mptsas-infinite-loop-while-fet.patch
  0047-vga-add-sr_vbe-register-set.patch
  0048-scsi-megasas-use-appropriate-proper.patch
  0049-scsi-megasas-check-read_queue_head-.patch
  0050-scsi-megasas-null-terminate-bios-ve.patch
  0051-vmsvga-move-fifo-sanity-checks-to-v.patch
  0052-vmsvga-don-t-process-more-than-1024.patch
  0053-block-iscsi-avoid-potential-overflo.patch
  0054-scsi-esp-check-TI-buffer-index-befo.patch
  0060-scsi-megasas-initialise-local-confi.patch
  0065-scsi-esp-check-buffer-length-before.patch
  0066-scsi-esp-respect-FIFO-invariant-aft.patch
  0067-pci-assign-Move-Invalid-ROM-error-m.patch
  0068-Xen-PCI-passthrough-fix-passthrough.patch
  0069-scsi-esp-make-cmdbuf-big-enough-for.patch
  0071-virtio-error-out-if-guest-exceeds-v.patch
  * Patches renamed:
  0055-xen-introduce-dummy-system-device.patch
  - > 0041-xen-introduce-dummy-system-device.patch
  0056-xen-write-information-about-support.patch
  - > 0042-xen-write-information-about-support.patch
  0057-xen-add-pvUSB-backend.patch
  - > 0043-xen-add-pvUSB-backend.patch
  0058-xen-move-xen_sysdev-to-xen_backend..patch
  - > 0044-xen-move-xen_sysdev-to-xen_backend..patch
  0059-vnc-add-configurable-keyboard-delay.patch
  - > 0045-vnc-add-configurable-keyboard-delay.patch
  0061-configure-add-echo_version-helper.patch
  - > 0046-configure-add-echo_version-helper.patch
  0062-configure-support-vte-2.91.patch
  - > 0047-configure-support-vte-2.91.patch
  0063-hw-arm-virt-mark-the-PCIe-host-cont.patch
  - > 0048-hw-arm-virt-mark-the-PCIe-host-cont.patch
  0064-xen-SUSE-xenlinux-unplug-for-emulat.patch
  - > 0049-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0070-scsi-esp-fix-migration.patch
  - > 0050-scsi-esp-fix-migration.patch
  0072-xen-when-removing-a-backend-don-t-r.patch
  - > 0051-xen-when-removing-a-backend-don-t-r.patch
  0073-xen-drain-submit-queue-in-xen-usb-b.patch
  - > 0052-xen-drain-submit-queue-in-xen-usb-b.patch
  0074-qcow2-avoid-extra-flushes-in-qcow2.patch
  - > 0053-qcow2-avoid-extra-flushes-in-qcow2.patch
  0075-qemu-bridge-helper-reduce-security-.patch
  - > 0054-qemu-bridge-helper-reduce-security-.patch
  0076-xen-use-a-common-function-for-pv-an.patch
  - > 0055-xen-use-a-common-function-for-pv-an.patch
* Wed Aug  3 2016 brogers@suse.com
- Temporarily disable ceph (rbd) functionality in OBS due to staging
  issues.
* Wed Aug  3 2016 brogers@suse.com
- use upstream solution for building xen-usb.c correctly
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped:
  0058-usb-Fix-conditions-that-xen-usb.c-i.patch
  * Patches added:
  0058-xen-move-xen_sysdev-to-xen_backend..patch
* Wed Aug  3 2016 brogers@suse.com
- Incorporate patch carried in Xen's qemu to get same support
  as Xen switches to use the qemu package (bsc#953339, bsc#953362,
  bsc#953518, bsc#984981)
  0064-xen-SUSE-xenlinux-unplug-for-emulat.patch
- Fix more potential OOB accesses in 53C9X emulation
  (CVE-2016-5238 bsc#982959)
  0065-scsi-esp-check-buffer-length-before.patch
  0066-scsi-esp-respect-FIFO-invariant-aft.patch
- Avoid "Invalid ROM" error message when it is not appropriate
  (bsc#982927)
  0067-pci-assign-Move-Invalid-ROM-error-m.patch
- Fix failure in Xen HVM PCI passthrough (bsc#981925, bsc#989250)
  0068-Xen-PCI-passthrough-fix-passthrough.patch
- Fix OOB access in 53C9X emulation (CVE-2016-6351 bsc#990835)
  0069-scsi-esp-make-cmdbuf-big-enough-for.patch
  0070-scsi-esp-fix-migration.patch
- Avoid potential for guest initiated OOM condition in qemu through
  virtio interface (CVE-2016-5403 bsc#991080)
  0071-virtio-error-out-if-guest-exceeds-v.patch
- Fix potential crashes in qemu from pvusb bugs (bsc#986156)
  0072-xen-when-removing-a-backend-don-t-r.patch
  0073-xen-drain-submit-queue-in-xen-usb-b.patch
- Avoid unneeded flushes in qcow2 which impact performance (bsc#991296)
  0074-qcow2-avoid-extra-flushes-in-qcow2.patch
- Finally get qemu-bridge-helper the permissions it needs for non-
  root usage. The kvm group is leveraged to control access. (boo#988279)
  0075-qemu-bridge-helper-reduce-security-.patch
- Fix pvusb not working for HVM guests (bsc#991785)
  0076-xen-use-a-common-function-for-pv-an.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
- Minor spec file formatting fixes
* Thu Jul 28 2016 agraf@suse.com
- Fix ARM PCIe DMA coherency bug (bsc#991034)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches added:
  0063-hw-arm-virt-mark-the-PCIe-host-cont.patch
* Tue Jul 19 2016 afaerber@suse.de
- Clean up the udev ifdeffery to cover systemd as well (boo#860275)
- Trigger udev rules also under systemd (boo#989655)
- Suppress s390x sysctl in chroot
- Ignore s390x sysctl failures (agraf)
* Thu Jul 14 2016 brogers@suse.com
- Build SLOF for SLE12 now that we have gcc fix (bsc#949000)
- Add script for loading kvm module on s390x
- Enable seccomp and iscsi support in more configurations
- Enable more support for virtio-gpu
- Fix /dev/kvm permissions problem with package install and no
  reboot (bnc#867867)
- Remove libtool dependency
- Disable more aggressive stack protector for performance reasons
- Enable vte to be used again in more configurations (bsc#988855)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches added:
  0061-configure-add-echo_version-helper.patch
  0062-configure-support-vte-2.91.patch
* Thu Jul 14 2016 agraf@suse.com
- Remove deprecated patch "work-around-SA_RESTART-race" (boo#982208)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped:
  0002-XXX-work-around-SA_RESTART-race-wit.patch
  0003-qemu-0.9.0.cvs-binfmt.patch
  0004-qemu-cvs-alsa_bitfield.patch
  0005-qemu-cvs-alsa_ioctl.patch
  0006-qemu-cvs-alsa_mmap.patch
  0007-qemu-cvs-gettimeofday.patch
  0008-qemu-cvs-ioctl_debug.patch
  0009-qemu-cvs-ioctl_nodirection.patch
  0010-block-vmdk-Support-creation-of-SCSI.patch
  0011-linux-user-add-binfmt-wrapper-for-a.patch
  0012-PPC-KVM-Disable-mmu-notifier-check.patch
  0013-linux-user-fix-segfault-deadlock.patch
  0014-linux-user-binfmt-support-host-bina.patch
  0015-linux-user-Ignore-broken-loop-ioctl.patch
  0016-linux-user-lock-tcg.patch
  0017-linux-user-Run-multi-threaded-code-.patch
  0018-linux-user-lock-tb-flushing-too.patch
  0019-linux-user-Fake-proc-cpuinfo.patch
  0020-linux-user-implement-FS_IOC_GETFLAG.patch
  0021-linux-user-implement-FS_IOC_SETFLAG.patch
  0022-linux-user-XXX-disable-fiemap.patch
  0023-slirp-nooutgoing.patch
  0024-vnc-password-file-and-incoming-conn.patch
  0025-linux-user-add-more-blk-ioctls.patch
  0026-linux-user-use-target_ulong.patch
  0027-block-Add-support-for-DictZip-enabl.patch
  0028-block-Add-tar-container-format.patch
  0029-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0030-console-add-question-mark-escape-op.patch
  0031-Make-char-muxer-more-robust-wrt-sma.patch
  0032-linux-user-lseek-explicitly-cast-no.patch
  0033-virtfs-proxy-helper-Provide-__u64-f.patch
  0034-configure-Enable-PIE-for-ppc-and-pp.patch
  0035-qtest-Increase-socket-timeout.patch
  0036-AIO-Reduce-number-of-threads-for-32.patch
  0037-configure-Enable-libseccomp-for-ppc.patch
  0038-dictzip-Fix-on-big-endian-systems.patch
  0039-block-split-large-discard-requests-.patch
  0040-xen_disk-Add-suse-specific-flush-di.patch
  0041-build-link-with-libatomic-on-powerp.patch
  0042-net-mipsnet-check-packet-length-aga.patch
  0043-i386-kvmvapic-initialise-imm32-vari.patch
  0044-esp-check-command-buffer-length-bef.patch
  0045-esp-check-dma-length-before-reading.patch
  0046-scsi-pvscsi-check-command-descripto.patch
  0047-scsi-mptsas-infinite-loop-while-fet.patch
  0048-vga-add-sr_vbe-register-set.patch
  0049-scsi-megasas-use-appropriate-proper.patch
  0050-scsi-megasas-check-read_queue_head-.patch
  0051-scsi-megasas-null-terminate-bios-ve.patch
  0052-vmsvga-move-fifo-sanity-checks-to-v.patch
  0053-vmsvga-don-t-process-more-than-1024.patch
  0054-block-iscsi-avoid-potential-overflo.patch
  0055-scsi-esp-check-TI-buffer-index-befo.patch
  0056-xen-introduce-dummy-system-device.patch
  0057-xen-write-information-about-support.patch
  0058-xen-add-pvUSB-backend.patch
  0059-usb-Fix-conditions-that-xen-usb.c-i.patch
  0060-vnc-add-configurable-keyboard-delay.patch
  0061-scsi-megasas-initialise-local-confi.patch
  * Patches added:
  0002-qemu-0.9.0.cvs-binfmt.patch
  0003-qemu-cvs-alsa_bitfield.patch
  0004-qemu-cvs-alsa_ioctl.patch
  0005-qemu-cvs-alsa_mmap.patch
  0006-qemu-cvs-gettimeofday.patch
  0007-qemu-cvs-ioctl_debug.patch
  0008-qemu-cvs-ioctl_nodirection.patch
  0009-block-vmdk-Support-creation-of-SCSI.patch
  0010-linux-user-add-binfmt-wrapper-for-a.patch
  0011-PPC-KVM-Disable-mmu-notifier-check.patch
  0012-linux-user-fix-segfault-deadlock.patch
  0013-linux-user-binfmt-support-host-bina.patch
  0014-linux-user-Ignore-broken-loop-ioctl.patch
  0015-linux-user-lock-tcg.patch
  0016-linux-user-Run-multi-threaded-code-.patch
  0017-linux-user-lock-tb-flushing-too.patch
  0018-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-implement-FS_IOC_GETFLAG.patch
  0020-linux-user-implement-FS_IOC_SETFLAG.patch
  0021-linux-user-XXX-disable-fiemap.patch
  0022-slirp-nooutgoing.patch
  0023-vnc-password-file-and-incoming-conn.patch
  0024-linux-user-add-more-blk-ioctls.patch
  0025-linux-user-use-target_ulong.patch
  0026-block-Add-support-for-DictZip-enabl.patch
  0027-block-Add-tar-container-format.patch
  0028-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0029-console-add-question-mark-escape-op.patch
  0030-Make-char-muxer-more-robust-wrt-sma.patch
  0031-linux-user-lseek-explicitly-cast-no.patch
  0032-virtfs-proxy-helper-Provide-__u64-f.patch
  0033-configure-Enable-PIE-for-ppc-and-pp.patch
  0034-qtest-Increase-socket-timeout.patch
  0035-AIO-Reduce-number-of-threads-for-32.patch
  0036-configure-Enable-libseccomp-for-ppc.patch
  0037-dictzip-Fix-on-big-endian-systems.patch
  0038-block-split-large-discard-requests-.patch
  0039-xen_disk-Add-suse-specific-flush-di.patch
  0040-build-link-with-libatomic-on-powerp.patch
  0041-net-mipsnet-check-packet-length-aga.patch
  0042-i386-kvmvapic-initialise-imm32-vari.patch
  0043-esp-check-command-buffer-length-bef.patch
  0044-esp-check-dma-length-before-reading.patch
  0045-scsi-pvscsi-check-command-descripto.patch
  0046-scsi-mptsas-infinite-loop-while-fet.patch
  0047-vga-add-sr_vbe-register-set.patch
  0048-scsi-megasas-use-appropriate-proper.patch
  0049-scsi-megasas-check-read_queue_head-.patch
  0050-scsi-megasas-null-terminate-bios-ve.patch
  0051-vmsvga-move-fifo-sanity-checks-to-v.patch
  0052-vmsvga-don-t-process-more-than-1024.patch
  0053-block-iscsi-avoid-potential-overflo.patch
  0054-scsi-esp-check-TI-buffer-index-befo.patch
  0055-xen-introduce-dummy-system-device.patch
  0056-xen-write-information-about-support.patch
  0057-xen-add-pvUSB-backend.patch
  0058-usb-Fix-conditions-that-xen-usb.c-i.patch
  0059-vnc-add-configurable-keyboard-delay.patch
  0060-scsi-megasas-initialise-local-confi.patch
- Enable ceph (rbd) support for aarch64
* Tue Jul 12 2016 brogers@suse.com
- Enable ceph (rbd) support
* Mon Jul  4 2016 glin@suse.com
- Fix OVMF iPXE network menu (bsc#986033, boo#987488)
  ipxe-efi-fix-garbage-bytes-in-device-path.patch
  ipxe-efi-fix-uninitialised-data-in-HII.patch
* Fri Jun 10 2016 brogers@suse.com
- Fix host information leak to guest in MegaRAID SAS 8708EM2 Host
  Bus AdapterMegaRAID SAS 8708EM2 Host Bus Adapter emulation support
  (CVE-2016-5105 bsc#982017)
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  0061-scsi-megasas-initialise-local-confi.patch
* Fri Jun 10 2016 brogers@suse.com
- Address various security/stability issues
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Fix OOB access in megasas emulated device (CVE-2016-5106 bsc#982018)
  0049-scsi-megasas-use-appropriate-proper.patch
  * Fix OOB access in megasas emulated device (CVE-2016-5107 bsc#982019)
  0050-scsi-megasas-check-read_queue_head-.patch
  * Fix OOB access in megasas emulated device (CVE-2016-5337 bsc#983961)
  0051-scsi-megasas-null-terminate-bios-ve.patch
  * Correct the vmvga fifo access checks (CVE-2016-4454 bsc#982222)
  0052-vmsvga-move-fifo-sanity-checks-to-v.patch
  * Fix potential DoS issue in vmvga processing (CVE-2016-4453 bsc#982223)
  0053-vmsvga-don-t-process-more-than-1024.patch
  * Fix heap buffer overflow flaw when iscsi protocol is used
  (CVE-2016-5126 bsc#982285)
  0054-block-iscsi-avoid-potential-overflo.patch
  * Fix OOB access in 53C9X emulation (CVE-2016-5338 bsc#983982)
  0055-scsi-esp-check-TI-buffer-index-befo.patch
- Add support to qemu for pv-usb under Xen (fate#316612)
  0056-xen-introduce-dummy-system-device.patch
  0057-xen-write-information-about-support.patch
  0058-xen-add-pvUSB-backend.patch
  0059-usb-Fix-conditions-that-xen-usb.c-i.patch
- Provide ability to rate limit keyboard events from the vnc server.
  This is part of the solution to an issue affecting openQA testing,
  where characters are lost, resulting in unexpected failures
  (bsc#974914)
  0060-vnc-add-configurable-keyboard-delay.patch
* Fri Jun  3 2016 brogers@suse.com
- Adjust to parallel changes in virglrenderer packages - no longer
  "BuildRequires" virglrenderer directly, just the devel package.
* Wed Jun  1 2016 brogers@suse.com
- Fix build compatibility with gcc6 wrt ipxe rom where compiler
  warnings are treated as errors.
  ipxe-ath9k-Fix-buffer-overrun-for-ar9287.patch
  ipxe-mucurses-Fix-GCC-6-nonnull-compare-errors.patch
  ipxe-sis190-Fix-building-with-GCC-6.patch
  ipxe-skge-Fix-building-with-GCC-6.patch
  ipxe-ath-Fix-building-with-GCC-6.patch
  ipxe-legacy-Fix-building-with-GCC-6.patch
- Fix ipxe build script which fails under perl v5.24
  ipxe-util-v5.24-perl-errors-on-redeclare.patch
- Specify build time disk space requirements for ppc64 and ppc64le
* Wed Jun  1 2016 agraf@suse.com
- Add sysctl script and %%post on s390x to allow kvm usage (bsc#975331)
* Thu May 26 2016 brogers@suse.com
- Address various security/stability issues
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Fix OOB access in MIPSnet emulated controller CVE-2016-4002 (bsc#975136)
  0042-net-mipsnet-check-packet-length-aga.patch
  * Fix possible host data leakage to guest from TPR access
  CVE-2016-4020 (bsc#975700)
  0043-i386-kvmvapic-initialise-imm32-vari.patch
  * Avoid OOB access in 53C9X emulation CVE-2016-4439 (bsc#980711)
  0044-esp-check-command-buffer-length-bef.patch
  * Avoid OOB access in 53C9X emulation CVE-2016-4441 (bsc#980723)
  0045-esp-check-dma-length-before-reading.patch
  * Avoid OOB access in Vmware PV SCSI emulation CVE-2016-4952 (bsc#981266)
  0046-scsi-pvscsi-check-command-descripto.patch
  * Avoid potential DoS in LSI SAS1068 emulation CVE-2016-4964 (bsc#981399)
  0047-scsi-mptsas-infinite-loop-while-fet.patch
  * Fix regression in vga behavior - introduced in v2.6.0 CVE-2016-3712 (bsc#978160)
  0048-vga-add-sr_vbe-register-set.patch
* Wed May 25 2016 brogers@suse.com
- Update to v2.6.0: See http://wiki.qemu-project.org/ChangeLog/2.6
- Enable SDL2, virglrenderer (for use with virtio-gpu), xfsctl, and
  tracing using default log backend
- Build efi pxe roms on x86_64
* Thu Apr 28 2016 afaerber@suse.de
- Check modules for conflicting release versions
- Suggest recently added block modules
* Thu Apr 28 2016 afaerber@suse.de
- Bump copyright in qemu.spec.in
- Enable libiscsi for Factory
- Enable seccomp for ppc64le as well
* Fri Apr 22 2016 afaerber@suse.de
- Update to v2.6.0-rc3: See http://wiki.qemu-project.org/ChangeLog/2.6
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped (upstreamed):
  0041-tests-Use-correct-config-param-for-.patch
  * Patches renamed:
  0042-build-link-with-libatomic-on-powerp.patch -> 0041-build-link-with-libatomic-on-powerp.patch
* Wed Apr 20 2016 afaerber@suse.de
- Partially revert the last change's cleanup
- Indicate SUSE version
* Fri Apr  1 2016 olaf@aepfle.de
- Update to v2.6.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.6
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Accept every size in DISCARD request from a guest (bsc#964427)
  0039-block-split-large-discard-requests-.patch
  * Recognize libxl flag to disable flush in block device (bsc#879425)
  0040-xen_disk-Add-suse-specific-flush-di.patch
  * Use correct flag for crypto tests
  0041-tests-Use-correct-config-param-for-.patch
  * Fix build on powerpc:
  0042-build-link-with-libatomic-on-powerp.patch
  * Patches dropped (upstreamed):
  seabios_checkrom_typo.patch
  seabios_avoid_smbios_signature_string.patch
* Tue Feb  9 2016 afaerber@suse.de
- Disable vte for Leap, fixing build
* Wed Jan 27 2016 afaerber@suse.de
- Don't drop u-boot.e500 yet - breaks testsuite
* Thu Jan 21 2016 afaerber@suse.de
- Re-enable libcacard support
- Clean up configured features
* Thu Jan 21 2016 afaerber@suse.de
- Clean up qemu-tools libcacard Provides/Obsoletes - separate again
- Drop u-boot.e500 - being packaged as u-boot-ppce500
* Fri Jan  8 2016 afaerber@suse.de
- Update to v2.5.0: See http://wiki.qemu-project.org/ChangeLog/2.5
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.5
  * Patches dropped (upstreamed):
  0039-tests-Fix-check-report-qtest-target.patch
* Tue Dec 29 2015 stefan.bruens@rwth-aachen.de
- Fix build on openSUSE 13.2
* Tue Dec  1 2015 agraf@suse.com
- Fix testsuite on 32bit systems (bsc#957379)
* Sun Nov 22 2015 afaerber@suse.de
- Update to v2.5.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.5
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.5
  * Rebase libseccomp enablement:
  0037-Revert-Revert-seccomp-tests-that-al.patch -> 0037-configure-Enable-libseccomp-for-ppc.patch
  * Provide qemu-ga and qemu-ipxe for qemu-testsuite
- Clean up qemu-ksm recommendation
* Sun Nov 22 2015 afaerber@suse.de
- Fix SLE11 build by fixing systemd conditionalization (from olh)
* Thu Nov 19 2015 afaerber@suse.de
- Update to v2.5.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.5
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.5
  * Patches dropped (upstream):
  0038-tcg-aarch64-Fix-tcg_out_qemu_-ld-st.patch
  0039-tests-Unique-test-path-for-string-v.patch
  gcc5-ipxe-add-missing-const-qualifiers.patch
  gcc5-ipxe-ath9k-Remove-confusing-logic-inversion-in-an-ANI-var.patch
  SLOF_ppc64le.patch
  * Patch renamed:
  0040-dictzip-Fix-on-big-endian-systems.patch -> 0038-dictzip-Fix-on-big-endian-systems.patch
  * --enable-smartcard-nss -> --enable-smartcard
  Needs an external libcacard, so drop it for now.
  * Drop --enable-vnc-tls
  * Require xz-devel for ipxe build
  * Package qemu-ga(8) man page
  * Package ivshmem-{client,server}
  * Patches added:
  0039-tests-Fix-check-report-qtest-target.patch
* Thu Nov 19 2015 tampakrap@opensuse.org
- Add systemd unit file and udev rules for qemu guest agent
  - taken from the SLE12 / Leap package, see boo#955707
* Wed Oct 28 2015 afaerber@suse.de
- Add _constraints file (based on work by kenljohnson)
* Tue Oct 20 2015 afaerber@suse.de
- Enable SLOF build for ppc64le, too, now (bsc#949000, bsc#949016)
* Mon Oct 12 2015 afaerber@suse.de
- Allow building SLOF on ppc64le (bsc#949016)
  SLOF_ppc64le.patch
- Add two checks for DictZip and tar qemu-img behavior (bsc#945778)
  * Clean up qemu-testsuite build/installation
* Thu Oct  8 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Fix endianness issues in DictZip block driver (bsc#937572, bsc#945778)
  0027-block-Add-support-for-DictZip-enabl.patch
  0028-block-Add-tar-container-format.patch
  0040-dictzip-Fix-on-big-endian-systems.patch
* Thu Oct  8 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Fix qemu-testsuite for glib2-2.46.0 by assuring uniqueness of paths
  0039-tests-Unique-test-path-for-string-v.patch
* Thu Oct  8 2015 afaerber@suse.de
- Build SLOF on ppc64 (bsc#949016, thanks to k0da)
  * Simplify x86 fw logic while at it
- No need to enable KVM for armv6hl
- Add notice about pre_checkin.sh to update_git.sh
* Thu Sep  3 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Fix aarch64 TCG:
  0038-tcg-aarch64-Fix-tcg_out_qemu_-ld-st.patch
* Wed Aug 12 2015 afaerber@suse.de
- Update to v2.4.0: See http://wiki.qemu-project.org/ChangeLog/2.4
* Fri Jul 24 2015 afaerber@suse.de
- Update to v2.4.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.4
  * Provide qemu-img symlink instead of passing QTEST_QEMU_IMG
* Fri Jul 17 2015 afaerber@suse.de
- Update to v2.4.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.4
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Patches dropped:
  0037-linux-user-Allocate-thunk-size-dyna.patch
  0039-s390x-Fix-stoc-direction.patch
  0040-s390x-Add-interlocked-access-facili.patch
  0041-fdc-force-the-fifo-access-to-be-in-.patch
  0042-rules.mak-Force-CFLAGS-for-all-obje.patch
  0043-qcow2-Set-MIN_L2_CACHE_SIZE-to-2.patch
  0044-hw-arm-boot-Increase-fdt-alignment.patch
  * Patches renamed:
  0038-Revert-Revert-seccomp-tests-that-al.patch -> 0037-Revert-Revert-seccomp-tests-that-al.patch
  * Package new vgabios-virtio.bin
  * target-x86_64.conf was dropped
  * Add qemu-block-dmg module sub-package
  * Set QTEST_QEMU_IMG variable for ahci-test
  * --enable-quorum and --enable-vnc-ws are no longer available
* Mon Jul 13 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix -kernel boot for AArch64
  * Patches added:
  0044-hw-arm-boot-Increase-fdt-alignment.patch
* Sat Jul  4 2015 crrodriguez@opensuse.org
- Use libusb-1_0-devel as buildrequires, not the old
  unused compatibility layer in libusb-devel
* Mon Jun  1 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix qemu2 cow caching (bsc#933132)
  * Patches added:
  0043-qcow2-Set-MIN_L2_CACHE_SIZE-to-2.patch
* Tue May 26 2015 jslaby@suse.com
- Patch queue updated from git://github.com/jirislaby/qemu.git opensuse-2.3
  * Patches added:
  0042-rules.mak-Force-CFLAGS-for-all-obje.patch
  gcc5-ipxe-add-missing-const-qualifiers.patch
  gcc5-ipxe-ath9k-Remove-confusing-logic-inversion-in-an-ANI-var.patch
* Thu May 14 2015 afaerber@suse.de
- Fix CVE-2015-3456 (boo#929339)
  0041-fdc-force-the-fifo-access-to-be-in-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
* Tue May 12 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches added:
  0040-s390x-Add-interlocked-access-facili.patch
- Disable dependency on libnuma for s390x (not available in SLE12)
* Wed Apr 29 2015 afaerber@suse.de
- Update to v2.3.0: See http://wiki.qemu-project.org/ChangeLog/2.3
- Disable iotests for now
* Wed Apr 22 2015 afaerber@suse.de
- Update to v2.3.0-rc4: See http://wiki.qemu-project.org/ChangeLog/2.3
* Mon Apr 20 2015 afaerber@suse.de
- Update seabios_avoid_smbios_signature_string.patch with version
  applied upstream
* Wed Apr 15 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix s390x stoc instructions
  0039-s390x-Fix-stoc-direction.patch
* Tue Apr 14 2015 afaerber@suse.de
- Update to v2.3.0-rc3: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches dropped (applied upstream):
  0037-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch
  * Patches renamed:
  0038-linux-user-Allocate-thunk-size-dyna.patch -> 0037-linux-user-Allocate-thunk-size-dyna.patch
  * Revert -rc3 change to disable seccomp on non-x86 architectures
  0038-Revert-Revert-seccomp-tests-that-al.patch
* Tue Apr 14 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix qemu-linux-user on powerpc
  * Patches added:
  0038-linux-user-Allocate-thunk-size-dyna.patch
* Sat Apr 11 2015 afaerber@suse.de
- Split off qemu-testsuite.spec
  * Package check-report.html and check-report.xml
  * Enable quick iotests
- Dropped 0030-net-Warn-about-default-MAC-address.patch
  The warning is relevant only for bridged setups, not for the
  default SLIRP based -net user / -netdev user setup,
  and it breaks output expectations of some iotests.
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches renamed:
  0031-console-add-question-mark-escape-op.patch -> 0030-console-add-question-mark-escape-op.patch
  0032-Make-char-muxer-more-robust-wrt-sma.patch -> 0031-Make-char-muxer-more-robust-wrt-sma.patch
  0033-linux-user-lseek-explicitly-cast-no.patch -> 0032-linux-user-lseek-explicitly-cast-no.patch
  0034-virtfs-proxy-helper-Provide-__u64-f.patch -> 0033-virtfs-proxy-helper-Provide-__u64-f.patch
  0035-configure-Enable-PIE-for-ppc-and-pp.patch -> 0034-configure-Enable-PIE-for-ppc-and-pp.patch
  0036-qtest-Increase-socket-timeout.patch       -> 0035-qtest-Increase-socket-timeout.patch
  0037-AIO-Reduce-number-of-threads-for-32.patch -> 0036-AIO-Reduce-number-of-threads-for-32.patch
  0038-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch -> 0037-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch
- Re-enable glusterfs on Factory (updated from v3.6.1 to v3.6.2)
- Re-enable seccomp for armv7l (libseccomp submission pending)
* Fri Apr 10 2015 afaerber@suse.de
- Suppress seccomp for Factory armv7l (broken in libseccomp v2.2.0)
- Disable glusterfs explicitly on Factory, SLE12 and before 13.1
* Thu Apr  9 2015 afaerber@suse.de
- Enable glusterfs and package as qemu-block-gluster
  glusterfs post-v3.5.3 and v3.6.1/v3.6.2 have switched the
  glusterfs-api.pc version incompatibly, so only 13.1+13.2 for now
- Use macro for module Conflicts
* Thu Apr  9 2015 afaerber@suse.de
- Tidy configure options:
  * Move --enable-modules to build options
  * Sort libusb alphabetically
  * Explicitly enable attr, bluez, fdt, lzo, tpm, vhdx, vhost-net,
  vnc, xen-pci-passthrough
  * Enable bzip2
  * Enable libssh2 where possible and package as qemu-block-ssh
  * Enable numa where a compatible numactl is available
  * Enable quorum where a compatible gnutls is available
  * Enable snappy where possible
  * Prepare to enable glusterfs
  * Explicitly enable the nop tracing backend (to be revisited)
  * Explicitly disable Archipelago, as we don't have libxseg and it's
  incompatibly GPL-3.0+
  * Explicitly disable libiscsi, libnfs, netmap and rbd
  as we don't have packages
  * Drop deprecated --enable-virtio-blk-data-plane (now default)
* Wed Apr  8 2015 afaerber@suse.de
- Fix 64-bit TCG stores on 32-bit Big Endian hosts (ppc)
  0038-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
* Wed Apr  8 2015 afaerber@suse.de
- Update to v2.3.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches dropped (upstreamed):
  0038-fw_cfg-test-Fix-test-path-to-includ.patch
  0039-rcu-tests-fix-compilation-on-32-bit.patch
* Sat Mar 28 2015 brogers@suse.com
- make check was failing due to a bogus SMBIOS signature being
  encountered within SeaBIOS. Avoid having that signature stored
  randomly within the SeaBIOS image.
  * seabios_avoid_smbios_signature_string.patch
* Thu Mar 26 2015 afaerber@suse.de
- Build x86 firmware only from 13.1 on (11.4 was broken, surpassing 128 KB)
- Update to v2.3.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches dropped (upstreamed):
  0038-linux-user-Fix-emulation-of-splice-.patch
  0039-ide-fix-cmd_write_pio-when-nsectors.patch
  0040-ide-fix-cmd_read_pio-when-nsectors-.patch
  0041-ahci-Fix-sglist-offset-manipulation.patch
  0042-ahci-test-improve-rw-buffer-pattern.patch
  0045-linux-user-fix-broken-cpu_copy.patch
  * Patches renamed:
  0043-fw_cfg-test-Fix-test-path-to-includ.patch -> 0038-fw_cfg-test-Fix-test-path-to-includ.patch
  0044-rcu-tests-fix-compilation-on-32-bit.patch -> 0039-rcu-tests-fix-compilation-on-32-bit.patch
* Mon Mar 23 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches added:
  0045-linux-user-fix-broken-cpu_copy.patch
* Sat Mar 21 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Make test path for fw_cfg-test unique (including architecture)
  0043-fw_cfg-test-Fix-test-path-to-includ.patch
  * Fix rcu tests build on ppc (undefined reference to `__sync_fetch_and_add_8')
  0044-rcu-tests-fix-compilation-on-32-bit.patch
- Fix typo in SeaBIOS size check
  seabios_checkrom_typo.patch
* Fri Mar 20 2015 afaerber@suse.de
- Update to v2.3.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Updated update_git.sh accordingly
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * seabios_128kb.patch: Added patch to squeeze SeaBIOS into 128 KB
  with our gcc 4.8.3 (brogers@suse.com)
- Renamed 0030-Legacy-Patch-kvm-qemu-preXX-report-.patch to
  0030-net-Warn-about-default-MAC-address.patch:
  Suppress warning for accel=qtest, to sanitize make check results.
- Added patches to fix ahci-test:
  0039-ide-fix-cmd_write_pio-when-nsectors.patch
  0040-ide-fix-cmd_read_pio-when-nsectors-.patch
  0041-ahci-Fix-sglist-offset-manipulation.patch
  0042-ahci-test-improve-rw-buffer-pattern.patch
* Sun Mar  1 2015 afaerber@suse.de
- Update company name in spec file templates
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.2
  * Patches added:
  0038-linux-user-Fix-emulation-of-splice-.patch
* Sun Feb 22 2015 mpluskal@suse.com
- Add user kvm when installing guest-agent.
- Use macro to update udev_rules when available
* Wed Feb 11 2015 afaerber@suse.de
- Fix packaging of e500 U-Boot
- Don't rely on wildcard with explicit excludes
* Wed Jan 14 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.2
  * Patches added:
  0037-AIO-Reduce-number-of-threads-for-32.patch
* Mon Jan 12 2015 afaerber@suse.de
- Update to v2.2.0: See http://wiki.qemu-project.org/ChangeLog/2.2
  * Updated DictZip and Tar block backends accordingly
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.2
  * Patches dropped:
  0015-target-arm-linux-user-no-tb_flush-o.patch (tb_flush() not called)
  0037-tests-Don-t-run-qom-test-twice.patch (superseded)
  0039-linux-user-Cast-validity-checks-on-.patch (helper function introduced)
  0040-linux-user-Convert-blkpg-to-use-a-s.patch (upstreamed)
  * Patched renumbered:
  0016-linux-user-Ignore-broken-loop-ioctl.patch -> 0015-linux-user-Ignore-broken-loop-ioctl.patch
  0017-linux-user-lock-tcg.patch                 -> 0016-linux-user-lock-tcg.patch
  0018-linux-user-Run-multi-threaded-code-.patch -> 0017-linux-user-Run-multi-threaded-code-.patch
  0019-linux-user-lock-tb-flushing-too.patch     -> 0018-linux-user-lock-tb-flushing-too.patch
  0020-linux-user-Fake-proc-cpuinfo.patch        -> 0019-linux-user-Fake-proc-cpuinfo.patch
  0021-linux-user-implement-FS_IOC_GETFLAG.patch -> 0020-linux-user-implement-FS_IOC_GETFLAG.patch
  0022-linux-user-implement-FS_IOC_SETFLAG.patch -> 0021-linux-user-implement-FS_IOC_SETFLAG.patch
  0023-linux-user-XXX-disable-fiemap.patch       -> 0022-linux-user-XXX-disable-fiemap.patch
  0024-slirp-nooutgoing.patch                    -> 0023-slirp-nooutgoing.patch
  0025-vnc-password-file-and-incoming-conn.patch -> 0024-vnc-password-file-and-incoming-conn.patch
  0026-linux-user-add-more-blk-ioctls.patch      -> 0025-linux-user-add-more-blk-ioctls.patch
  0027-linux-user-use-target_ulong.patch         -> 0026-linux-user-use-target_ulong.patch
  0028-block-Add-support-for-DictZip-enabl.patch -> 0027-block-Add-support-for-DictZip-enabl.patch
  0029-block-Add-tar-container-format.patch      -> 0028-block-Add-tar-container-format.patch
  0030-Legacy-Patch-kvm-qemu-preXX-dictzip.patch -> 0029-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0031-Legacy-Patch-kvm-qemu-preXX-report-.patch -> 0030-Legacy-Patch-kvm-qemu-preXX-report-.patch
  0032-console-add-question-mark-escape-op.patch -> 0031-console-add-question-mark-escape-op.patch
  0033-Make-char-muxer-more-robust-wrt-sma.patch -> 0032-Make-char-muxer-more-robust-wrt-sma.patch
  0034-linux-user-lseek-explicitly-cast-no.patch -> 0033-linux-user-lseek-explicitly-cast-no.patch
  0035-virtfs-proxy-helper-Provide-__u64-f.patch -> 0034-virtfs-proxy-helper-Provide-__u64-f.patch
  0036-configure-Enable-PIE-for-ppc-and-pp.patch -> 0035-configure-Enable-PIE-for-ppc-and-pp.patch
  0038-qtest-Increase-socket-timeout.patch       -> 0036-qtest-Increase-socket-timeout.patch
* Mon Sep  1 2014 afaerber@suse.de
- Enable RDMA support for SLE12 and later
* Thu Aug 28 2014 afaerber@suse.de
- Copy the freshly built s390-ccw.img over to the location
  from which it is installed (bnc#893535)
* Fri Aug 22 2014 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches added:
  0039-linux-user-Cast-validity-checks-on-.patch
  0040-linux-user-Convert-blkpg-to-use-a-s.patch
* Thu Aug 21 2014 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
- Revert use of %%{version} in Source line as it breaks update_git.sh
* Thu Aug  7 2014 coolo@suse.com
- build libcaca from a different spec file to avoid cycles with
  spice
* Wed Aug  6 2014 coolo@suse.com
- update to v2.1.0: http://wiki.qemu-project.org/ChangeLog/2.1
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches dropped:
  0039-fix-full-frame-updates-for-VNC-clie.patch
  0040-vnc-update-fix.patch
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Fri Jul 25 2014 afaerber@suse.de
- Backported VNC fixes for openQA (bnc#888142):
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches added:
  0039-fix-full-frame-updates-for-VNC-clie.patch
  0040-vnc-update-fix.patch
* Wed Jul 23 2014 afaerber@suse.de
- Update to v2.1.0-rc3: http://wiki.qemu-project.org/ChangeLog/2.1
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches dropped:
  0039-module-Simplify-module_load.patch
  0040-module-Don-t-complain-when-a-module.patch
  * Updated update_git.sh script accordingly
* Wed Jul 16 2014 afaerber@suse.de
- Update to v2.1.0-rc2: http://wiki.qemu-project.org/ChangeLog/2.1
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches dropped:
  0041-tests-Fix-unterminated-string-outpu.patch
  0042-libqos-Fix-PC-PCI-endianness-glitch.patch
  0043-qtest-fix-vhost-user-test-compilati.patch
  * Updated update_git.sh accordingly
  * Extended update_git.sh to add generated patch names to change log
* Wed Jul  9 2014 afaerber@suse.de
- Update to v2.1.0-rc0: http://wiki.qemu-project.org/ChangeLog/2.1
  * xen_disk discard support now upstream
  0037-xen_disk-add-discard-support.patch dropped
  * PowerPC ELF v2 support now upstream
  0045-tcg-ppc64-Support-the-ELFv2-ABI.patch dropped
  * Patches renamed during rebase:
  0015-linux-user-arm-no-tb_flush-on-reset.patch -> 0015-target-arm-linux-user-no-tb_flush-o.patch
  * Patches reordered due to rebase:
  0038-tests-Don-t-run-qom-test-twice.patch -> 0037-tests-Don-t-run-qom-test-twice.patch
  0041-qtest-Increase-socket-timeout.patch -> 0038-qtest-Increase-socket-timeout.patch
  0071-module-Simplify-module_load.patch -> 0039-module-Simplify-module_load.patch
  0072-module-Don-t-complain-when-a-module.patch -> 0040-module-Don-t-complain-when-a-module.patch
  * Patches automatically dropped on rebase:
  0039-qtest-Assure-that-init_socket-s-lis.patch
  0040-qtest-Add-error-reporting-to-socket.patch
  0042-qtest-Be-paranoid-about-accept-addr.patch
  0043-arm-translate.c-Fix-smlald-Instruct.patch
  0044-target-arm-A64-fix-unallocated-test.patch
  0046-vmstate-add-VMS_MUST_EXIST.patch
  0047-vmstate-add-VMSTATE_VALIDATE.patch
  0048-virtio-net-fix-buffer-overflow-on-i.patch
  0049-virtio-net-out-of-bounds-buffer-wri.patch
  0050-virtio-out-of-bounds-buffer-write-o.patch
  0051-ahci-fix-buffer-overrun-on-invalid-.patch
  0052-hpet-fix-buffer-overrun-on-invalid-.patch
  0053-hw-pci-pcie_aer.c-fix-buffer-overru.patch
  0054-pl022-fix-buffer-overun-on-invalid-.patch
  0055-vmstate-fix-buffer-overflow-in-targ.patch
  0056-virtio-avoid-buffer-overrun-on-inco.patch
  0057-virtio-validate-num_sg-when-mapping.patch
  0058-pxa2xx-avoid-buffer-overrun-on-inco.patch
  0059-ssd0323-fix-buffer-overun-on-invali.patch
  0060-tsc210x-fix-buffer-overrun-on-inval.patch
  0061-zaurus-fix-buffer-overrun-on-invali.patch
  0062-virtio-scsi-fix-buffer-overrun-on-i.patch
  0063-vmstate-s-VMSTATE_INT32_LE-VMSTATE_.patch
  0064-usb-sanity-check-setup_index-setup_.patch
  0065-savevm-Ignore-minimum_version_id_ol.patch
  0066-ssi-sd-fix-buffer-overrun-on-invali.patch
  0067-openpic-avoid-buffer-overrun-on-inc.patch
  0068-virtio-net-out-of-bounds-buffer-wri.patch
  0069-virtio-validate-config_len-on-load.patch
  0070-virtio-allow-mapping-up-to-max-queu.patch
  * iPXE fixes now included
  ipxe-build-Work-around-bug-in-gcc-4.8.patch dropped
  ipxe-build-Avoid-strict-aliasing-warning.patch dropped
  ipxe-zbin-Fix-size-used-for-memset-in-al.patch dropped
  * SeaVGABIOS fix now included
  vgabios-Make-sure-stdvga_list_modes-doesn-t-overrun-.patch dropped
  * Modified update_git.sh accordingly
- Update to v2.1.0-rc1: http://wiki.qemu-project.org/ChangeLog/2.1
  * 0041-tests-Fix-unterminated-string-outpu.patch: Test fix
  * 0042-libqos-Fix-PC-PCI-endianness-glitch.patch: Test fix for ppc
  * 0043-qtest-fix-vhost-user-test-compilati.patch: Test fix for SP3
  * Modified update_git.sh accordingly
* Mon Jun 23 2014 afaerber@suse.de
- Move block-curl.so to new qemu-block-curl package, avoiding a
  dependency of qemu-tools on qemu for Xen (bnc#882008)
  * Avoid the reported error message about missing modules
  0071-module-Simplify-module_load.patch
  0072-module-Don-t-complain-when-a-module.patch
- Improve update_git.sh performance (backport from SLE12)
* Mon Jun  2 2014 brogers@suse.com
- only build the x86 firmware on x86, ensuring consistent binaries
- remove un-needed pmtools BuildRequires
- Fix vga related problem doing direct kernel boot for SLES 10 and
  SLES 11 guests (bnc#880625)
  vgabios-Make-sure-stdvga_list_modes-doesn-t-overrun-.patch
- Probe vhost-net module on SLE11 (copied from SP3 package)
* Sat May 24 2014 afaerber@suse.de
- Fix CVE-2013-4148 (bnc#864812)
  0048-virtio-net-fix-buffer-overflow-on-i.patch
- Fix CVE-2013-4149 (bnc#864649)
  0068-virtio-net-out-of-bounds-buffer-wri.patch
- Fix CVE-2013-4150 (bnc#864650)
  0049-virtio-net-out-of-bounds-buffer-wri.patch
- Fix CVE-2013-4151 (bnc#864653)
  0050-virtio-out-of-bounds-buffer-write-o.patch
- Fix CVE-2013-4526 (bnc#864671)
  0051-ahci-fix-buffer-overrun-on-invalid-.patch
- Fix CVE-2013-4527 (bnc#864673)
  0052-hpet-fix-buffer-overrun-on-invalid-.patch
- Fix CVE-2013-4529 (bnc#864678)
  0053-hw-pci-pcie_aer.c-fix-buffer-overru.patch
- Fix CVE-2013-4530 (bnc#864682)
  0054-pl022-fix-buffer-overun-on-invalid-.patch
- Fix CVE-2013-4531 (bnc#864796)
  0055-vmstate-fix-buffer-overflow-in-targ.patch
- Fix CVE-2013-4533 (bnc#864655)
  0058-pxa2xx-avoid-buffer-overrun-on-inco.patch
- Fix CVE-2013-4534 (bnc#864811)
  0067-openpic-avoid-buffer-overrun-on-inc.patch
- Fix CVE-2013-4535 / CVE-2013-4536 (bnc#864665)
  0057-virtio-validate-num_sg-when-mapping.patch
- Fix CVE-2013-4537 (bnc#864391)
  0066-ssi-sd-fix-buffer-overrun-on-invali.patch
- Fix CVE-2013-4538 (bnc#864769)
  0059-ssd0323-fix-buffer-overun-on-invali.patch
- Fix CVE-2013-4539 (bnc#864805)
  0060-tsc210x-fix-buffer-overrun-on-inval.patch
- Fix CVE-2013-4540 (bnc#864801)
  0061-zaurus-fix-buffer-overrun-on-invali.patch
- Fix CVE-2013-4541 (bnc#864802)
  0064-usb-sanity-check-setup_index-setup_.patch
- Fix CVE-2013-4542 (bnc#864804)
  0062-virtio-scsi-fix-buffer-overrun-on-i.patch
- Fix CVE-2013-6399 (bnc#864814)
  0067-virtio-avoid-buffer-overrun-on-inco.patch
- Fix CVE-2014-0182 (bnc#874788)
  0069-virtio-validate-config_len-on-load.patch
- Backported patch from stable branch (brogers):
  0070-virtio-allow-mapping-up-to-max-queu.patch
* Wed May 14 2014 afaerber@suse.de
- Fix conflict with libcacard 0.1.2 from project security
  * Adopt description and group for libcacard-devel from there
- Drop libcacard.{a,la} from libcacard-devel
  If needed, libcacard.a should go into a libcacard-devel-static.
- Change qemu-extra to explicitly list qemu-system-* binaries
* Tue May 13 2014 afaerber@suse.de
- ABI fixes for ppc64le TCG. Addresses acpi-test failures.
  0045-tcg-ppc64-Support-the-ELFv2-ABI.patch
* Sat May 10 2014 afaerber@suse.de
- Split 60-kvm.rules into 60-kvm.rules and 60-kvm.x86.rules
- Install udev rules on s390x, ppc and arm, too
  * Clean up KVM vs. qemu-kvm conditionals
- Package qemu-system-ppcemb in qemu-ppc and qemu-system-aarch64
  in qemu-arm
* Fri Apr 18 2014 afaerber@suse.de
- Fix aarch64 emulation issues:
  0043-arm-translate.c-Fix-smlald-Instruct.patch
  0044-target-arm-A64-fix-unallocated-test.patch
* Thu Apr 17 2014 afaerber@suse.de
- Attempt to solve or debug occasional qtest fd assertions
  0039-qtest-Assure-that-init_socket-s-lis.patch
  0040-qtest-Add-error-reporting-to-socket.patch
  0041-qtest-Increase-socket-timeout.patch
  0042-qtest-Be-paranoid-about-accept-addr.patch
* Thu Apr 17 2014 afaerber@suse.de
- Update to v2.0.0: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
* Mon Apr 14 2014 afaerber@suse.de
- Update to v2.0.0-rc3: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
  * Addresses CVE-2014-0150 (bnc#873235), CVE-2013-4544 (bnc#873613)
* Fri Apr 11 2014 afaerber@suse.de
- Update to v2.0.0-rc2: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
  * Resolves Gtk mouse issues (bnc#849587)
  * Fixes endianness-test failures for prep machine on Big Endian host
* Fri Apr  4 2014 afaerber@suse.de
- Fix qemu-kvm script for s390x (bnc#869021) (bfrogers)
- Fix ksm.service file permissions to not be executable w/o shebang
- Re-enable Gtk build on 11.4 (fixes unpackaged qemu.mo files error)
- Fix SLE11 SP3 build by making sub-package "noarch" conditional
  * Do not exclude qemu-ifup from qemu package when not installing
- Speed up %%check by not running qom-test twice for some targets
  0038-tests-Don-t-run-qom-test-twice.patch
* Thu Apr  3 2014 afaerber@suse.de
- Updated to v2.0.0-rc1: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
  * Resolves breakage of live migration (bnc#871302)
  * Addresses CVE-2014-0142, CVE-2014-0143, CVE-2014-0144,
  CVE-2014-0145, CVE-2014-0146, CVE-2014-0147 (bnc#870439)
- Drop 0037-roms-Build-vgabios.bin.patch (unneeded)
* Tue Apr  1 2014 afaerber@suse.de
- Enhance update_git.sh script
  * Fix duplicate .patch for short filenames
  * Read SeaBIOS version from QEMU tarball
* Mon Mar 31 2014 afaerber@suse.de
- Re-create qemu-2.0.0-rc0.tar.bz2 to include SeaBIOS .version
* Fri Mar 28 2014 afaerber@suse.de
- Improve update_git.sh script to use a user-agnostic git symlink
* Wed Mar 26 2014 brogers@suse.com
- Tidy up qemu.spec a bit: white space, line length, use macros
  as appropriate
- Improve update_git.sh to not change files in OBS if the file
  remains unchanged
* Wed Mar 26 2014 afaerber@suse.de
- Fix library directory
- Set default file attributes for qemu-ksm
- Enable Smartcard emulation
  * Reorder package definitions to avoid %%version troubles
* Wed Mar 19 2014 afaerber@suse.de
- Update to v2.0.0-rc0: Cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Adapt update_git.sh script accordingly
  * Generate package version automatically from VERSION file
  * Switch from LGPL VGABIOS to SeaVGABIOS
  * Enable modules
  * Explicitly enable virtio-blk-data-plane (no functional change)
  * Package new firmware blobs
* Fri Mar  7 2014 speilicke@suse.com
- Add qemu-ksm subpackage providing a systemd service file for
  enabling / disabling Kernel Samepage Merging. It is independent of
  qemu (but recommended by it).
* Fri Feb 28 2014 afaerber@suse.de
- Move target-x86_64.conf to qemu-x86 sub-package
* Thu Feb 20 2014 afaerber@suse.de
- Split out KVM architectures to per-architecture subpackages
- Suggest qemu-lang package
* Tue Feb 18 2014 brogers@suse.com
- enable usb passthrough via --enable-libusb config option
* Sat Feb 15 2014 brogers@suse.com
- Fix improperly formatted wrapper script (bnc#864094)
* Fri Feb 14 2014 afaerber@suse.de
- Enable make check
* Thu Feb 13 2014 brogers@suse.com
- Use Provides/Obsoletes as means to transition kvm users to the
  qemu-kvm package
* Wed Feb 12 2014 brogers@suse.com
- Migrate kvm package contents to a new qemu-kvm sub-package, and
  move the kvm related udev rules to the qemu package. (The kvm
  package is being retired).
  Add qemu-ifup
  Add qemu-kvm.1.gz
  Add kvm_stat
  Add 60-kvm.rules
  Add 80-kvm.rules
* Mon Feb  3 2014 afaerber@suse.de
- Implement discard support for xen_disk (olh) (fate#316071)
  0042-xen_disk-add-discard-support.patch.patch
* Fri Jan 24 2014 afaerber@suse.de
- Simplified VMDK SCSI support handling (backport from 13.1/v1.6.2)
  * Increases the number of heads for SCSI from 16 to 255
* Fri Jan 17 2014 afaerber@suse.de
- Bump copyright in qemu.spec.in
- Use vte-devel instead of vte2-devel and force using Gtk3,
  reported by Takashi and Dirk (bnc#840607, bnc#849587).
* Mon Jan 13 2014 coolo@suse.com
- xen dropped support for i586, so don't buildrequire it
* Thu Jan  2 2014 afaerber@suse.de
- Update version number of SeaBIOS, spotted by BdMdesigN
* Fri Dec  6 2013 afaerber@suse.de
- Update to v1.7.0: See http://wiki.qemu-project.org/ChangeLog/1.7
  * Adapted update_git.sh accordingly
  * Dropped --enable-mixemu (no longer available)
  * Added a work around for roms/Makefile issue
  * patch 0038-gdbstub-Fix-gdb_register_coprocesso.patch dropped
* Wed Oct  9 2013 dmueller@suse.com
- use --enable-pie to fix arm build
* Tue Oct  8 2013 afaerber@suse.de
- Undo workaround for sasl - fixed in Factory
* Wed Oct  2 2013 afaerber@suse.de
- Work around Factory sasl breakage by allowing build w/o vnc-sasl
- Move build_and_copy_vgabios_bin.patch to Git patch queue
  * Clearly mark in-.spec patch queue as for roms/ipxe/ only
- Synchronized qemu.spec.in from qemu.spec:
  * Added ipxe-build-Avoid-strict-aliasing-warning.patch
  * Modified SeaBIOS summary
  * Added Conflicts for firmware subpackages
  * Dropped %%dir
- Add patch enabling PIE support for ppc/ppc64 (k0da)
* Fri Sep 13 2013 brogers@suse.com
- Build x86 firmware from tarball source. The firmware components
  produced are equivalent to the upstream provided binary blobs
  currently being used. They are delivered in noarch subpackages as
  follows (addresses bnc#830002):
  * qemu-seabios v1.7.2.2
  * qemu-vgabios v0.6c
  * qemu-sgabios v8 (svn rev 8)
  * qemu-ipxe v1.0.0
- Add following patches to enable x86 firmware to build:
  ipxe-build-Work-around-bug-in-gcc-4.8.patch
  ipxe-zbin-Fix-size-used-for-memset-in-al.patch
  build_and_copy_vgabios_bin.patch
  ipxe-build-Avoid-strict-aliasing-warning.patch
* Mon Aug 26 2013 rob.verduijn@gmail.com
- Enabled usb-redirection
  * Fixes starting VMs in gnome-boxes (bnc#839703)
* Sat Aug 17 2013 afaerber@suse.de
- Enable Xen support to allow testing our QEMU in place of Xen's
  This prepares for consolidating QEMU packaging further.
* Sat Aug 17 2013 afaerber@suse.de
- Fix gdbstub for arm/m68k/ppc guests (from pending upstream pull)
* Fri Aug 16 2013 afaerber@suse.de
- Update to v1.6.0: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
* Tue Aug 13 2013 afaerber@suse.de
- Update to v1.6.0-rc3: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
- Changed back versioning scheme to 1.6.0rcX (saschpe, brogers).
* Fri Aug  9 2013 afaerber@suse.de
- Update to v1.6.0-rc2: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
- Changed version from 1.6.0rcX to 1.5.9X (reported by lnussel)
* Fri Aug  2 2013 afaerber@suse.de
- Update to v1.6.0-rc1: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
* Thu Aug  1 2013 afaerber@suse.de
- Use libfdt build dependency not just for ppc.
  QEMU 1.6 needs it for ppc, arm and microblaze guests and uses a
  bundled copy if one of those targets is built and the system does
  not have a compatible libfdt.
* Tue Jul 30 2013 afaerber@suse.de
- Update to v1.6.0-rc0: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Fixes build against recent dtc (SLE_11_SP2 ppc64 w/ Base:System)
  * Includes Gtk patches for bnc#830459
  * Adapt update_git.sh script accordingly
* Mon Jul 22 2013 brogers@suse.com
- Fix segfault that occurs from using -vga qxl (bnc#830459)
* Tue Jun 18 2013 afaerber@suse.de
- Clarify through spec file comments that the patch queue is
  auto-generated through update_git.sh.
  Please do not submit SRs that bypass our patch handling.
* Sat May 25 2013 afaerber@suse.de
- Really enable pulseaudio and oss support (bnc#737070)
- Amend licenses list with GPL-2.0 (adopted from kvm package)
- Be explicit in enabling features our packaging relies on
- Disable stripping at QEMU level
- Use %%optflags rather than $QEMU_OPT_FLAGS
* Fri May 24 2013 afaerber@suse.de
- Move /emul/ia32-linux to qemu-linux-user
* Fri May 24 2013 afaerber@suse.de
- Drop dependency on bison
  * Reorder BuildRequires alphabetically
- Fix summary of qemu-lang sub-package
- Drop post-build-checks suppression (qemu-linux-user only)
* Fri May 24 2013 afaerber@suse.de
- Enable brlapi as done for kvm package
* Fri May 24 2013 afaerber@suse.de
- Use %%{?_smp_mflags} rather than %%{?jobs:-j%%jobs}
* Thu May 23 2013 afaerber@suse.de
- Extend virtfs typedef workaround to ppc64 for SLE_11_SP2
* Tue May 21 2013 afaerber@suse.de
- Split off qemu-linux-user package into separate .spec file.
  * Simplified %%build and %%install sections
  * Dropped *-static dependencies
* Mon May 20 2013 afaerber@suse.de
- Update to v1.5.0 final: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh accordingly
  * Add BuildRequires for gtk2/3 and vte2 to enable new frontend
  * Place translations into new qemu-lang package
  * Really enable SPICE support from 11.4 in configure, too
* Fri May 17 2013 afaerber@suse.de
- Add BuildRequires for pixman, to avoid using internal version
  that fails to build on ppc
* Thu May 16 2013 afaerber@suse.de
- Update to v1.5.0-rc2: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh accordingly
- Add patch by brogers to fix SLE 11 SP2 build (from kvm package)
* Tue May 14 2013 afaerber@suse.de
- Update to v1.5.0-rc1: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh accordingly
  * TODO file no longer exists, don't try to package it
  * Package qemu-mips64{,el}
* Tue May 14 2013 ohering@suse.de
- Enable spice support starting from 11.4
* Tue May  7 2013 afaerber@suse.de
- Update to v1.5.0-rc0: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh script
  * Audio cards are now all enabled by default
* Wed Apr 24 2013 afaerber@suse.de
- Enable pa and oss audio drivers, as in kvm package (bnc#737070)
- Enable hda audio card, as done in kvm package (bnc#801794)
* Mon Apr 22 2013 dimstar@opensuse.org
- Add explicit alsa-devel BuildRequires: this used to (wrongly) be
  pulled in by libSDL-devel.
* Sun Feb 17 2013 afaerber@suse.de
- Update licenses from new format_spec_file
* Sat Feb 16 2013 afaerber@suse.de
- Update to v1.4.0: See http://wiki.qemu.org/ChangeLog/1.4
  * Adapt update_git.sh accordingly
* Sun Feb 10 2013 afaerber@suse.de
- Update to v1.4.0-rc1: See http://wiki.qemu.org/ChangeLog/1.4
  * Adapt update_git.sh accordingly
- Update update_git.sh to reference github.com/openSUSE/qemu.git
* Thu Dec 13 2012 agraf@suse.com
- linux-user: fix lseek with SEEK_END
* Thu Dec 13 2012 agraf@suse.com
- Cherry pick patches from qemu-kvm into the qemu package:
  - 0033-Add-support-for-DictZip-enabled-gzi.patch
  - 0034-Add-tar-container-format.patch.patch
  - 0035-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  - 0036-Legacy-Patch-kvm-qemu-preXX-report-.patch
  - 0037-console-add-question-mark-escape-op.patch
  - 0038-Make-char-muxer-more-robust-wrt-sma.patch
* Wed Dec  5 2012 afaerber@suse.de
- Revert memory size constraint, the workaround patch got applied
* Wed Dec  5 2012 afaerber@suse.de
- Update to v1.3.0: see http://wiki.qemu.org/ChangeLog/1.3
  * Update update_git.sh script accordingly
* Wed Nov 28 2012 afaerber@suse.de
- Replace -fno-gcse patch with v3
* Tue Nov 27 2012 afaerber@suse.de
- Add patch to workaround GCC PR55489 via -fno-gcse,
  another step to avoid builds failing with out-of-memory
* Tue Nov 27 2012 afaerber@suse.de
- Add _constraints to request adequate memory to succeed building
* Tue Nov 27 2012 afaerber@suse.de
- Update to v1.3.0-rc1: see http://wiki.qemu.org/ChangeLog/1.3
  * Update update_git.sh accordingly
* Tue Nov 20 2012 afaerber@suse.de
- Update to v1.3.0-rc0: see http://wiki.qemu.org/ChangeLog/1.3
  * Update update_git.sh accordingly
  * Disable SPICE for 11.4 since it can no longer be built lacking
  pyparsing
* Wed Oct 10 2012 agraf@suse.com
- use ulong for syscall parameters. fixes lseek with big files
* Wed Oct 10 2012 agraf@suse.com
- Add more block ioctl handlers for kiwi
* Tue Oct  9 2012 afaerber@suse.de
- Sync qemu.spec.in file, please don't forget!
* Fri Sep 14 2012 schwab@linux-m68k.org
- Don't strip binaries
* Thu Sep 13 2012 idonmez@suse.com
- Add explicit dependency on makeinfo for manpage/doc generation
* Fri Sep  7 2012 vuntz@suse.com
- Add libcap-devel BuildRequires since it's needed to enable VirtFS
  support.
- Add libcap-ng-devel BuildRequires to be able to drop privileges
  in qemu-bridge-helper.
- Add libjpeg-devel and libpng-devel BuildRequires to enable VNC
  jpeg and png support.
- Pass --enable-virtfs to configure to detect changes that will
  cause VirtFS support to not be built.
* Wed Sep  5 2012 afaerber@suse.de
- update to v1.2.0: see http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
  * this includes the fix for CVE-2012-3515
* Wed Sep  5 2012 afaerber@suse.de
- add bounds checks in console VT100 emulation (bnc#777084,
  CVE-2012-3515)
* Wed Sep  5 2012 afaerber@suse.de
- update to v1.2.0-rc3: http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
- add two patches from kvm for SUSE Studio, forwarded by Dinar:
  * add -nooutgoing option for slirp networking
  * add allowed-connections= and password-file= options for VNC
* Tue Aug 28 2012 afaerber@suse.de
- update to v1.2.0-rc1: http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
* Tue Aug 21 2012 agraf@suse.com
- fix getdent in linux-user
- fix statfs in linux-user
- disable FIEMAP support in linux-user
* Tue Aug 21 2012 agraf@suse.com
- add support for FS_IOC_[G|S]ETFLAG ioctls
* Fri Aug 17 2012 afaerber@suse.de
- update to v1.2.0-rc0: http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
  * package new qemu-or32 executable into linux-user
* Wed Aug 15 2012 dmueller@suse.com
- avoid installing qemu on a qemu build
* Tue Jul 31 2012 agraf@suse.com
- add hijack for /proc/cpuinfo
- add compatibility patch for glibc 2.16 (Thanks AJ!)
* Wed Jul 11 2012 agraf@suse.com
- fix segfault even better
* Wed Jul 11 2012 agraf@suse.com
- linux-user: improve locking even across tb flushes
* Tue Jul 10 2012 agraf@suse.com
- linux-user: pin multi-threaded applications to a single host cpu
* Tue Jul 10 2012 agraf@suse.com
- linux-user: improve lock
* Thu Jul  5 2012 agraf@suse.com
- linux-user: add tcg lock for multi-threaded guest programs
* Mon Jun 25 2012 afaerber@suse.de
- include qemu-img and qemu-nbd in qemu-tools package
* Mon Jun 25 2012 afaerber@suse.de
- add qemu-guest-agent package
* Mon Jun 25 2012 agraf@suse.com
- add fix for segv in linux-user (fixes java)
* Tue Jun 19 2012 afaerber@suse.de
- revert LIBRARY_PATH patch by Alex
* Mon Jun 18 2012 afaerber@suse.de
- add patch by Alex to force gcc being emulated for LIBRARY_PATH
* Mon Jun 18 2012 dvaleev@suse.com
- add libfdt1 to buildrequires on ppc
* Thu Jun 14 2012 afaerber@suse.de
- revert qemu-bridge-helper mode change (cf. BNC#765948)
* Wed Jun 13 2012 brogers@suse.com
- don't use permissions.d
* Wed Jun 13 2012 agraf@suse.com
- Add fix for bogus losetup ioctl to not warn us about it
* Sat Jun  9 2012 brogers@suse.com
- Set up bridge helper as a setuid executable
* Sat Jun  9 2012 afaerber@suse.de
- Add patch for specifying --libexecdir
  * Fixes having to specify the path to qemu-bridge-helper manually
- Drop superfluous `make qemu-img`
- Move qemu-bridge-helper to its own subpackage, to share with KVM
* Tue Jun  5 2012 afaerber@suse.de
- Update to v1.1.0: see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Fri Jun  1 2012 afaerber@suse.de
- Update to v1.1.0-rc4: see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Thu May 31 2012 agraf@suse.com
- fix /proc/self/maps faking with secondary threads
* Wed May 30 2012 agraf@suse.de
- revert commit a84fac1426 to fix automoc4 for arm
* Tue May 29 2012 agraf@suse.com
- remove manual interp prefix, which made all linux-user binaries
  point to an i386 LD_PREFIX path
* Tue May 29 2012 agraf@suse.com
- add patch to fix building of go (swi in thumb ignores imm)
* Tue May 22 2012 afaerber@suse.de
- Update to v1.1.0-rc3; see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Thu May 17 2012 afaerber@suse.de
- Update to v1.1.0-rc2; see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Wed May 16 2012 afaerber@suse.de
- Remove workaround for forcing cURL detection
* Sun May 13 2012 afaerber@suse.de
- Update to v1.1-rc1: see http://wiki.qemu.org/ChangeLog/1.1
  * Add workaround for 11.4: add -lrt after -lglib-2.0
- Adapt update_git.sh script to new tag
* Tue May  8 2012 afaerber@suse.de
- Update to v1.1-rc0; see http://wiki.qemu.org/ChangeLog/1.1
  * Do not try to mv qemu, the executable is gone, there's a dir now
  * Do not try to mv */qemu-*, there's a pc-bios/qemu-icon.bmp
  * Be more specific in temporary copying of files to dynamic/
  * Drop duplicate %%_bindir/qemu_binfmt_misc.sh, only in sbin now
  * Use dynamic version of new executable qemu-bridge-helper
- Update update_git.sh script to pull patches from suse-1.1 branch
* Mon May  7 2012 afaerber@suse.de
- Update URL to project homepage
* Mon May  7 2012 agraf@suse.com
- compile fixes for ppc64abi32
- fix update_fit.sh script if wc -c is 40
- fix stale tbs after mmap
* Wed Mar  7 2012 agraf@suse.com
- cut off patch file names after 40 bytes, support older git versions
  for update_git.sh
* Mon Mar  5 2012 agraf@suse.com
- resolve VMAs downwards, fixes arm git build for real
* Sat Mar  3 2012 agraf@suse.com
- update update_git.sh for 1.0.1
- add fixes for reserved_va mmap(NULL) case, fixes git build on arm
* Tue Feb 28 2012 idonmez@suse.com
- Enable spice support
* Wed Feb 22 2012 brogers@suse.com
- update to latest stable release: 1.0.1. For changes see:
  http://wiki.qemu.org/ChangeLog/1.0
* Mon Feb  6 2012 brogers@suse.com
- avoid buffer overflow in e1000 device emulation (bnc#740165)
* Mon Feb  6 2012 agraf@suse.de
- qemu-user: fix fallocate
* Fri Feb  3 2012 agraf@suse.de
- qemu-user: fix previous patch
* Thu Feb  2 2012 agraf@suse.de
- qemu-user: add host binary support for binfmt
* Thu Feb  2 2012 agraf@suse.de
- qemu-user: add fix for /proc/self/maps to only show mappable regions
* Wed Feb  1 2012 agraf@suse.de
- qemu-user: add wrapper for BLKBSZGET
* Tue Jan 31 2012 agraf@suse.de
- qemu-user: add fix for deadloop with ulimit constraints
- qemu-user: add device mapper and loopback ioctls, enabling kpatkx
* Tue Jan 10 2012 agraf@suse.de
- backport all ppc-1.0 stable patches to our package
- add fix for PPC HV KVM on 3.1
* Tue Jan 10 2012 agraf@suse.de
- add fix for PPC in HV KVM mode
* Fri Jan  6 2012 agraf@suse.de
- add workaround for KVM on PPC to support hugetlbfs
- add upstream patches to fake $0 in /proc/self/maps (fixes ps)
* Wed Dec 14 2011 agraf@suse.com
- add update_git.sh to simplify maintenance of the tree
- use -R automatically in linux-user to gain more address space
- drop MAP_32BIT patch (deprecated by the one above)
* Mon Dec 12 2011 agraf@suse.com
- add linker patch for ppc hosts
* Mon Dec 12 2011 agraf@suse.com
- remove exclusivearch - we should be able to build everywhere!
* Sun Dec 11 2011 agraf@suse.com
- fix compilation for 11.4
* Sun Dec 11 2011 agraf@suse.com
- fix compilation on sle11
- add %%fdupes for duplicate file checking
* Sun Dec 11 2011 agraf@suse.com
- update to 1.0 from upstream. for changelogs please see:
  - 0.14 -> 0.15: http://wiki.qemu.org/ChangeLog/0.15
  - 0.15 -> 1.0:  http://wiki.qemu.org/ChangeLog/1.0
- the binary "qemu" is now called qemu-system-i386
* Tue Nov  8 2011 agraf@suse.com
- only ignore specific timer_create syscall, no all of them
* Sun Nov  6 2011 agraf@suse.com
- don't print out unsupported syscalls but rather silently ignore
  them - some programs catch stderr and get confused
* Thu Nov  3 2011 adrian@suse.de
- add a number of patches to fake /proc entries (from Alex)
* Fri Oct 28 2011 adrian@suse.de
- split linux-user binaries into qemu-linux-user package
  (this static package can be used in cross build in OBS)
* Tue Oct 18 2011 adrian@suse.de
- add xattr support for openSUSE 12.1
- added syscall numbers to fix prlimit64 support (from upstream)
* Wed Oct  5 2011 joop.boonen@opensuse.org
- Fixed glibc arm build issue according to
  https://bugs.meego.com/show_bug.cgi?format=multiple&id=20418
  added a reverse patch
* Tue Oct  4 2011 adrian@suse.de
- add binfmt misc handler binary patch from alex. This is a handler
  which calls qemu with -0 argument and right parameters to avoid
  broken runs due to different set $0 as on real hardware
- move arch specific patches at the end to avoid arch dep conflicts
  with other patches
- enable linux-user build to get binfmt handler
* Thu Sep 29 2011 adrian@suse.de
- add 0021-implement-prlimit64-syscall.patch from upstream to avoid
  output and confused configure scripts when testing gcc on armv7hl
- add 0022-fixing-smp-races.patch from alex to fix some SMP races
* Tue Sep 27 2011 adrian@suse.de
- add 0020-linux-user-implement-reboot-syscall.patch from alex
- extend 0010 mmap patch for files
* Mon Sep 26 2011 adrian@suse.de
- add fix from alex for openat file permission handling
* Mon Jun 20 2011 aj@suse.de
- Add BuildRequires: glibc-devel-static
* Thu May 19 2011 andrea@opensuse.org
- removed un-required vde buildrequires
* Tue May 17 2011 brogers@novell.com
- build correctly for SLE11
- reset revision to zero after version change
* Wed May 11 2011 andrea@opensuse.org
- added 0018-qemu-0.14.1-mcast-udp.patch to enable multicast and
  udp tunneling support
* Tue May 10 2011 andrea@opensuse.org
- New Upstream version 0.14.1
    See http://wiki.qemu.org/Changelog/0.14 for changes in 0.14
- removed 0014-qemu-0.11-git-ioctl_mount.patch not required anymore
- enabled vde support
- some spec clean up
* Mon Feb 21 2011 coolo@novell.com
- disable parallel build for a while, it takes too much memory
  for our workers
* Thu Feb 10 2011 uli@suse.de
- update -> 0.14.0-rc1
  See http://wiki.qemu.org/Changelog/0.14 for changes in 0.14.
  (There is no such page for the 0.13 tree. The ChangeLog file ends at
  0.12.0, http://wiki.qemu.org/ChangeLog at 0.12.5 and suggests to look at
  the git log. High-level information of what has changed in 0.13 is
  apparently not available.)
* Fri May 28 2010 uli@suse.de
- update -> 0.12.4
  see http://wiki.qemu.org/ChangeLog for changes
* Wed May 19 2010 brogers@novell.com
- co-exist with virt-utils, which provides some qemu components
  (bnc#586115)
* Sun Apr 18 2010 crrodriguez@opensuse.org
- requires timezone
* Mon Oct  5 2009 uli@suse.de
- update -> 0.11.0 final
  - mips: fix conditional move off fp conditions codes (Nath Froyd)
  - fix migration to obey -S (Paolo Bonzini)
  - remove pc-0-10 machine type (Mark McLoughlin)
  - vnc: fix copyrect screen corruption (Gerd Hoffman)
  - fix vm state change handlers running order (Markus Armbruster)
  - e1000: fix eerc and ics emulation (Bill Paul)
  - fix sdl zooming with pl110 (Blue Swirl)
  - sparc64: flush pending conditional evaluations (Igor Kovalenko)
  - esp: fix interrupt register read (Blue Swirl)
  - option rom makefile fixes (Paul Brook)
  - fix sparse warnings (Blue Swirl)
  - fix symfind (Laurent Desnogues)
  - win32: fix default prefix (Stefan Weil)
  - fix checksum writing in signboot (Alex Graf)
  - fix sdl window resize (Stefano Stabellini)
  - do not resize the screen on hw_invalidate (Stefano Stabellini)
  - Add checks for -smbios option (Beth Kon)
  - fix do_set_link (Luiz Capitulino)
  - fix do_commit behavior (Luiz Capitulino)
  - make windows notice media change (Gleb Natapov)
  - check for PR_SET_NAME being defined (Nathan Froyd)
  - fix migration for ide devices (Anthony Liguori)
  - Use correct depth in vmware vga (Reimar Doffiner)
  - support 32bpp cursors in sdl (Reimar Doffinger)
  - fix device name completion for eject (Blue Swirl)
  - make screendump use DisplayState properly (Stefano Stabellini)
  - fix autostart with live migration (Avi Kivity)
  - fix detached migration with exec (Chris Lalancette)
  - fix segv when changing vnc password in sdl (Zach Amsden)
  - fix vnc password clearing with stdio monitor (Zach Amsden)
  - clean up VGA type selection (Zach Amsden)
  - add missing linefeed in error message (Stefan Weil)
  - fix rtc polling mode (Bernhard Kauer)
  - qcow2: order concurrent aio requests (Kevin Wolf)
  - qemu-io: port to win32 (Stefan Weil)
  - alpha: fix extlh instruction (Vince Weaver)
  - tcg: fix size of local variables in tcg_gen_bswap64_i64 (Stefan Weil)
  - net: fix send ordering (Jan Kiszka)
  - escc: fix IRQ routing (Aurelien Jarno)
  - versatile: fix Linux task preemption (Aurelien Jarno)
  - curses: reduce memory usage by 250MB (Aurelien Jarno)
- disabled ppc64 host, seems to be very broken
* Thu Sep 10 2009 uli@suse.de
- package missing tools (qemu-nbd, qemu-io)
* Thu Sep  3 2009 uli@suse.de
- disable S/390 target on 32-bit platforms
* Tue Aug 11 2009 uli@suse.de
- update -> 0.11.0 RC1
  - add machine aliasing support (Mark McLoughlin)
  - add getfd/closefd monitor commands (Mark McLoughlin)
  - fix live migration (various)
  - HPET fixes (various)
  - slirp: fix guestfwd for incoming data (Jan Kiszka)
  - fix qemu-img convert to copy unallocated parts of the image
    (Akkarit Sangpetch)
  - vmdk: fix backing file handling (Kevin Wolf)
  - scsi: add save/restore support (Nolan Leake)
  - e1000: ignore reset command (Kevin Wolf)
  - allow monitor interaction when using -incoming exec: (Chris Lalancette)
  - fix -net socket,listen (Jan Kiszka)
  - serial: fix lost characters after sysrq (Jason Wessel)
  - lsi53c895a: Implement additional registers (Sebastian Herbszt)
  - i386: fix cpu reset (Nitin Kamble)
  - Prevent CD-ROM eject while device is locked (Mark McLoughlin)
  - Fix memory leaks (various)
  - Reset PS2 keyboard/mouse on reset (Dinesh Subraveti)
  - Fix -initrd with > 4GB guests (Glauber Costa)
  - qcow2 fixes (various)
  - Enable power button event generation (Gleb Natapov)
  - fix serial option in -drive
  - Fix non-ACPI timer interrupt routing (Beth Kon)
  - Fix keyboard mapping on newer Xords with non-default keymaps (balrog)
  - Make PCI config status register read-only (Anthony Liguori)
  - Fix crash on resolution change -> screen dump -> vga redraw (Avi Kivity)
  - fix savevm/loadvm (various)
  - virtio: fix guest oops with 2.6.25 kernels (Rusty Russell)
  - SH4: add support for -kernel (Takashi Yoshii, Aurelien Jarno)
  - hotplug: fix closing of char devices (Jan Kiszka)
  - hotplug: remove incorrect check for device name (Eduardo Habkost)
  - fix VGA regression (malc)
- added S/390 host and target
- maintaining patches in git
- several linux-user improvements for compatibility and speed
- enabled curl block driver, VNC TLS and SASL, AIO, and Bluetooth
* Wed Apr 15 2009 ro@suse.de
- buildfix: refresh patches
* Fri Mar 27 2009 crrodriguez@suse.de
- BuildRequire zlib-devel-static
* Tue Mar 24 2009 uli@suse.de
- update -> release (0.10.1)
  - fixes bnc #435135 (CVE-2008-4539, SWAMP #22179), #362956
    (CVE-2008-1945, CVE-2008-0928), #461565 (CVE-2008-2382)
  - Kernel Virtual Machine acceleration support
  - GDB XML register description support
  - Intel e1000 emulation
  - HPET emulation
  - VirtIO paravirtual device support
  - Marvell 88w8618 / MusicPal emulation
  - Nokia N-series tablet emulation / OMAP2 processor emulation
  - PCI hotplug support
  - Curses display support
  - qemu-nbd utility to mount supported block formats
  - Altivec support in PPC emulation and new firmware (OpenBIOS)
  - Multiple VNC clients are now supported
  - TLS encryption is now supported in VNC
  - MIPS Magnum R4000 machine (Hervé Poussineau)
  - Braille support (Samuel Thibault)
  - Freecom MusicPal system emulation (Jan Kiszka)
  - OMAP242x and Nokia N800, N810 machines (Andrzej Zaborowski)
  - EsounD audio driver (Frederick Reeve)
  - Gravis Ultrasound GF1 sound card (Tibor "TS" Schütz)
  - Many, many, bug fixes and new features
  - virtio-net: allow masking of notifications on empty queue (Alex
    Williamson)
  - e1000: fix rx descriptor low threshold logic (Alex Willaimson)
  - x86 tcg: add NULL checks to lsl instruction (Jan Kiszka)
  - kvm vga: fix screen corruption with -std-vga and Windows (Avi Kivity)
  - kvm vga: fix screen corruption with Ubuntu installations (Glauber Costa)
  - virtio-net: check right return size on sg list (Alex Williamson)
  - Make qemu_announce_self handle holes (live migration after hotplug)
    (Marcelo Tosatti)
  - Revert r6804-r6808 (qcow2 allocation info).  This series of changes
    added a high cost to startup for large qcow2 images (Anthony Liguori)
  - qemu-img: fix help message (Aurelien Jarno)
  - Fix build for non-default installs of SDL (Anthony Liguori)
  - Fix race condition in env->interrupt_request.  When using TCG and a
    dynticks host timer, this condition could cause TCG to get stuck in an
    infinite loop (Aurelien Jarno)
  - Fix reading encrypted hard disk passwords during early startup (Jan
    Kiszka)
  - Fix encrypted disk reporting in 'info block' (Jan Kiszka)
  - Fix console size with tiny displays (MusicPal) (Jan Kiszka)
  - Improve error handling in bdrv_open2 (Jan Kiszka)
  - Avoid leaking data in mux'ed character devices (Jan Kiszka)
  - Fix initial character device reset (no banner in monitor) (Jan Kiszka)
  - Fix cpuid KVM crash on i386 host (Lubomir Rintel)
  - Fix SLES10sp2 installation by adding ISTAT1 register to LSI SCSI
    emulation (Ryan Harper)
- s390x TCG backend
- i386-linux-user NPTL support
* Wed Oct  8 2008 uli@suse.de
- update -> current SVN
  - fixes PPC hosts
  - fixes SH4 targets (reenabled), adds NPTL support
  - SSSE3, SSE4.* instructions, "unreal" mode fixed
  - Alpha target converted to TCG
  - live migration
  - Bluetooth emulation
  - SCSI tape support
  - OpenBIOS binary updated
  - UHCI emulation rewritten
  - lots of bugfixes
* Mon Aug  4 2008 ro@suse.de
- fix build by adding return statements for two nonvoid functions
  (qemu-nonvoid_return.patch), actually unreached code
* Thu Jul 24 2008 uli@suse.de
- update -> current SVN
  - MIPS Magnum R4000 machine (Hervé Poussineau)
  - Braille support (Samuel Thibault)
  - Freecom MusicPal system emulation (Jan Kiszka)
  - OMAP242x and Nokia N800, N810 machines (Andrzej Zaborowski)
  - EsounD audio driver (Frederick Reeve)
  - Gravis Ultrasound GF1 sound card (Tibor "TS" Schütz)
- added pcap networking
- ditched GCC3 thanks to TCG. Hooray!
  (downside: no PPC and SH4 emulation, no S/390 host)
* Thu May 15 2008 cthiel@suse.de
- use lsilogic instead of buslogic for SCSI VMDK images
* Thu May  8 2008 uli@suse.de
- add format option to disable autodetection of disk image format
  (bnc#380828)
* Fri Apr 25 2008 uli@suse.de
- revert secfix (causes data corruption, no known good patch
  available yet)
- support creation of SCSI VMDK images
* Tue Mar 11 2008 uli@suse.de
- secfix (unchecked block read/write vulnerability, bug #362956)
* Thu Jan 17 2008 uli@suse.de
- update -> 0.9.1
  - TFTP booting from host directory (Anthony Liguori, Erwan Velu)
  - Tap device emulation for Solaris (Sittichai Palanisong)
  - Monitor multiplexing to several I/O channels (Jason Wessel)
  - ds1225y nvram support (Herve Poussineau)
  - CPU model selection support (J. Mayer, Paul Brook, Herve Poussineau)
  - Several Sparc fixes (Aurelien Jarno, Blue Swirl, Robert Reif)
  - MIPS 64-bit FPU support (Thiemo Seufer)
  - Xscale PDA emulation (Andrzej Zaborowski)
  - ColdFire system emulation (Paul Brook)
  - Improved SH4 support (Magnus Damm)
  - MIPS64 support (Aurelien Jarno, Thiemo Seufer)
  - Preliminary Alpha guest support (J. Mayer)
  - Gumstix boards: connex and verdex emulation (Thorsten Zitterell)
  - Intel mainstone II board emulation (Armin Kuster)
  - VMware SVGA II graphics card support (Andrzej Zaborowski)
- revert s390-dis.c to last GPLv2 version
- reenabled qemu-system-ppcemb
* Mon Dec 10 2007 uli@suse.de
- fixed open() usage with O_CREAT
* Tue Nov 13 2007 uli@suse.de
- update -> current CVS:
  - Read-only support for Parallels disk images (Alex Beregszaszi)
  - CRIS emulation (Edgar E. Iglesias)
  - SPARC32PLUS execution support (Blue Swirl)
  - MIPS mipssim pseudo machine (Thiemo Seufer)
  - Strace for Linux userland emulation (Stuart Anderson, Thayne Harbaugh)
  - OMAP310 MPU emulation plus Palm T|E machine (Andrzej Zaborowski)
  - ARM v6, v7, NEON SIMD and SMP emulation (Paul Brook/CodeSourcery)
* Thu Oct 11 2007 ro@suse.de
- hack to fix build: undef DEBUG_BLOCK for now
* Fri Sep 28 2007 agraf@suse.de
- fix SVM support (Alexander Graf)
* Thu Sep 13 2007 agraf@suse.de
- add SVM emulation support (Alexander Graf)
- fix a misassumption in the s390 fix (uli)
- allow more IDE power management (Ben Guthro)
- log any I/O error and perform automatic read retry for CDrom (Ben Guthro)
- fix Coherent guest support (Jan Jezabek)
- fix several Darwin guest issues (Filip Navara)
* Mon Aug 20 2007 agraf@suse.de
- fix ATAPI bug when using libata (Brandon Philips)  (#291775)
* Sat Aug 11 2007 olh@suse.de
- disable only SNDRV_SB_CSP_IOCTL_LOAD_CODE for _IOC_SIZEBITS < 14
* Thu Aug  9 2007 olh@suse.de
- disable some alsa SB ioctl declarations
* Mon Aug  6 2007 olh@suse.de
- remove inclusion of linux/compiler.h
* Mon Jul 30 2007 uli@suse.de
- fixed for S/390
* Tue Jul 10 2007 schwab@suse.de
- Add (incomplete) m68k emulation.
* Mon Jul  9 2007 agraf@suse.de
- included alsa support in qemu-user
- update to current cvs
  - TFTP booting from host directory (Anthony Liguori, Erwan Velu)
  - Tap device emulation for Solaris (Sittichai Palanisong)
  - Monitor multiplexing to several I/O channels (Jason Wessel)
  - ds1225y nvram support (Herve Poussineau)
  - CPU model selection support (J. Mayer, Paul Brook, Herve Poussineau)
  - Several Sparc fixes (Aurelien Jarno, Blue Swirl)
  - MIPS 64-bit FPU support (Thiemo Seufer)
  - Xscale PDA emulation (Andrzei Zaborowski)
  - ColdFire system emulation (Paul Brook)
  - Improved SH4 support (Magnus Damm)
  - MIPS64 support (Aurelien Jarno, Thiemo Seufer)
  - Preliminary Alpha guest support (J. Mayer)
  - IPC fixes
* Wed Jun 20 2007 agraf@suse.de
- applied proper fix for x86_64 and the MAP_32BIT flag
* Wed Jun 20 2007 uli@suse.de
- added secfixes (bug #252519)
* Thu Jun 14 2007 agraf@suse.de
- made wine work (set FS register to 0 on init)
- suppressed robust_list warnings
* Wed Jun 13 2007 agraf@suse.de
- made flash player 9 work on ppc
- fixed FUTEX_WAKE_OP on machines where endianness differs
- made mmap on x86_64 use the MAP_32BIT flag
- removed a useless spin_lock
- removed an annoying debug message for forking
- implemented sched_getaffinity syscall
- fixed configure call so it takes gcc3 again
* Wed Jun 13 2007 uli@suse.de
- support "vga=" parameter (Pascal Terjan)
- direct jump support for x86-64 (Gwenole Beauchesne)
- fix chaining of CPU instances (Gwenole Beauchesne)
- live migration support (Anthony Liguori)
- fix fprem/fprem1 insns (Julian Seward)
- KVM support
- Z80/ZX Spectrum emulation (Stuart Brady)
- GCC4 support postponed (breaks x86-64 on i386)
* Mon Jun 11 2007 agraf@suse.de
- implemented TLS support on i386 so qemu-user can be used to run
  with current libc versions (partly done by David Woodhouse,
  fixed by Alexander Graf)
- added a dirty hack for an mmap page table bug on qemu-user x86
  emulation
- disable AF_NETLINK in qemu-user (endianness problems)
- applied fast path mangling patch from Kirill A. Shutemov
- applied strace patch for debugging (by Stuart R. Anderson)
* Wed Apr  4 2007 agraf@suse.de
- fixed initrd loading on x86
* Thu Mar 29 2007 ro@suse.de
- added bison to BuildRequires
* Tue Feb 20 2007 uli@suse.de
- added better fix by Robert Schiele (bug #241950)
- update -> 0.9.0
  - Support for relative paths in backing files for disk images
  - Async file I/O API
  - New qcow2 disk image format
  - Support of multiple VM snapshots
  - Linux: specific host CDROM and floppy support
  - SMM support
  - Moved PCI init, MP table init and ACPI table init to Bochs BIOS
  - Support for MIPS32 Release 2 instruction set (Thiemo Seufer)
  - MIPS Malta system emulation (Aurelien Jarno, Stefan Weil)
  - Darwin userspace emulation (Pierre d'Herbemont)
  - m68k user support (Paul Brook)
  - several x86 and x86_64 emulation fixes
  - Mouse relative offset VNC extension (Anthony Liguori)
  - PXE boot support (Anthony Liguori)
  - '-daemonize' option (Anthony Liguori)
* Tue Feb  6 2007 uli@suse.de
- added fix by Robert Schiele to work without usbdevfs
  (bug #241950)
* Thu Feb  1 2007 ro@suse.de
- remove -fstack-protector from CFLAGS
* Fri Oct 27 2006 schwab@suse.de
- Fix char signedness.
* Mon Sep 11 2006 uli@suse.de
- re-added ARM FPE patch
- fixed SPARC on PPC
- install missing openbios-sparc32
* Sat Sep  9 2006 dmueller@suse.de
- update to 0.8.2:
  - ACPI support
  - PC VGA BIOS fixes
  - MIPS FPU support (Marius Groeger)
  - PPC breakpoints and single stepping (Jason Wessel)
  - USB updates (Paul Brook)
  - UDP/TCP/telnet character devices (Jason Wessel)
  - Windows sparse file support (Frediano Ziglio)
  - RTL8139 NIC TCP segmentation offloading (Igor Kovalenko)
  - PCNET NIC support (Antony T Curtis)
  - Support for variable frequency host CPUs
  - Workaround for win32 SMP hosts
  - Support for AMD Flash memories (Jocelyn Mayer)
  - Audio capture to WAV files support (malc)
* Tue May 30 2006 uli@suse.de
- fixed to build on PPC with new glibc
* Mon May 29 2006 uli@suse.de
- fixed to build with new kernel headers
* Wed Mar  8 2006 uli@suse.de
- split giant patch
- added NWFPE glue code fix
* Tue Mar  7 2006 schwab@suse.de
- More fixes for ia64 port.
* Mon Mar  6 2006 schwab@suse.de
- Remove obsolete hunk from ia64 patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 uli@suse.de
- update -> 0.8.0
* Thu Dec  8 2005 uli@suse.de
- update to current CVS (MIPS userspace, ARM system, SMP, USB,
  NX, VLAN, serial, parallel, ES1370, ALSA backend)
- build i386 and AMD64 emus with kqemu support if possible
- install missing PPC video driver, SPARC boot ROM
- install missing keymaps
* Mon Nov  7 2005 uli@suse.de
- updated linker scripts for new binutils release
* Sat Sep 17 2005 dmueller@suse.de
- update to 0.7.2
* Mon Aug 15 2005 schwab@suse.de
- Don't package /emul/ia32-linux on ia64.
* Mon Aug 15 2005 schwab@suse.de
- Fix compilation on ia64.
* Mon Aug  1 2005 uli@suse.de
- update -> 0.7.1
- enabled x86_64-system
* Mon Jul 11 2005 uli@suse.de
- update -> CVS (MIPS emulation)
- build with throwaway GCC3 (still no GCC4-compatible QEMU in
  sight)
- enabled armeb-user
- link *-user statically (necessary for chrooting into non-native
  systems)
- disabled s390, alpha, armv4l build (broken and unmaintained)
- disabled qemu-fast (broken and deprecated)
- disabled i386-user on x86_64 (useless)
- build with %%jobs
* Wed Jun  1 2005 ro@suse.de
- update to 0.7.0, still no success with gcc-4
* Thu Jan 27 2005 uli@suse.de
- baselibs-x86 link is unnecessary on x86/AMD64
- two ARM emulation fixes (RRX operand fix by Paul Brook, shifter
  carry fix by me)
- SDL 1.2.8 can be linked statically -> enabled qemu-fast
* Mon Nov 29 2004 uli@suse.de
- update -> 0.6.1
- build softmmu binaries on s390 (still doesn't work though)
- pack /emul/ia32-linux directory and symlink from /usr/share/qemu
  so it's possible to use the IA64 baselibs-x86 packages
* Wed Sep 15 2004 uli@suse.de
- removed unnecessary dependency on private glibc symbol
  (bug #44864)
* Fri Aug  6 2004 uli@suse.de
- update -> 0.6.0 (fixes for several OSs, improvements in emulated
  hardware (IDE, PCI, network, VGA, APM, PowerMac), minor fixes,
  tool for conversion of VMware images)
* Tue May 11 2004 uli@suse.de
- update -> 0.5.5 (contains ARM, utime() fixes and several others)
- make uname() return target machine name (fixes config.guess,
  rpm etc.)
- fake sigaltstack() (fixes m4)
- enabled x86-64
* Wed May  5 2004 uli@suse.de
- fixed ARM emulation bug
* Wed Apr 28 2004 uli@suse.de
- build with -fno-unit-at-a-time (fixes PPC system emulator)
* Wed Apr 28 2004 uli@suse.de
- update -> 0.5.4 (runs Linux/PPC, several fixes)
* Mon Apr 19 2004 uli@suse.de
- initial package
